/************************************************************************//**
 *
 * @file    lcd8b_reg.h
 *
 * @brief   Definition of the LCD8B Register.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Oct. 2017    1.10
 *              - Modify register definition.
 *          - 01 Nov. 2018    1.20
 *              - Change source code.
 *
 ***************************************************************************/
#ifndef LCD8B_REG_H__
#define LCD8B_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <c17_mcu_select.h>

/// LCD8B Clock Control Register
typedef union LCD8CLK_REG_TAG {
    unsigned short  reg;
    struct LCD8CLK_REG_BIT_TAG {
        /**
         * These bits select the clock source of the LCD8B.
         * .CLKSRC[1:0]
         *  These bits select the clock source of the LCD8B.
         * .CLKDIV[2:0]
         *  These bits select the division ratio of the LCD8B operating clock.
         * +-------------+-----------------------------------+
         * |             |           CLKSRC[1:0]             |
         * |             +--------+--------+--------+--------+
         * |             |  0x0   |   0x1  |  0x2   |  0x3   |
         * | CLKDIV[2:0] +--------+--------+--------+--------+
         * |             |        |        |        |        |
         * |             |  IOSC  |  OSC1  |  OSC3  | EXOSC  |
         * |             |        |        |        |        |
         * +-------------+--------+--------+--------+--------+
         * |   0x6,0x7   |Reserved|  1/1   |Reserved|  1/1   |
         * +-------------+--------+        +--------+        +
         * |     0x5     | 1/128  |        | 1/128  |        |
         * +-------------+--------+        +--------+        +
         * |     0x4     |  1/64  |        |  1/64  |        |
         * +-------------+--------+        +--------+        +
         * |     0x3     |  1/32  |        |  1/32  |        |
         * +-------------+--------+        +--------+        +
         * |     0x2     |  1/16  |        |  1/16  |        |
         * +-------------+--------+        +--------+        +
         * |     0x1     |  1/8   |        |  1/8   |        |
         * +-------------+--------+        +--------+        +
         * |     0x0     |  1/4   |        |  1/4   |        |
         * +-------------+--------+--------+--------+--------+
         */
        unsigned short      CLKSRC      : 2;
        unsigned short      reserved_1  : 2;    ///< Reserved.
        /**
         * These bits select the clock source of the LCD8B.
         * .CLKSRC[1:0]
         *  These bits select the clock source of the LCD8B.
         * .CLKDIV[2:0]
         *  These bits select the division ratio of the LCD8B operating clock.
         * +-------------+-----------------------------------+
         * |             |           CLKSRC[1:0]             |
         * |             +--------+--------+--------+--------+
         * |             |  0x0   |   0x1  |  0x2   |  0x3   |
         * | CLKDIV[2:0] +--------+--------+--------+--------+
         * |             |        |        |        |        |
         * |             |  IOSC  |  OSC1  |  OSC3  | EXOSC  |
         * |             |        |        |        |        |
         * +-------------+--------+--------+--------+--------+
         * |   0x6,0x7   |Reserved|  1/1   |Reserved|  1/1   |
         * +-------------+--------+        +--------+        +
         * |     0x5     | 1/128  |        | 1/128  |        |
         * +-------------+--------+        +--------+        +
         * |     0x4     |  1/64  |        |  1/64  |        |
         * +-------------+--------+        +--------+        +
         * |     0x3     |  1/32  |        |  1/32  |        |
         * +-------------+--------+        +--------+        +
         * |     0x2     |  1/16  |        |  1/16  |        |
         * +-------------+--------+        +--------+        +
         * |     0x1     |  1/8   |        |  1/8   |        |
         * +-------------+--------+        +--------+        +
         * |     0x0     |  1/4   |        |  1/4   |        |
         * +-------------+--------+--------+--------+--------+
         */
        unsigned short      CLKDIV      : 3;
        unsigned short      reserved_2  : 1;    ///< Reserved.
        /**
         * This bit sets whether the LCD8B operating clock is supplied in DEBUG mode or not.
         * .DBRUN
         *  This bit sets whether the LCD8B operating clock is supplied in DEBUG mode or not.
         *    1 (R/W): Clock supplied in DEBUG mode
         *    0 (R/W): No clock supplied in DEBUG mode
         */
        unsigned short      DBRUN       : 1;
        unsigned short      reserved_3  : 7;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} LCD8CLK_REG;

/// LCD8B Control Register
typedef union LCD8CTL_REG_TAG {
    unsigned short  reg;
    struct LCD8CTL_REG_BIT_TAG {
        /**
         * This bit enables the LCD8B operations.
         * .MODEN
         *  This bit enables the LCD8B operations.
         *    1 (R/W): Enable LCD8B operations (The operating clock is supplied.)
         *    0 (R/W): Disable LCD8B operations (The operating clock is stopped.)
         */
        unsigned short      MODEN       : 1;
        /**
         * This bit enables the SEG/COM-pin discharge operations when Display off is selected.
         * .LCDDIS
         *    1 (R/W): Enable SEG/COM-pin discharge operations
         *    0 (R/W): Disable SEG/COM-pin discharge operations
         */
        unsigned short      LCDDIS      : 1;
        unsigned short      reserved_1  :14;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} LCD8CTL_REG;

/// LCD8B Timing Control Register 1
typedef union LCD8TIM1_REG_TAG {
    unsigned short  reg;
    struct LCD8TIM1_REG_BIT_TAG {
        /**
         * These bits set the drive duty.
         * .LDUTY[2:0]
         *  These bits set the drive duty.
         */
        unsigned short      LDUTY       : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * These bits set the frame frequency.
         * .FRMCNT[3:0]
         *  These bits set the frame frequency
         */
        unsigned short      FRMCNT      : 4;
        unsigned short      reserved_2  : 4;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} LCD8TIM1_REG;

/// LCD8B Timing Control Register 2
typedef union LCD8TIM2_REG_TAG {
    unsigned short  reg;
    struct LCD8TIM2_REG_BIT_TAG {
        /**
         * These bits enable the n-line inverse AC drive function and set the number of inverse lines.
         * .NLINE[2:0]
         * These bits enable the n-line inverse AC drive function and set the number of inverse lines.
         * +-------------+--------------------------+
         * |  NLINE[4:0] |  Number of inverse lines |
         * +-------------+--------------------------+
         * |     0x7     |          7 lines         |
         * +-------------+--------------------------+
         * |     ...     |          ...             |
         * +-------------+--------------------------+
         * |     0x01    |          1 line          |
         * +-------------+--------------------------+
         * |     0x00    |       Normal drive       |
         * +-------------+--------------------------+
         */
        unsigned short      NLINE       : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
        /**
         * These bits select the booster clock frequency for the LCD voltage booster.
         * .BSTC[1:0]
         *  These bits select the booster clock frequency for the LCD voltage booster.
         * +-------------+------------------------------+
         * |  BSTC[1:0]  | Booster clock frequency [Hz] |
         * +-------------+------------------------------+
         * |     0x3     |          fCLK_LCD8B/64       |
         * +-------------+------------------------------+
         * |     0x2     |          fCLK_LCD8B/32       |
         * +-------------+------------------------------+
         * |     0x1     |          fCLK_LCD8B/16       |
         * +-------------+------------------------------+
         * |     0x0     |          fCLK_LCD8B/4        |
         * +-------------+------------------------------+
         */
        unsigned short      BSTC        : 2;
        unsigned short      reserved_2  : 6;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} LCD8TIM2_REG;

#if defined(C17_MCUSEL_W15)
/// LCD8B Power Control Register
typedef union LCD8PWR_REG_TAG {
    unsigned short  reg;
    struct LCD8PWR_REG_BIT_TAG {
        /**
         * This bit turns the LCD voltage regulator on and off.
         * .VCEN
         *  This bit turns the LCD voltage regulator on and off.
         *    1 (R/W): LCD voltage regulator on
         *    0 (R/W): LCD voltage regulator off
         */
        unsigned short      VCEN        : 1;
        /**
         * This bit sets the LCD voltage regulator output (reference voltage for boosting).
         * .VCSEL
         *  This bit sets the LCD voltage regulator output (reference voltage for boosting).
         *    1 (R/W): VC2
         *    0 (R/W): VC1
         */
        unsigned short      VCSEL       : 1;
        /**
         * This bit sets the LCD voltage regulator into heavy load protection mode.
         * .HVLD
         *  This bit sets the LCD voltage regulator into heavy load protection mode.
         *    1 (R/W): Heavy load protection mode
         *    0 (R/W): Normal mode
         */
        unsigned short      HVLD        : 1;
        /**
         * This bit selects the LCD drive bias.
         * .BISEL
         * This bit selects the LCD drive bias.
         *    1 (R/W): 1/4 bias
         *    0 (R/W): 1/3 bias
         */
        unsigned short      BISEL       : 1;
        /**
         * This bit turns the LCD voltage booster on and off.
         * .BSTEN
         * This bit turns the LCD voltage booster on and off.
         *    1 (R/W): LCD voltage booster on
         *    0 (R/W): LCD voltage booster off
         */
        unsigned short      BSTEN       : 1;
        unsigned short      reserved_1  : 3;    ///< Reserved.
        /**
         * These bits set the LCD panel contrast.
         * .LC[4:0]
         *  These bits set the LCD panel contrast.
         * +-------------+--------------+
         * |   LC[4:0]   |   Contrast   |
         * +-------------+--------------+
         * |     0x1f    |  High(dark)  |
         * +-------------+              +
         * |     0x1e    |              |
         * +-------------+              +
         * |     ...     |     ...      |
         * +-------------+              +
         * |     0x1     |              |
         * +-------------+              +
         * |     0x0     |  Low(light)  |
         * +-------------+--------------+
         */
        unsigned short      LC          : 5;
        unsigned short      reserved_2  : 3;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} LCD8PWR_REG;

#elif defined(C17_MCUSEL_W18)
/// LCD8B Power Control Register
typedef union LCD8PWR_REG_TAG {
    unsigned short  reg;
    struct LCD8PWR_REG_BIT_TAG {
        /**
         * This bit turns the LCD voltage regulator on and off.
         * .VCEN
         *  This bit turns the LCD voltage regulator on and off.
         *    1 (R/W): LCD voltage regulator on
         *    0 (R/W): LCD voltage regulator off
         */
        unsigned short      VCEN        : 1;
        /**
         * This bit sets the LCD voltage regulator output (reference voltage for boosting).
         * .VCSEL
         *  This bit sets the LCD voltage regulator output (reference voltage for boosting).
         *    1 (R/W): VC2
         *    0 (R/W): VC1
         */
        unsigned short      VCSEL       : 1;
        /**
         * This bit sets the LCD voltage regulator into heavy load protection mode.
         * .HVLD
         *  This bit sets the LCD voltage regulator into heavy load protection mode.
         *    1 (R/W): Heavy load protection mode
         *    0 (R/W): Normal mode
         */
        unsigned short      HVLD        : 1;
        /**
         * This bit selects the LCD drive bias.
         * .BISEL
         * This bit selects the LCD drive bias.
         *    1 (R/W): 1/4 bias
         *    0 (R/W): 1/3 bias
         */
        unsigned short      BISEL       : 1;
        /**
         * This bit turns the LCD voltage booster on and off.
         * .BSTEN
         * This bit turns the LCD voltage booster on and off.
         *    1 (R/W): LCD voltage booster on
         *    0 (R/W): LCD voltage booster off
         */
        unsigned short      BSTEN       : 1;
        unsigned short      reserved_1  : 3;    ///< Reserved.
        /**
         * These bits set the LCD panel contrast.
         * .LC[4:0]
         *  These bits set the LCD panel contrast.
         * +-------------+--------------+
         * |   LC[4:0]   |   Contrast   |
         * +-------------+--------------+
         * |     0x1f    |  High(dark)  |
         * +-------------+              +
         * |     0x1e    |              |
         * +-------------+              +
         * |     ...     |     ...      |
         * +-------------+              +
         * |     0x1     |              |
         * +-------------+              +
         * |     0x0     |  Low(light)  |
         * +-------------+--------------+
         */
        unsigned short      LC          : 5;
        unsigned short      reserved_2  : 2;    ///< Reserved.
        /**
         * This bit selects the LCD drive power supply mode
         * .EXVCSEL
         *  This bit selects the LCD drive power supply mode (external voltage application mode or internal generation mode).
         *    1 (R/W): External voltage application mode
         *    0 (R/W): Internal generation mode
         */
        unsigned short      EXVCSEL     : 1;
    } bit;
    unsigned char   byte_reg[2];
} LCD8PWR_REG;

#else
/// LCD8B Power Control Register
typedef union LCD8PWR_REG_TAG {
    unsigned short  reg;
    struct LCD8PWR_REG_BIT_TAG {
        /**
         * This bit turns the LCD voltage regulator on and off.
         * .VCEN
         *  This bit turns the LCD voltage regulator on and off.
         *    1 (R/W): LCD voltage regulator on
         *    0 (R/W): LCD voltage regulator off
         */
        unsigned short      VCEN        : 1;
        /**
         * This bit sets the LCD voltage regulator output (reference voltage for boosting).
         * .VCSEL
         *  This bit sets the LCD voltage regulator output (reference voltage for boosting).
         *    1 (R/W): VC2
         *    0 (R/W): VC1
         */
        unsigned short      VCSEL       : 1;
        /**
         * This bit sets the LCD voltage regulator into heavy load protection mode.
         * .HVLD
         *  This bit sets the LCD voltage regulator into heavy load protection mode.
         *    1 (R/W): Heavy load protection mode
         *    0 (R/W): Normal mode
         */
        unsigned short      HVLD        : 1;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * This bit turns the LCD voltage booster on and off.
         * .BSTEN
         * This bit turns the LCD voltage booster on and off.
         *    1 (R/W): LCD voltage booster on
         *    0 (R/W): LCD voltage booster off
         */
        unsigned short      BSTEN       : 1;
        unsigned short      reserved_2  : 3;    ///< Reserved.
        /**
         * These bits set the LCD panel contrast.
         * .LC[3:0]
         *  These bits set the LCD panel contrast.
         * +-------------+--------------+
         * |   LC[3:0]   |   Contrast   |
         * +-------------+--------------+
         * |     0xf     |  High(dark)  |
         * +-------------+              +
         * |     0xe     |              |
         * +-------------+              +
         * |     ...     |     ...      |
         * +-------------+              +
         * |     0x1     |              |
         * +-------------+              +
         * |     0x0     |  Low(light)  |
         * +-------------+--------------+
         */
        unsigned short      LC          : 4;
        unsigned short      reserved_3  : 4;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} LCD8PWR_REG;
#endif

/// LCD8B Display Control Register
typedef union LCD8DSP_REG_TAG {
    unsigned short  reg;
    struct LCD8DSP_REG_BIT_TAG {
        /**
         * These bits control the LCD display on/off and select a display mode
         * .DSPC[1:0]
         *  These bits control the LCD display on/off and select a display mode
         * +-------------+------------------------+
         * | DSPC[1:0]   | LCD display            |
         * +-------------+------------------------+
         * |     0x3     | All off (static drive) |
         * +-------------+------------------------+
         * |     0x2     | All on                 |
         * +-------------+------------------------+
         * |     0x1     | Normal display         |
         * +-------------+------------------------+
         * |     0x0     | Display off            |
         * +-------------+------------------------+
         */
        unsigned short      DSPC        : 2;
        /**
         * This bit switches the display area in the display data RAM.
         * .DSPAR
         *  This bit switches the display area in the display data RAM.
         *    1 (R/W): Display area 1
         *    0 (R/W): Display area 0
         */
        unsigned short      DSPAR       : 1;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * This bit controls black/white inversion on the LCD display.
         * .DSPREV
         *  This bit controls black/white inversion on the LCD display.
         *    1 (R/W): Normal display
         *    0 (R/W): Inverted display
         */
        unsigned short      DSPREV      : 1;
        /**
         * This bit selects the common pin assignment direction.
         * .COMREV
         *  This bit selects the common pin assignment direction.
         *    1 (R/W): Normal assignment
         *    0 (R/W): Inverse assignment
         */
        unsigned short      COMREV      : 1;
        /**
         * This bit selects the segment pin assignment direction.
         * .SEGREV
         *  This bit selects the segment pin assignment direction.
         *    1 (R/W): Normal assignment
         *    0 (R/W): Inverse assignment
         */
        unsigned short      SEGREV      : 1;
        unsigned short      reserved_2  : 9;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} LCD8DSP_REG;

/// LCD8B COM Pin Control Register 0
typedef union LCD8COMC0_REG_TAG {
    unsigned short  reg;
    struct LCD8COMC0_REG_BIT_TAG {
        /**
         * These bits configure the partial drive of the COM0 pins.
         * .COM0DEN
         *  These bits configure the partial drive of the COM0 pins.
         *    1 (R/W): Normal output
         *    0 (R/W): Off waveform output
         */
        unsigned short      COM0DEN     : 1;
        /**
         * These bits configure the partial drive of the COM1 pins.
         * .COM1DEN
         *  These bits configure the partial drive of the COM1 pins.
         *    1 (R/W): Normal output
         *    0 (R/W): Off waveform output
         */
        unsigned short      COM1DEN     : 1;
        /**
         * These bits configure the partial drive of the COM2 pins.
         * .COM2DEN
         *  These bits configure the partial drive of the COM2 pins.
         *    1 (R/W): Normal output
         *    0 (R/W): Off waveform output
         */
        unsigned short      COM2DEN     : 1;
        /**
         * These bits configure the partial drive of the COM3 pins.
         * .COM3DEN
         *  These bits configure the partial drive of the COM3 pins.
         *    1 (R/W): Normal output
         *    0 (R/W): Off waveform output
         */
        unsigned short      COM3DEN     : 1;
        /**
         * These bits configure the partial drive of the COM4 pins.
         * .COM4DEN
         *  These bits configure the partial drive of the COM4 pins.
         *    1 (R/W): Normal output
         *    0 (R/W): Off waveform output
         */
        unsigned short      COM4DEN     : 1;
        /**
         * These bits configure the partial drive of the COM5 pins.
         * .COM5DEN
         *  These bits configure the partial drive of the COM5 pins.
         *    1 (R/W): Normal output
         *    0 (R/W): Off waveform output
         */
        unsigned short      COM5DEN     : 1;
        /**
         * These bits configure the partial drive of the COM6 pins.
         * .COM6DEN
         *  These bits configure the partial drive of the COM6 pins.
         *    1 (R/W): Normal output
         *    0 (R/W): Off waveform output
         */
        unsigned short      COM6DEN     : 1;
        /**
         * These bits configure the partial drive of the COM7 pins.
         * .COM7DEN
         *  These bits configure the partial drive of the COM7 pins.
         *    1 (R/W): Normal output
         *    0 (R/W): Off waveform output
         */
        unsigned short      COM7DEN     : 1;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} LCD8COMC0_REG;

/// LCD8B Interrupt Flag Register
typedef union LCD8INTF_REG_TAG {
    unsigned short  reg;
    struct LCD8INTF_REG_BIT_TAG {
        /**
         * This bit indicates the frame interrupt cause occurrence status.
         * .FRMIF
         *  This bit indicates the frame interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      FRMIF       : 1;
        unsigned short      reserved_1  :15;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} LCD8INTF_REG;

/// LCD8B Interrupt Enable Register
typedef union LCD8INTE_REG_TAG {
    unsigned short  reg;
    struct LCD8INTE_REG_BIT_TAG {
        /**
         * This bit enables the frame interrupt.
         * .FRMIE
         *  This bit enables the frame interrupt.
         *    1 (R/W): Enable interrupt
         *    0 (R/W): Disable interrupt
         */
        unsigned short      FRMIE       : 1;
        unsigned short      reserved_1  :15;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} LCD8INTE_REG;

#ifdef __cplusplus
}
#endif

#endif // LCD8B_REG_H__
