/************************************************************************//**
 *
 * @file    boot.c
 *
 * @brief   This is vector and interrupt program with C.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 09 Jan. 2018    1.10
 *              - Delete intNmi.
 *          - 01 Nov. 2018    1.20
 *              - Change source code.
 *
 ******************************************************************************/
#include <libstdio.h>
#include <c17_mcu_select.h>
#include <c17_misc.h>
#include "c17_init_config.h"


/* --- definition --- */

/* -----------------------------------------------------------------------------
 *  When simulated I/O is used, the following are made effective.
 *  Please confirm "GNU17 GDB commands" and "GNU17 linker script setting"
 *  that exists in the property of the project.
 * -------------------------------------------------------------------------- */
//#define SIM_IO_USED


/* --- function declaration --- */

void boot(void);

static void clearBss(void);
static void loadLmaToVmaData(void);
#ifdef SIM_IO_USED
static void loadLmaToVmaSimIO(void);
#endif // SIM_IO_USED
static void end(void);

// Non Maskable Interrupt Handler
void intAddrErr(void)				__attribute__ ((interrupt_handler));
void intReserved(void)				__attribute__ ((interrupt_handler));

/* --- external declaration --- */

extern int main(void);

#ifdef C17_PE_SVD
extern void c17intSvd(void)			__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_PORT
extern void c17intPortInput(void)	__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_PWG2
extern void c17intPwg2(void)		__attribute__ ((interrupt_handler));
#endif
extern void c17intClg(void)			__attribute__ ((interrupt_handler));
#ifdef C17_PE_RTCA
extern void c17intRtca(void)		__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_T16
extern void c17intT16Ch0(void)		__attribute__ ((interrupt_handler));
#endif
#if defined(C17_PE_UART_MASTER) || defined(C17_PE_UART_SLAVE)
extern void c17intUartCh0(void)		__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_T16
extern void c17intT16Ch1(void)		__attribute__ ((interrupt_handler));
#endif
#if defined(C17_PE_I2C_MASTER) || defined(C17_PE_I2C_SLAVE)
extern void c17intI2c(void)			__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_T16B
extern void c17intT16bCh0(void)		__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_SNDA
extern void c17intSnda(void)		__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_REMC
extern void c17intRemc(void)		__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_LCD8B
extern void c17intLcd8b(void)		__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_RFC
extern void c17intRfcCh0(void)		__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_RFC
extern void c17intRfcCh1(void)		__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_T16
extern void c17intT16Ch2(void)		__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_T16
extern void c17intT16Ch3(void)		__attribute__ ((interrupt_handler));
#endif
#ifdef C17_PE_ADC
extern void c17intAd12(void)		__attribute__ ((interrupt_handler));
#endif

extern unsigned long __START_bss;
extern unsigned long __END_bss;
extern unsigned long __START_data;
extern unsigned long __START_data_lma;
extern unsigned long __END_data;
extern unsigned long __START_simio;
extern unsigned long __START_simio_lma;
extern unsigned long __END_simio;

extern void emu_copro_process(void);

/* special definitions for vector table  */
typedef void func(void);
#ifdef __POINTER16
#define VECTOR(vec)  (vec),0
#else
#define VECTOR(vec)  (vec)
#endif

/** vector table */
func *const vector[] = {			// No	Base+	Name

	/* ----- Non-Maskable Interrupts ----- */
	VECTOR(boot),					// 0	00		Reset
	VECTOR(intAddrErr),				// 1	04		Address misaligned
	VECTOR(intReserved),			// 2	08		NMI
	VECTOR(emu_copro_process),		// 3	0C		Co-processor emulation

	/* ----- Maskable Interrupts ----- */
#ifdef C17_PE_SVD
	VECTOR(c17intSvd),				// 4	10		SVD interrupt
#else
	VECTOR(intReserved),			// 4	10		SVD interrupt
#endif
#ifdef C17_PE_PORT
	VECTOR(c17intPortInput),		// 5	14		PORT interrupt
#else
	VECTOR(intReserved),			// 5	14		PORT interrupt
#endif
#ifdef C17_PE_PWG2
	VECTOR(c17intPwg2),				// 6	18		PWG2 interrupt
#else
	VECTOR(intReserved),			// 6	18		PWG2 interrupt
#endif
	VECTOR(c17intClg),				// 7	1C		CLG interrupt
#ifdef C17_PE_RTCA
	VECTOR(c17intRtca),				// 8	20		RTCA interrupt
#else
	VECTOR(intReserved),			// 8	20		RTCA interrupt
#endif
#ifdef C17_PE_T16
	VECTOR(c17intT16Ch0),			// 9	24		T16 ch.0 interrupt
#else
	VECTOR(intReserved),			// 9	24		T16 ch.0 interrupt
#endif
#if defined(C17_PE_UART_MASTER) || defined(C17_PE_UART_SLAVE)
	VECTOR(c17intUartCh0),			// 10	28		UART ch.0 interrupt
#else
	VECTOR(intReserved),			// 10	28		UART ch.0 interrupt
#endif
#ifdef C17_PE_T16
	VECTOR(c17intT16Ch1),			// 11	2C		T16 ch.1 interrupt
#else
	VECTOR(intReserved),			// 11	2C		T16 ch.1 interrupt
#endif
	VECTOR(intReserved),			// 12	30		SPIA ch.0 interrupt
#if defined(C17_PE_I2C_MASTER) || defined(C17_PE_I2C_SLAVE)
	VECTOR(c17intI2c),				// 13	34		I2C ch.0 interrupt
#else
	VECTOR(intReserved),			// 13	34		I2C ch.0 interrupt
#endif
#ifdef C17_PE_T16B
	VECTOR(c17intT16bCh0),			// 14	38		T16B ch.0 interrupt
#else
	VECTOR(intReserved),			// 14	38		T16B ch.0 interrupt
#endif
	VECTOR(intReserved),			// 15	3C		T16B ch.1 interrupt
	VECTOR(intReserved),			// 16	40		UART ch.1 interrupt
#ifdef C17_PE_SNDA
	VECTOR(c17intSnda),				// 17	44		SNDA interrupt
#else
	VECTOR(intReserved),			// 17	44		SNDA interrupt
#endif
#ifdef C17_PE_REMC
	VECTOR(c17intRemc),				// 18	48		REMC2 interrupt
#else
	VECTOR(intReserved),			// 18	48		REMC2 interrupt
#endif
#ifdef C17_PE_LCD8B
	VECTOR(c17intLcd8b),			// 19	4C		LCD4A interrupt
#else
	VECTOR(intReserved),			// 19	4C		LCD4A interrupt
#endif
#ifdef C17_PE_RFC
	VECTOR(c17intRfcCh0),			// 20	50		RFC ch.0 interrupt
#else
	VECTOR(intReserved),			// 20	50		RFC ch.0 interrupt
#endif
#ifdef C17_PE_RFC
	VECTOR(c17intRfcCh1),			// 21	54		RFC ch.1 interrupt
#else
	VECTOR(intReserved),			// 21	54		RFC ch.1 interrupt
#endif
#ifdef C17_PE_T16
	VECTOR(c17intT16Ch2),			// 22	58		T16 ch.2 interrupt
#else
	VECTOR(intReserved),			// 22	58		T16 ch.2 interrupt
#endif
	VECTOR(intReserved),			// 23	5C		SPIA ch.1 interrupt
#ifdef C17_PE_T16
	VECTOR(c17intT16Ch3),			// 24	60		T16 ch.3 interrupt
#else
	VECTOR(intReserved),			// 24	60		T16 ch.3 interrupt
#endif
#ifdef C17_PE_ADC
	VECTOR(c17intAd12),				// 25	64		ADC12A interrupt
#else
	VECTOR(intReserved),			// 25	64		ADC12A interrupt
#endif
	VECTOR(intReserved),			// 26	68		T16B ch.2 interrupt
	VECTOR(intReserved),			// 27	6C		reserved
	VECTOR(intReserved),			// 28	70		reserved
	VECTOR(intReserved),			// 29	74		reserved
	VECTOR(intReserved),			// 30	78		reserved
	VECTOR(intReserved),			// 31	7C		reserved
};

/************************************************************************//**
 * boot function.
 *
 * @brief   First, it resets the Stack Pointer, clear the bss area,
 *          and copy LMA to VMA.
 *          Next, it calls "main" function and calls "end" function.
 ***************************************************************************/
void boot(void)
{
	/// Set stack pointer.
	asm("xld.a	%sp, __START_stack");

	/// Initialize section.
	clearBss();						/// - Clear the bss area.
	loadLmaToVmaData();				/// - Copy LMA data to VMA data(".data" section).
#ifdef SIM_IO_USED
	loadLmaToVmaSimIO();			/// - Copy LMA data to VMA data(".simio" section).
#endif // SIM_IO_USED

	/// Initialize library.
    _init_sys();					/// - Initialize for sys.c.
    _init_lib();					/// - Initialize for lib.c.

	c17setFlashcAccessCycle(0x1);	/// Set RDWAIT = 2cycle (4.2MHz max)

	asm ("ei");						/// Interrupt enable.

	main();			 				/// Call main.

	end(); 							/// Call end.
}


/* ----- static ----- */

/************************************************************************//**
 * clearBss function.
 *
 * @brief   Clear ".bss" Section.
 ***************************************************************************/
static void clearBss(void)
{
	unsigned char	*addr;
	unsigned long	size;
	unsigned long	i;

	addr	= (unsigned char *)&__START_bss;
	size	= (unsigned long)&__END_bss - (unsigned long)&__START_bss;

	/// Clear ".bss" section.
	for(i = 0 ; i < size ; i++){
		*addr++ = 0x00;
	}

	return;
}


/************************************************************************//**
 * loadLmaToVma function.
 *
 * @brief   This function copys LMA data to VMA data(".data" section).
 ***************************************************************************/
static void loadLmaToVmaData(void)
{
	unsigned char		*src;
	unsigned char		*dst;
	unsigned long		size;
	unsigned long		i;

	/// Load ".data" section.
	src		= (unsigned char *)&__START_data_lma;
	dst		= (unsigned char *)&__START_data;
	size	= (unsigned long)&__END_data - (unsigned long)&__START_data;

	for(i = 0 ; i < size ; i++){
		*dst++ = *src++;
	}

}


#ifdef SIM_IO_USED
/************************************************************************//**
 * loadLmaToVmaSimIO function.
 *
 * @brief   This function copys LMA data to VMA data(".simio" section).
 *          When simulated I/O is used, it calls it.
 ***************************************************************************/
static void loadLmaToVmaSimIO(void)
{
	unsigned char		*src;
	unsigned char		*dst;
	unsigned long		size;
	unsigned long		i;

	/// Load ".simio" section.
	src		= (unsigned char *)&__START_simio_lma;
	dst		= (unsigned char *)&__START_simio;
	size	= (unsigned long)&__END_simio - (unsigned long)&__START_simio;

	for(i = 0 ; i < size ; i++){
		*dst++ = *src++;
	}

}
#endif // SIM_IO_USED


/************************************************************************//**
 * end function.
 *
 * @brief   This function has only infinite loop.
 ***************************************************************************/
static void end(void)
{
	/// Infinite loop.
	while (1){
		;
	}
}


/* ----- Non Maskable Interrupt Handler ----- */

/************************************************************************//**
 * intAddrErr function.
 *
 * @brief   Interrupt handler for "Address misaligned".
 ***************************************************************************/
void intAddrErr(void)
{
	/// Infinite loop.
	while (1){
		;
	}
}


/************************************************************************//**
 * intReserved function.
 *
 * @brief   Interrupt handler for "Reserved".
 ***************************************************************************/
void intReserved(void)
{
	/// Infinite loop.
	while (1){
		;
	}
}

