/************************************************************************//**
 *
 * @file    c17_clg.c
 *
 * @brief   This is CLG(osc) driver program file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Oct. 2017    1.10
 *              - Change source code.
 *          - 01 Nov. 2018    1.20
 *              - Change source code.
 *
 ***************************************************************************/
#include <stdlib.h>
#include "crt0.h"
#include "c17_misc.h"
#include "c17_clg.h"
#include "c17_init_config.h"

/* --- interrupt handler (GNU17v3 Only) --- */
#ifdef CRT0_LINKED
#if defined(C17_MCUSEL_M01)
C17_INTERRUPT_HANDLER(_vector06_handler, c17intClg);	// CLG interrupt
#else
C17_INTERRUPT_HANDLER(_vector07_handler, c17intClg);	// CLG interrupt
#endif
#endif /* CRT0_LINKED */


/* --- global variable --- */
// Interrupt counter.
/**
 * @todo c17clgOsc3Intflag =  OSC3 Interruption flag.
 */
volatile unsigned short c17clgOsc3Intflag		= 0;	///< OSC3 Interruption flag.

/**
 * @todo c17clgIOscIntflag =  IOSC Interruption flag.
 */
volatile unsigned short c17clgIOscIntflag		= 0;	///< IOSC Interruption flag.

/**
 * @todo c17clgOsc1Intflag =  OSC1 Interruption flag.
 */
volatile unsigned short c17clgOsc1Intflag		= 0;	///< OSC1 Interruption flag.

#ifdef CLG_OSC3_ENABLE
#if defined(C17_MCUSEL_589)
#else
/************************************************************************//**
 * @brief   Start OSC3 (Internal oscillator).
 *
 * @param   clgFreq            frequency
 *  @li @c  C17_CLG_OSC3_4MHZ  4MHz
 *  @li @c  C17_CLG_OSC3_8MHZ  8MHz
 *  @li @c  C17_CLG_OSC3_12MHZ 12MHz
 *  @li @c  C17_CLG_OSC3_16MHZ 16MHz
 *
 * @retval  none
 ***************************************************************************/
void c17startClgIntOSC3(unsigned short clgFreq)
{
	CLGINTE_REG clginte_set;
	CLGOSC3_REG	clgosc3_set;
	CLGOSC_REG	clgosc_set;
	CLGINTF_REG	clgintf_set;

	/// It doesn't do at all when having already started.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
	}

	if(clgosc_set.bit.OSC3EN == 1) {
		return;
	}

	/* CLG Interrupt Flag Register. Interrupt Flag Register read & clear */
	{
		clgintf_set.reg = 0x0;
		clgintf_set.bit.OSC3STAIF = 1;
		CLGINTF = clgintf_set.reg;
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.reg = CLGINTE;
		clginte_set.bit.OSC3STAIE = 1;		/// Enable interrupt.(Please make the following effective when you use interrupt.)
		CLGINTE = clginte_set.reg;
	}

	/// Initialize the interrupt.
	ILVCLG	= INTERRUPT_LEVEL_CLG;			/// - Set interrupt level.

	/// Disable write-protect.
	c17protectMiscOff();

#if defined(C17_MCUSEL_M40)
	/* CLGOSC3:CLG OSC3 Control Register. */
	{
		/**
		 * @todo Change OSC3WT
		 */
		clgosc3_set.bit.OSC3WT = 1;			/// Set the oscillation stabilization waiting time(1 = 4096 clocks).
		CLGOSC3 = clgosc3_set.reg;
	}
#elif defined(C17_MCUSEL_F63)
	/* CLGOSC3:CLG OSC3 Control Register. */
	{
		/**
		 * @todo Change OSC3WT
		 */
		clgosc3_set.bit.OSC3FQ = clgFreq;	/// OSC3(Internal oscillator) frequency.
		clgosc3_set.bit.OSC3WT = 0;			/// Set the oscillation stabilization waiting time(0 = 4 clocks).
		CLGOSC3 = clgosc3_set.reg;
	}
#else
	/* CLGOSC3:CLG OSC3 Control Register. */
	{
		/**
		 * @todo Change OSC3MD,OSC3WT,OSC3INV
		 */
		clgosc3_set.bit.OSC3FQ = clgFreq;	/// OSC3(Internal oscillator) frequency.
		clgosc3_set.bit.OSC3MD = 0;			/// Internal oscillator.
		clgosc3_set.bit.OSC3INV = 3;		/// Set the oscillation inverter gain of the OSC3 oscillator circuit.
		clgosc3_set.bit.OSC3WT = 0;			/// Set the oscillation stabilization waiting time(0 = 4 clocks).
		CLGOSC3 = clgosc3_set.reg;
	}
#endif

	/// Enable write-protect.
	c17protectMiscOn();

	c17clgOsc3Intflag = 0;
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.OSC3EN = 1;			/// Start oscillation.
		CLGOSC = clgosc_set.reg;
	}

	/**
	 * Wait OSC3STAIF Interrupt for the oscillation stabilization.
	 * @todo Add time-out processing as needed.
	 */
	while (c17clgOsc3Intflag == 0) {
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.bit.OSC3STAIE = 0;		/// Disable interrupt.
		CLGINTE = clginte_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_M40) || \
	defined(C17_MCUSEL_F63)
#else
/************************************************************************//**
 * @brief   Start OSC3 (external oscillator).
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17startClgExtOSC3(void)
{
	CLGINTE_REG clginte_set;
	CLGOSC3_REG	clgosc3_set;
	CLGOSC_REG	clgosc_set;
	CLGINTF_REG	clgintf_set;

	PDMODSEL_REG	pdmodsel_set;
	PDFNCSEL_REG	pdfncsel_set;

	/// It doesn't do at all when having already started.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
	}

	if(clgosc_set.bit.OSC3EN == 1) {
		return;
	}

	/* CLG Interrupt Flag Register. Interrupt Flag Register read & clear */
	{
		clgintf_set.reg = 0x0;
		clgintf_set.bit.OSC3STAIF = 1;
		CLGINTF = clgintf_set.reg;
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.reg = CLGINTE;
		clginte_set.bit.OSC3STAIE = 1;		/// Enable interrupt.(Please make the following effective when you use interrupt.)
		CLGINTE = clginte_set.reg;
	}

	/// Initialize the interrupt.
	ILVCLG	= INTERRUPT_LEVEL_CLG;			/// - Set interrupt level.

	/// Disable write-protect.
	c17protectMiscOff();

#if defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34)
	/* CLGOSC3:CLG OSC3 Control Register. */
	{
		/**
		 * @todo Change OSC3MD,OSC3WT,OSC3INV
		 */
		clgosc3_set.bit.OSC3FQ = 1;			/// OSC3(Internal oscillator) frequency.
		clgosc3_set.bit.OSC3MD = 1;			/// Crystal/ceramic oscillator.
		clgosc3_set.bit.OSC3INV = 3;		/// Set the oscillation inverter gain of the OSC3 oscillator circuit.
		clgosc3_set.bit.OSC3WT = 4;			/// Set the oscillation stabilization waiting time(4 = 1024 clocks).
		CLGOSC3 = clgosc3_set.reg;
	}
#elif defined(C17_MCUSEL_589)
	/* CLGOSC3:CLG OSC3 Control Register. */
	{
		/**
		 * @todo Change OSC3WT,OSC3INV
		 */
		clgosc3_set.bit.OSC3INV = 3;		/// Set the oscillation inverter gain of the OSC3 oscillator circuit.
		clgosc3_set.bit.OSC3WT = 4;			/// Set the oscillation stabilization waiting time(4 = 1024 clocks).
		CLGOSC3 = clgosc3_set.reg;
	}
#else
	/* CLGOSC3:CLG OSC3 Control Register. */
	{
		/**
		 * @todo Change OSC3MD,OSC3WT,OSC3INV
		 */
		clgosc3_set.bit.OSC3FQ = 1;			/// OSC3(Internal oscillator) frequency.
		clgosc3_set.bit.OSC3MD = 2;			/// Crystal/ceramic oscillator.
		clgosc3_set.bit.OSC3INV = 3;		/// Set the oscillation inverter gain of the OSC3 oscillator circuit.
		clgosc3_set.bit.OSC3WT = 4;			/// Set the oscillation stabilization waiting time(4 = 1024 clocks).
		CLGOSC3 = clgosc3_set.reg;
	}
#endif

	/// Enable write-protect.
	c17protectMiscOn();

	/**
	 * Set Universal Port Multiplexer (UPMUX).
	 * PD4 = OSC3
	 * PD3 = OSC4
	 */
	/* PDMODSEL: PD Port Mode Select Register */
	{
		/// PD Port Mode Select Register
		pdmodsel_set.reg = PDMODSEL;
		pdmodsel_set.bit.PD4SEL = 1;		/// - PD4 : Enable peripheral I/O function.
		pdmodsel_set.bit.PD3SEL = 1;		/// - PD3 : Enable peripheral I/O function.
		PDMODSEL = pdmodsel_set.reg;

	}
	/* PDFNCSEL: PD Port Function Select Register */
	{
		pdfncsel_set.reg = PDFNCSEL;
		pdfncsel_set.bit.PD4MUX = 2;		/// - PD4 : UPMUX.
		pdfncsel_set.bit.PD3MUX = 2;		/// - PD3 : UPMUX.
		PDFNCSEL = pdfncsel_set.reg;
	}

	c17clgOsc3Intflag = 0;
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.OSC3EN = 1;			/// Start oscillation.
		CLGOSC = clgosc_set.reg;
	}

	/**
	 * Wait OSC3STAIF Interrupt for the oscillation stabilization.
	 * @todo Add time-out processing as needed.
	 */
	while (c17clgOsc3Intflag == 0) {
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.bit.OSC3STAIE = 0;		/// Disable interrupt.
		CLGINTE = clginte_set.reg;
	}
}
#endif


/************************************************************************//**
 * @brief   Stop OSC3.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17stopClgOSC3(void)
{
	CLGINTE_REG clginte_set;
	CLGOSC_REG	clgosc_set;
	CLGINTF_REG	clgintf_set;

	/// Stop OSC3.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.OSC3EN = 0;			/// Stop oscillation.
		CLGOSC = clgosc_set.reg;
	}

	/// Disable interrupt.(Please make the following effective when you use interrupt.)
	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.reg = CLGINTE;
		clginte_set.bit.OSC3STAIE = 0;		/// Disable interrupt.
		CLGINTE = clginte_set.reg;
	}
	/// Clear interrupt flag(CLGINTF.OSC3STAIF).
	/* CLG Interrupt Flag Register. Interrupt Flag Register read & clear */
	{
		clgintf_set.reg = 0x0;
		clgintf_set.bit.OSC3STAIF = 1;
		CLGINTF = clgintf_set.reg;
	}
}
#endif


#ifdef CLG_IOSC_ENABLE
#if defined(C17_MCUSEL_589)
/************************************************************************//**
 * @brief   Start IOSC.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17startClgIOSC(unsigned short clgFreq)
{
	CLGOSC_REG	clgosc_set;
	CLGIOSC_REG	clgiosc_set;
	CLGINTF_REG	clgintf_set;
	CLGINTE_REG clginte_set;

	/// It doesn't do at all when having already started.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
	}

	if(clgosc_set.bit.IOSCEN == 1) {
		return;
	}

	/// Clear interrupt flag(CLGINTF.IOSCSTAIF).
	/* CLG Interrupt Flag Register. Interrupt Flag Register read & clear */
	{
		clgintf_set.reg = 0x0;
		clgintf_set.bit.IOSCSTAIF = 1;
		CLGINTF = clgintf_set.reg;
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.reg = CLGINTE;
		clginte_set.bit.IOSCSTAIE = 1;		/// Enable interrupt.(Please make the following effective when you use interrupt.)
		CLGINTE = clginte_set.reg;
	}

	/// Initialize the interrupt.
	ILVCLG	= INTERRUPT_LEVEL_CLG;			/// - Set interrupt level.

	/// Disable write-protect.
	c17protectMiscOff();

	/* CLGIOSC:CLG IOSC Control Register. */
	{
		clgiosc_set.bit.IOSCFQ = clgFreq;	/// IOSC frequency.
		CLGIOSC = clgiosc_set.reg;
	}

	/// Enable write-protect.
	c17protectMiscOn();

	c17clgIOscIntflag = 0;
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.IOSCEN = 1;			/// Start oscillation.
		CLGOSC = clgosc_set.reg;
	}

	/**
	 * Wait IOSCSTAIF Interrupt  for the oscillation stabilization.
	 * @todo Add time-out processing as needed.
	 */
	while (c17clgIOscIntflag == 0) {
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.bit.IOSCSTAIE = 0;		/// Disable interrupt.
		CLGINTE = clginte_set.reg;
	}
}
#else
/************************************************************************//**
 * @brief   Start IOSC.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17startClgIOSC(void)
{
	CLGINTE_REG clginte_set;
	CLGOSC_REG	clgosc_set;
	CLGINTF_REG	clgintf_set;

	/// It doesn't do at all when having already started.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
	}

	if(clgosc_set.bit.IOSCEN == 1) {
		return;
	}

	/// Clear interrupt flag(CLGINTF.IOSCSTAIF).
	/* CLG Interrupt Flag Register. Interrupt Flag Register read & clear */
	{
		clgintf_set.reg = 0x0;
		clgintf_set.bit.IOSCSTAIF = 1;
		CLGINTF = clgintf_set.reg;
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.reg = CLGINTE;
		clginte_set.bit.IOSCSTAIE = 1;		/// Enable interrupt.(Please make the following effective when you use interrupt.)
		CLGINTE = clginte_set.reg;
	}

	/// Initialize the interrupt.
	ILVCLG	= INTERRUPT_LEVEL_CLG;			/// - Set interrupt level.

	c17clgIOscIntflag = 0;
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.IOSCEN = 1;			/// Start oscillation.
		CLGOSC = clgosc_set.reg;
	}

	/**
	 * Wait IOSCSTAIF Interrupt  for the oscillation stabilization.
	 * @todo Add time-out processing as needed.
	 */
	while (c17clgIOscIntflag == 0) {
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.bit.IOSCSTAIE = 0;		/// Disable interrupt.
		CLGINTE = clginte_set.reg;
	}
}
#endif


/************************************************************************//**
 * @brief   Stop IOSC.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17stopClgIOSC(void)
{
	CLGINTE_REG clginte_set;
	CLGOSC_REG	clgosc_set;
	CLGINTF_REG	clgintf_set;

	/// Stop IOSC.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.IOSCEN = 0;			/// Stop oscillation.
		CLGOSC = clgosc_set.reg;
	}

	/// Disable interrupt.(Please make the following effective when you use interrupt.)
	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.reg = CLGINTE;
		clginte_set.bit.IOSCSTAIE = 0;		/// Disable interrupt.
		CLGINTE = clginte_set.reg;
	}

	/// Clear interrupt flag(CLGINTF.IOSCSTAIF).
	/* CLG Interrupt Flag Register. Interrupt Flag Register read & clear */
	{
		clgintf_set.reg = 0x0;
		clgintf_set.bit.IOSCSTAIF = 1;
		CLGINTF = clgintf_set.reg;
	}
}
#endif


#ifdef CLG_OSC1_ENABLE
/************************************************************************//**
 * @brief   Start OSC1.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17startClgOSC1(void)
{
	CLGOSC_REG	clgosc_set;
	CLGOSC1_REG	clgosc1_set;
	CLGINTE_REG clginte_set;
	CLGINTF_REG	clgintf_set;

	/// It doesn't do at all when having already started.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
	}

	if(clgosc_set.bit.OSC1EN == 1) {
		return;
	}

	/// Clear interrupt flag(CLGINTF.OSC1STAIF).
	/* CLG Interrupt Flag Register. Interrupt Flag Register read & clear */
	{
		clgintf_set.reg = 0x0;
		clgintf_set.bit.OSC1STAIF = 1;
		CLGINTF = clgintf_set.reg;
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.reg = CLGINTE;
		clginte_set.bit.OSC1STAIE = 1;		/// Enable interrupt.(Please make the following effective when you use interrupt.)
		CLGINTE = clginte_set.reg;
	}

	/// Initialize the interrupt.
	ILVCLG	= INTERRUPT_LEVEL_CLG;			/// - Set interrupt level.

	/// Disable write-protect.
	c17protectMiscOff();

#if defined(C17_MCUSEL_M01) || defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23)
	/* CLGOSC1:CLG OSC1 Control Register. */
	{
		/**
		 * @todo Change OSDRB,OSDEN,OSC1BUP,CGI1,INV1B,INV1N,OSC1WT
		 */
		clgosc1_set.bit.OSDRB = 0;			/// Set the OSC1 oscillator circuit restart function.(disable)
		clgosc1_set.bit.OSDEN = 0;			/// Set the controls the oscillation stop detector.(off)
		clgosc1_set.bit.OSC1BUP = 0;		/// Set the oscillation startup control circuit(disable).
		clgosc1_set.bit.CGI1 = 0;			/// Set the internal gate capacitance.
		clgosc1_set.bit.INV1B = 3;			/// Set the oscillation inverter gain that will be applied at boost startup.
		clgosc1_set.bit.INV1N = 1;			/// Set the oscillation inverter gain applied at normal operation.
		clgosc1_set.bit.OSC1WT = 1;			/// Set the oscillation stabilization waiting time(1 = 4096 clocks).
		CLGOSC1 = clgosc1_set.reg;
	}
#endif
#if defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04) || \
	defined(C17_MCUSEL_W15) || \
	defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18) || \
	defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36) || \
	defined(C17_MCUSEL_589)
	/* CLGOSC1:CLG OSC1 Control Register. */
	{
		/**
		 * @todo Change OSDRB,OSDEN,OSC1BUP,CGI1,INV1B,INV1N,OSC1WT
		 */
		clgosc1_set.bit.OSDRB = 1;			/// Set the OSC1 oscillator circuit restart function.(enable)
		clgosc1_set.bit.OSDEN = 0;			/// Set the controls the oscillation stop detector.(off)
		clgosc1_set.bit.OSC1BUP = 1;		/// Set the oscillation startup control circuit(enable).
		clgosc1_set.bit.CGI1 = 0;			/// Set the internal gate capacitance.
		clgosc1_set.bit.INV1B = 2;			/// Set the oscillation inverter gain that will be applied at boost startup.
		clgosc1_set.bit.INV1N = 1;			/// Set the oscillation inverter gain applied at normal operation.
		clgosc1_set.bit.OSC1WT = 1;			/// Set the oscillation stabilization waiting time(1 = 4096 clocks).
		CLGOSC1 = clgosc1_set.reg;
	}
#endif
#if defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_M10) || \
	defined(C17_MCUSEL_M40) || \
	defined(C17_MCUSEL_F63)
	/* CLGOSC1:CLG OSC1 Control Register. */
	{
		/**
		 * @todo Change OSDRB,OSDEN,OSC1BUP,OSC1SELCR,CGI1,INV1B,INV1N,OSC1WT
		 */
		clgosc1_set.bit.OSDRB = 1;			/// Set the OSC1 oscillator circuit restart function.(enable)
		clgosc1_set.bit.OSDEN = 0;			/// Set the controls the oscillation stop detector.(off)
		clgosc1_set.bit.OSC1BUP = 1;		/// Set the oscillation startup control circuit(enable).
		clgosc1_set.bit.OSC1SELCR = 0;		/// Select oscillator type(Crystal oscillator.).
		clgosc1_set.bit.CGI1 = 0;			/// Set the internal gate capacitance.
		clgosc1_set.bit.INV1B = 2;			/// Set the oscillation inverter gain that will be applied at boost startup.
		clgosc1_set.bit.INV1N = 1;			/// Set the oscillation inverter gain applied at normal operation.
		clgosc1_set.bit.OSC1WT = 1;			/// Set the oscillation stabilization waiting time(1 = 4096 clocks).
		CLGOSC1 = clgosc1_set.reg;
	}
#endif
#if defined(C17_MCUSEL_W12) || \
	defined(C17_MCUSEL_M31)
	/* CLGOSC1:CLG OSC1 Control Register. */
	{
		/**
		 * @todo Change OSDRB,OSDEN,OSC1BUP,OSC1SELCR,CGI1,INV1B,INV1N,OSC1WT
		 */
		clgosc1_set.bit.OSDRB = 1;			/// Set the OSC1 oscillator circuit restart function.(enable)
		clgosc1_set.bit.OSDEN = 0;			/// Set the controls the oscillation stop detector.(off)
		clgosc1_set.bit.OSC1BUP = 1;		/// Set the oscillation startup control circuit(enable).
		clgosc1_set.bit.OSC1SELCR = 1;		/// Select oscillator type(Internal oscillator.).
		clgosc1_set.bit.CGI1 = 0;			/// Set the internal gate capacitance.
		clgosc1_set.bit.INV1B = 2;			/// Set the oscillation inverter gain that will be applied at boost startup.
		clgosc1_set.bit.INV1N = 1;			/// Set the oscillation inverter gain applied at normal operation.
		clgosc1_set.bit.OSC1WT = 1;			/// Set the oscillation stabilization waiting time(1 = 4096 clocks).
		CLGOSC1 = clgosc1_set.reg;
	}
#endif

	/// Enable write-protect.
	c17protectMiscOn();

	c17clgOsc1Intflag = 0;
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.OSC1EN = 1;			/// Start oscillation.
		CLGOSC = clgosc_set.reg;
	}

	/**
	 * Wait OSC1STAIF Interrupt  for the oscillation stabilization.
	 * @todo Add time-out processing as needed.
	 */
	while (c17clgOsc1Intflag == 0) {
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.bit.OSC1STAIE = 0;		/// Disable interrupt.
		CLGINTE = clginte_set.reg;
	}
}


/************************************************************************//**
 * @brief   Stop OSC1.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17stopClgOSC1(void)
{
	CLGINTE_REG clginte_set;
	CLGOSC_REG	clgosc_set;
	CLGINTF_REG	clgintf_set;

	/// Stop IOSC.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.OSC1EN = 0;			/// Stop oscillation.
		CLGOSC = clgosc_set.reg;
	}

	/// Disable interrupt.(Please make the following effective when you use interrupt.)
	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.reg = CLGINTE;
		clginte_set.bit.OSC1STAIE = 0;		/// Disable interrupt.
		CLGINTE = clginte_set.reg;
	}

	/// Clear interrupt flag(CLGINTF.IOSCSTAIF).
	/* CLG Interrupt Flag Register. Interrupt Flag Register read & clear */
	{
		clgintf_set.reg = 0x0;
		clgintf_set.bit.OSC1STPIF = 1;
		CLGINTF = clgintf_set.reg;
	}
}


#if defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13) || \
	defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_M10) || \
	defined(C17_MCUSEL_M40) || \
	defined(C17_MCUSEL_F63)
/************************************************************************//**
 * @brief   select oscillator type of the OSC1.
 *
 * @param    oscillator type
 *
 * @retval  none
 ***************************************************************************/
void c17selOscTypOSC1(unsigned short selOSC1)
{
	CLGOSC_REG	clgosc_set;
	CLGOSC1_REG	clgosc1_set;
	CLGINTE_REG clginte_set;
	CLGINTF_REG	clgintf_set;

	/// Stop OSC1.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.OSC1EN = 0;			/// Stop oscillation.
		CLGOSC = clgosc_set.reg;
	}

	/// Clear interrupt flag(CLGINTF.OSC1STAIF).
	/* CLG Interrupt Flag Register. Interrupt Flag Register read & clear */
	{
		clgintf_set.reg = 0x0;
		clgintf_set.bit.OSC1STAIF = 1;
		CLGINTF = clgintf_set.reg;
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.reg = CLGINTE;
		clginte_set.bit.OSC1STAIE = 1;		/// Enable interrupt.(Please make the following effective when you use interrupt.)
		CLGINTE = clginte_set.reg;
	}

	/// Initialize the interrupt.
	ILVCLG	= INTERRUPT_LEVEL_CLG;			/// - Set interrupt level.

	/// Disable write-protect.
	c17protectMiscOff();

	/// Select oscillator type of the OSC1.
	/* CLGOSC1:CLG OSC1 Control Register. */
	{
		clgosc1_set.reg = CLGOSC1;
		clgosc1_set.bit.OSC1SELCR = selOSC1;		/// select oscillator type.
		CLGOSC1 = clgosc1_set.reg;
	}

	/// Enable write-protect.
	c17protectMiscOn();

	c17clgOsc1Intflag = 0;
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.OSC1EN = 1;			/// Start oscillation.
		CLGOSC = clgosc_set.reg;
	}

	/**
	 * Wait OSC1STAIF Interrupt  for the oscillation stabilization.
	 * @todo Add time-out processing as needed.
	 */
	while (c17clgOsc1Intflag == 0) {
	}

	/* CLGINTE:CLG Interrupt Enable Register. */
	{
		clginte_set.bit.OSC1STAIE = 0;		/// Disable interrupt.
		CLGINTE = clginte_set.reg;
	}

}
#endif
#endif


#ifdef CLG_OSC3_ENABLE
/************************************************************************//**
 * @brief   The system clock set in OSC3.
 *
 * @param   none
 *
 * @retval  EXIT_SUCCESS        Success.
 * @retval  EXIT_FAILURE        Failed.
 ***************************************************************************/
int c17switchClgSystemClockOSC3(void)
{
	CLGOSC_REG	clgosc_set;
	CLGSCLK_REG	clgsclk_set ;

	/// When OSC3 doesn't start, nothing is done.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
	}

	if(clgosc_set.bit.OSC3EN == 0) {
		return EXIT_FAILURE;
	}

	/// Disable write-protect.
	c17protectMiscOff();

	/// Select the system clock source.
	/* CLGSCLK:CLG System Clock Control Register. */
	{
		/**
		 * @todo Change Enable the SYSCLK switching function at wake-up.
		 */
		clgsclk_set.bit.WUPMD = 1;			/// Enable the SYSCLK switching function at wake-up.
		clgsclk_set.bit.WUPDIV = 0;			/// wake-up clock division =1/1
		clgsclk_set.bit.WUPSRC = 0;			/// wake-up clock source =IOSC

		/**
		 * @todo Change CLKDIV
		 */
		clgsclk_set.bit.CLKDIV = 0;			/// Set division ratio of the clock source(1/1).
		clgsclk_set.bit.CLKSRC = 2;			/// Set system clock source(OSC3).
		CLGSCLK = clgsclk_set.reg;
	}

	/// Enable write-protect.
	c17protectMiscOn();

	return EXIT_SUCCESS;
}
#endif


#ifdef CLG_IOSC_ENABLE
/************************************************************************//**
 * @brief   The system clock set in IOSC.
 *
 * @param   none
 *
 * @retval  EXIT_SUCCESS        Success.
 * @retval  EXIT_FAILURE        Failed.
 ***************************************************************************/
int c17switchClgSystemClockIOSC(void)
{
	CLGOSC_REG	clgosc_set;
	CLGSCLK_REG	clgsclk_set;

	/// When IOSC doesn't start, nothing is done.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
	}

	if(clgosc_set.bit.IOSCEN == 0) {
		return EXIT_FAILURE;
	}

	/// Disable write-protect.
	c17protectMiscOff();

	/// Select the system clock source.
	/* CLGSCLK:CLG System Clock Control Register. */
	{
		/**
		 * @todo Change Enable the SYSCLK switching function at wake-up.
		 */
		clgsclk_set.bit.WUPMD = 0;			/// Disable the SYSCLK switching function at wake-up.
		clgsclk_set.bit.WUPDIV = 0;
		clgsclk_set.bit.WUPSRC = 0;
		/**
		 * @todo Change CLKDIV
		 */
		clgsclk_set.bit.CLKDIV = 0;			/// Set division ratio of the clock source(1/1).
		clgsclk_set.bit.CLKSRC = 0;			/// Set system clock source(IOSC).
		CLGSCLK = clgsclk_set.reg;
	}

	/// Enable write-protect.
	c17protectMiscOn();

	return EXIT_SUCCESS;
}
#endif


#ifdef CLG_OSC1_ENABLE
#if defined(C17_MCUSEL_M40)
#else
/************************************************************************//**
 * @brief	The auto-trimming function adjusts the IOSCCLK/OSC3CLK clock frequency by
 * 			trimming the clock with reference to the high precision OSC1CLK
 * 			clock generated by the OSC1 oscillator circuit.
 *
 * @param   none
 *
 * @retval  EXIT_SUCCESS        Success.
 * @retval  EXIT_FAILURE        Failed.
 ***************************************************************************/
int c17ClgAutoTrimming(void)
{
#if defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_M10)
	CLGOSC3_REG	clgosc3_set;
#else
	CLGIOSC_REG	clgiosc_set;
#endif
	CLGINTF_REG	clgintf_set;

	/// start OSC1.
	c17startClgOSC1();
	/// The system clock set to OSC1.
	if (c17switchClgSystemClockOSC1() == EXIT_FAILURE) {
		return EXIT_FAILURE;
	}

#if defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_M10)
	// stop and start OSC3.
	c17stopClgOSC3();
	c17startClgIntOSC3(C17_CLG_OSC3_16MHZ);

	/// Clear interrupt flag(CLGINTF.OSC3TEDIF).
	{
		clgintf_set.reg = CLGINTF;
		clgintf_set.bit.OSC3TEDIF = 1;
		CLGINTF = clgintf_set.reg;
	}
#elif defined(C17_MCUSEL_589)
	// stop and start IOSC.
	c17stopClgIOSC();
	c17startClgIOSC(C17_CLG_IOSC_8MHZ);

	/// Clear interrupt flag(CLGINTF.IOSCTEDIF).
	{
		clgintf_set.reg = CLGINTF;
		clgintf_set.bit.IOSCTEDIF = 1;
		CLGINTF = clgintf_set.reg;
	}
#else
	// stop and start IOSC.
	c17stopClgIOSC();
	c17startClgIOSC();

	/// Clear interrupt flag(CLGINTF.IOSCTEDIF).
	{
		clgintf_set.reg = CLGINTF;
		clgintf_set.bit.IOSCTEDIF = 1;
		CLGINTF = clgintf_set.reg;
	}
#endif

	/// Disable write-protect.
	c17protectMiscOff();

#if defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_M10)
	/// Enable IOSC oscillation auto-trimming.
	/* CLGIOSC: CLG IOSC Control Register.*/
	{
		clgosc3_set.bit.OSC3STM = 1;
		CLGOSC3 = clgosc3_set.reg;
	}
#else
	/// Enable IOSC oscillation auto-trimming.
	/* CLGIOSC: CLG IOSC Control Register.*/
	{
		clgiosc_set.bit.IOSCSTM = 1;
		CLGIOSC = clgiosc_set.reg;
	}
#endif

	/// Enable write-protect.
	c17protectMiscOn();

#if defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25) || \
	defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34) || \
	defined(C17_MCUSEL_M10)
	/// Wait OSC3 oscillation auto-trimming.
	{
		clgintf_set.reg = CLGINTF;
	}
	while (clgintf_set.bit.OSC3TEDIF == 0) {
		asm("nop");
		/**
		 * Wait OSC3TEDIF Interrupt  for the oscillation stabilization.
		 * @todo Add time-out processing as needed.
		 */
		{
			clgintf_set.reg = CLGINTF;
		}
	}

	/// The system clock set to IOSC.
	return c17switchClgSystemClockOSC3();

#else
	/// Wait IOSC oscillation auto-trimming.
	{
		clgintf_set.reg = CLGINTF;
	}
	while (clgintf_set.bit.IOSCTEDIF == 0) {
		asm("nop");
		/**
		 * Wait IOSCTEDIF Interrupt  for the oscillation stabilization.
		 * @todo Add time-out processing as needed.
		 */
		{
			clgintf_set.reg = CLGINTF;
		}
	}

	/// The system clock set to IOSC.
	return c17switchClgSystemClockIOSC();

#endif
}
#endif


/************************************************************************//**
 * @brief   The system clock set in OSC1.
 *
 * @param   none
 *
 * @retval  EXIT_SUCCESS        Success.
 * @retval  EXIT_FAILURE        Failed.
 ***************************************************************************/
int c17switchClgSystemClockOSC1(void)
{
	CLGOSC_REG	clgosc_set;
	CLGSCLK_REG	clgsclk_set ;

	/// When OSC1 doesn't start, nothing is done.
	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
	}

	if(clgosc_set.bit.OSC1EN == 0) {
		return EXIT_FAILURE;
	}

	/// Disable write-protect.
	c17protectMiscOff();

	/// Select the system clock source.
	/* CLGSCLK:CLG System Clock Control Register. */
	{
		/**
		 * @todo Change Enable the SYSCLK switching function at wake-up.
		 */
		clgsclk_set.bit.WUPMD = 1;			/// Enable the SYSCLK switching function at wake-up.
		clgsclk_set.bit.WUPDIV = 0;			/// wake-up clock division =1/1
		clgsclk_set.bit.WUPSRC = 0;			/// wake-up clock source =IOSC

		/**
		 * @todo Change CLKDIV
		 */
		clgsclk_set.bit.CLKDIV = 0;			/// Set division ratio of the clock source(1/1).
		clgsclk_set.bit.CLKSRC = 1;			/// Set system clock source(OSC1).
		CLGSCLK = clgsclk_set.reg;
	}

	/// Enable write-protect.
	c17protectMiscOn();

	return EXIT_SUCCESS;
}
#endif


/************************************************************************//**
 * @brief   CLG interrupt function.(Register in the vector table.)
 *
 *          1, It checks interruption.
 *
 *          2, interruption flag is cleared.
 *
 *          3, Increment the interrupt counter.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intClg(void)
{
	/* CLG Interrupt Flag Register. Interrupt Flag Register read & clear */
	CLGINTF_REG	clgintf_set;
	{
		clgintf_set.reg = CLGINTF;
		CLGINTF = clgintf_set.reg;
	}

	/// Check interrupt cause occurrence status.
	if (clgintf_set.bit.IOSCSTAIF == 1) {
	   /**
		* @todo add interrupt function of IOSC oscillation stabilization waiting completion
		*/
		c17clgIOscIntflag = 1;
	}
#ifdef CLG_OSC3_ENABLE
	/// Check interrupt cause occurrence status.
	if (clgintf_set.bit.OSC3STAIF == 1) {
	   /**
		* @todo add interrupt function of OSC3 oscillation stabilization waiting completion
		*/
		c17clgOsc3Intflag = 1;
	}
#endif
#ifdef CLG_OSC1_ENABLE
	/// Check interrupt cause occurrence status.
	if (clgintf_set.bit.OSC1STAIF == 1) {
	   /**
		* @todo add interrupt function of OSC1 oscillation stabilization waiting completion
		*/
		c17clgOsc1Intflag = 1;
	}
#endif
}


#ifdef CLG_OSC3_ENABLE
/************************************************************************//**
 * @brief   Set To OSC3SLPC.
 *
 * @param   clgSlpc
 *  @li @c      0          Continue operation state before SLEEP
 *  @li @c      1          Stop clock source in SLEEP mode
 *
 * @retval  none
 ***************************************************************************/
void c17setOsc3OpeInSleep(unsigned short clgSlpc)
{
	CLGOSC_REG	clgosc_set;

	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.OSC3SLPC = clgSlpc;
		CLGOSC = clgosc_set.reg;
	}
}
#endif


#ifdef CLG_IOSC_ENABLE
/************************************************************************//**
 * @brief   Set To IOSCSLPC.
 *
 * @param   clgSlpc
 *  @li @c      0          Continue operation state before SLEEP
 *  @li @c      1          Stop clock source in SLEEP mode
 *
 * @retval  none
 ***************************************************************************/
void c17setIoscOpeInSleep(unsigned short clgSlpc)
{
	CLGOSC_REG	clgosc_set;

	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.IOSCSLPC = clgSlpc;
		CLGOSC = clgosc_set.reg;
	}
}
#endif


#ifdef CLG_OSC1_ENABLE
/************************************************************************//**
 * @brief   Set To OSC1SLPC.
 *
 * @param   clgSlpc
 *  @li @c      0          Continue operation state before SLEEP
 *  @li @c      1          Stop clock source in SLEEP mode
 *
 * @retval  none
 ***************************************************************************/
void c17setOsc1OpeInSleep(unsigned short clgSlpc)
{
	CLGOSC_REG	clgosc_set;

	/* CLGOSC:CLG Oscillation Control Register. */
	{
		clgosc_set.reg = CLGOSC;
		clgosc_set.bit.OSC1SLPC = clgSlpc;
		CLGOSC = clgosc_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_M01)
/************************************************************************//**
 * @brief   Enable Fout.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P3MODSEL_REG	p3modsel_set;
	P3FNCSEL_REG	p3fncsel_set;

	/**
	 * P32 = FOUT
	 *
	 */
	/* P3MODSEL: P3 Port Mode Select Register */
	{
		p3modsel_set.reg = P3MODSEL;
		p3modsel_set.bit.P32SEL = 1;
		P3MODSEL = p3modsel_set.reg;
	}
	/* P3FNCSEL: P3 Port Function Select Register */
	{
		p3fncsel_set.reg = P3FNCSEL;
		p3fncsel_set.bit.P32MUX = 0;
		P3FNCSEL = p3fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P3MODSEL_REG	p3modsel_set;
	P3FNCSEL_REG	p3fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P32 = PORT
	 *
	 */
	/* P3MODSEL: P3 Port Mode Select Register */
	{
		p3modsel_set.reg = P3MODSEL;
		p3modsel_set.bit.P32SEL = 0;
		P3MODSEL = p3modsel_set.reg;
	}
	/* P3FNCSEL: P3 Port Function Select Register */
	{
		p3fncsel_set.reg = P3FNCSEL;
		p3fncsel_set.bit.P32MUX = 0;
		P3FNCSEL = p3fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_W22) || defined(C17_MCUSEL_W23)
/************************************************************************//**
 * @brief   Enable Fout.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/**
	 * P15 = FOUT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P15SEL = 1;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P15MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P15 = PORT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P15SEL = 0;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P15MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_M12) || defined(C17_MCUSEL_M13)
/************************************************************************//**
 * @brief   Enable Fout.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/**
	 * P16 = FOUT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P16SEL = 1;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P16MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P16 = PORT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P16SEL = 0;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P16MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_M30) || defined(C17_MCUSEL_M31) || defined(C17_MCUSEL_M32) || defined(C17_MCUSEL_M33) || defined(C17_MCUSEL_M34)
/************************************************************************//**
 * @brief   Enable Fout.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/**
	 * P10 = FOUT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P10SEL = 1;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P10MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P10 = PORT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P10SEL = 0;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P10MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_W34) || defined(C17_MCUSEL_W35) || defined(C17_MCUSEL_W36)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT0_REG	clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/**
	 * P12 = FOUT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P12SEL = 1;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P12MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
	/* CLGFOUT0: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT0 = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT0_REG	clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/* CLGFOUT0: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT0;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT0 = clgfout_set.reg;
	}

	/**
	 * P12 = PORT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P12SEL = 0;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P12MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_W03) || defined(C17_MCUSEL_W04)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P0MODSEL_REG	p0modsel_set;
	P0FNCSEL_REG	p0fncsel_set;

	/**
	 * P06 = FOUT
	 *
	 */
	/* P0MODSEL: P0 Port Mode Select Register */
	{
		p0modsel_set.reg = P0MODSEL;
		p0modsel_set.bit.P06SEL = 1;
		P0MODSEL = p0modsel_set.reg;
	}
	/* P0FNCSEL: P0 Port Function Select Register */
	{
		p0fncsel_set.reg = P0FNCSEL;
		p0fncsel_set.bit.P06MUX = 0;
		P0FNCSEL = p0fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P0MODSEL_REG	p0modsel_set;
	P0FNCSEL_REG	p0fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P06 = PORT
	 *
	 */
	/* P0MODSEL: P0 Port Mode Select Register */
	{
		p0modsel_set.reg = P0MODSEL;
		p0modsel_set.bit.P06SEL = 0;
		P0MODSEL = p0modsel_set.reg;
	}
	/* P0FNCSEL: P0 Port Function Select Register */
	{
		p0fncsel_set.reg = P0FNCSEL;
		p0fncsel_set.bit.P06MUX = 0;
		P0FNCSEL = p0fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_W12) || defined(C17_MCUSEL_W13)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/**
	 * P10 = FOUT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P10SEL = 1;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P10MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P10 = PORT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P10SEL = 0;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P10MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P3MODSEL_REG	p3modsel_set;
	P3FNCSEL_REG	p3fncsel_set;

	/**
	 * P34 = FOUT
	 *
	 */
	/* P3MODSEL: P3 Port Mode Select Register */
	{
		p3modsel_set.reg = P3MODSEL;
		p3modsel_set.bit.P34SEL = 1;
		P3MODSEL = p3modsel_set.reg;
	}
	/* P3FNCSEL: P3 Port Function Select Register */
	{
		p3fncsel_set.reg = P3FNCSEL;
		p3fncsel_set.bit.P34MUX = 0;
		P3FNCSEL = p3fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P3MODSEL_REG	p3modsel_set;
	P3FNCSEL_REG	p3fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P34 = PORT
	 *
	 */
	/* P3MODSEL: P3 Port Mode Select Register */
	{
		p3modsel_set.reg = P3MODSEL;
		p3modsel_set.bit.P34SEL = 0;
		P3MODSEL = p3modsel_set.reg;
	}
	/* P3FNCSEL: P3 Port Function Select Register */
	{
		p3fncsel_set.reg = P3FNCSEL;
		p3fncsel_set.bit.P34MUX = 0;
		P3FNCSEL = p3fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_W15)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/**
	 * P16 = FOUT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P16SEL = 1;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P16MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P16 = PORT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P16SEL = 0;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P16MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_W18)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/**
	 * P16 = FOUT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P16SEL = 1;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P16MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P16 = PORT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P16SEL = 0;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P16MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_M20) || defined(C17_MCUSEL_M21) || defined(C17_MCUSEL_M22) || defined(C17_MCUSEL_M23) || defined(C17_MCUSEL_M24) || defined(C17_MCUSEL_M25)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/**
	 * P13 = FOUT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P13SEL = 1;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P13MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P1MODSEL_REG	p1modsel_set;
	P1FNCSEL_REG	p1fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P13 = PORT
	 *
	 */
	/* P1MODSEL: P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		p1modsel_set.bit.P13SEL = 0;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P1FNCSEL: P1 Port Function Select Register */
	{
		p1fncsel_set.reg = P1FNCSEL;
		p1fncsel_set.bit.P13MUX = 0;
		P1FNCSEL = p1fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_589)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P3MODSEL_REG	p3modsel_set;
	P3FNCSEL_REG	p3fncsel_set;

	/**
	 * P35 = FOUT
	 *
	 */
	/* P3MODSEL: P3 Port Mode Select Register */
	{
		p3modsel_set.reg = P3MODSEL;
		p3modsel_set.bit.P35SEL = 1;
		P3MODSEL = p3modsel_set.reg;
	}
	/* P3FNCSEL: P3 Port Function Select Register */
	{
		p3fncsel_set.reg = P3FNCSEL;
		p3fncsel_set.bit.P35MUX = 0;
		P3FNCSEL = p3fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P3MODSEL_REG	p3modsel_set;
	P3FNCSEL_REG	p3fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P35 = PORT
	 *
	 */
	/* P3MODSEL: P3 Port Mode Select Register */
	{
		p3modsel_set.reg = P3MODSEL;
		p3modsel_set.bit.P35SEL = 0;
		P3MODSEL = p3modsel_set.reg;
	}
	/* P3FNCSEL: P3 Port Function Select Register */
	{
		p3fncsel_set.reg = P3FNCSEL;
		p3fncsel_set.bit.P35MUX = 0;
		P3FNCSEL = p3fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_M10)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P0MODSEL_REG	p0modsel_set;
	P0FNCSEL_REG	p0fncsel_set;

	/**
	 * P04 = FOUT
	 *
	 */
	/* P0MODSEL: P0 Port Mode Select Register */
	{
		p0modsel_set.reg = P0MODSEL;
		p0modsel_set.bit.P04SEL = 1;
		P0MODSEL = p0modsel_set.reg;
	}
	/* P0FNCSEL: P0 Port Function Select Register */
	{
		p0fncsel_set.reg = P0FNCSEL;
		p0fncsel_set.bit.P04MUX = 0;
		P0FNCSEL = p0fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUT0DIV = clgClkDiv;
		clgfout_set.bit.FOUT0SRC = clgClkSrc;
		clgfout_set.bit.FOUT0EN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout0.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P0MODSEL_REG	p0modsel_set;
	P0FNCSEL_REG	p0fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUT0EN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P04 = PORT
	 *
	 */
	/* P0MODSEL: P0 Port Mode Select Register */
	{
		p0modsel_set.reg = P0MODSEL;
		p0modsel_set.bit.P04SEL = 0;
		P0MODSEL = p0modsel_set.reg;
	}
	/* P0FNCSEL: P0 Port Function Select Register */
	{
		p0fncsel_set.reg = P0FNCSEL;
		p0fncsel_set.bit.P04MUX = 0;
		P0FNCSEL = p0fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_M40)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT_REG		clgfout_set;
	P5MODSEL_REG	p5modsel_set;
	P5FNCSEL_REG	p5fncsel_set;

	/**
	 * P53 = FOUT
	 *
	 */
	/* P5MODSEL: P5 Port Mode Select Register */
	{
		p5modsel_set.reg = P5MODSEL;
		p5modsel_set.bit.P53SEL = 1;
		P5MODSEL = p5modsel_set.reg;
	}
	/* P5FNCSEL: P5 Port Function Select Register */
	{
		p5fncsel_set.reg = P5FNCSEL;
		p5fncsel_set.bit.P53MUX = 0;
		P5FNCSEL = p5fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT_REG		clgfout_set;
	P5MODSEL_REG	p5modsel_set;
	P5FNCSEL_REG	p5fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT = clgfout_set.reg;
	}

	/**
	 * P53 = PORT
	 *
	 */
	/* P5MODSEL: P5 Port Mode Select Register */
	{
		p5modsel_set.reg = P5MODSEL;
		p5modsel_set.bit.P53SEL = 0;
		P5MODSEL = p5modsel_set.reg;
	}
	/* P5FNCSEL: P5 Port Function Select Register */
	{
		p5fncsel_set.reg = P5FNCSEL;
		p5fncsel_set.bit.P53MUX = 0;
		P5FNCSEL = p5fncsel_set.reg;
	}
}
#endif


#if defined(C17_MCUSEL_F63)
/************************************************************************//**
 * @brief   Enable Fout0.
 *
 * @param   clgClkSrc
 *  @li @c  C17_FOUT_IOSC  FOUT clock source= IOSC
 *  @li @c  C17_FOUT_OSC1  FOUT clock source= OSC1
 *  @li @c  C17_FOUT_OSC3  FOUT clock source= OSC3
 *  @li @c  C17_FOUT_SYS   FOUT clock source= SYSTEM
 *
 * @param   clgClkDiv      FOUT Division
 *  @li @c  0 to 0x7
 *
 * @retval  none
 ***************************************************************************/
void c17enableFout(unsigned short clgClkSrc, unsigned short clgClkDiv)
{
	CLGFOUT0_REG	clgfout_set;
	P0MODSEL_REG	p0modsel_set;
	P0FNCSEL_REG	p0fncsel_set;

	/**
	 * P04 = FOUT
	 *
	 */
	/* P0MODSEL: P0 Port Mode Select Register */
	{
		p0modsel_set.reg = P0MODSEL;
		p0modsel_set.bit.P04SEL = 1;
		P0MODSEL = p0modsel_set.reg;
	}
	/* P0FNCSEL: P0 Port Function Select Register */
	{
		p0fncsel_set.reg = P0FNCSEL;
		p0fncsel_set.bit.P04MUX = 0;
		P0FNCSEL = p0fncsel_set.reg;
	}
	/* CLGFOUT: CLG FOUT Control Register0. */
	{
		clgfout_set.reg = 0;
		clgfout_set.bit.FOUTDIV = clgClkDiv;
		clgfout_set.bit.FOUTSRC = clgClkSrc;
		clgfout_set.bit.FOUTEN = 1;
		CLGFOUT0 = clgfout_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable Fout.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableFout(void)
{
	CLGFOUT0_REG	clgfout_set;
	P0MODSEL_REG	p0modsel_set;
	P0FNCSEL_REG	p0fncsel_set;

	/* CLGFOUT: CLG FOUT Control Register. */
	{
		clgfout_set.reg = CLGFOUT0;
		clgfout_set.bit.FOUTEN = 0;
		CLGFOUT0 = clgfout_set.reg;
	}

	/**
	 * P04 = PORT
	 *
	 */
	/* P0MODSEL: P0 Port Mode Select Register */
	{
		p0modsel_set.reg = P0MODSEL;
		p0modsel_set.bit.P04SEL = 0;
		P0MODSEL = p0modsel_set.reg;
	}
	/* P0FNCSEL: P0 Port Function Select Register */
	{
		p0fncsel_set.reg = P0FNCSEL;
		p0fncsel_set.bit.P04MUX = 0;
		P0FNCSEL = p0fncsel_set.reg;
	}
}
#endif

