/************************************************************************//**
 *
 * @file    c17_lcd8b.c
 *
 * @brief   This is LCD8B driver program file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Nov. 2018    1.10
 *              - Change source code.
 *
 ***************************************************************************/
#include "crt0.h"
#include "c17_misc.h"
#include "c17_lcd8b.h"
#include "c17_init_config.h"

#if defined(C17_PE_LCD8B)
/* --- interrupt handler (GNU17v3 Only) --- */
#ifdef CRT0_LINKED
C17_INTERRUPT_HANDLER(_vector19_handler, c17intLcd8b);		// LCD8B interrupt
#endif /* CRT0_LINKED */


/* --- function declaration --- */
static void initLcd8bSegRam(void);

/************************************************************************//**
 * @brief   This function initializes LCD8B driver.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17initLcd8b(void)
{
	/// Disable LCD8B.
	c17offLcd8bDisplay();

	/// LCD8B Setting
	if((LCD8B_INIT & 0x20) == 0x20)
	{
		/// Initialize LCD8B.
		c17setLcd8b((LCD8B_INIT & 0x18)>>3, (LCD8B_INIT & 0x0F));

		/// Initialize the interrupt.
		ILVLCD8B = INTERRUPT_LEVEL_LCD8B;				/// - Set interrupt level.
	}
}


/************************************************************************//**
 * @brief   Enable LCD8B interrupt .
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntLcd8b(void)
{
 	LCD8INTF_REG	lcd8intf_set;
 	LCD8INTE_REG	lcd8inte_set;

	/// Clear interrupt flags.
	/* LCDINTF:LCD8B Interrupt Flag Register. */
	{
		lcd8intf_set.bit.FRMIF = 1;
		LCD8INTF = lcd8intf_set.reg;
	}

	/// Disable LCD8B frame interrupts.
	/* LCD8INTE:LCD8B Interrupt Enable Register. */
	{
		lcd8inte_set.bit.FRMIE = 1;
		LCD8INTE = lcd8inte_set.reg;
	}
}


/************************************************************************//**
 * @brief   Disable LCD8B interrupt .
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntLcd8b(void)
{
 	LCD8INTF_REG	lcd8intf_set;
 	LCD8INTE_REG	lcd8inte_set;

	/// Clear interrupt flags.
	/* LCD8INTF:LCD8B Interrupt Flag Register. */
	{
		lcd8intf_set.bit.FRMIF = 1;
		LCD8INTF = lcd8intf_set.reg;
	}

	/// Disable LCD8B frame interrupts.
	/* LCD8INTE:LCD8B Interrupt Enable Register. */
	{
		lcd8inte_set.bit.FRMIE = 0;
		LCD8INTE = lcd8inte_set.reg;
	}
}


/************************************************************************//**
 * @brief   The display turn on.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17onLcd8bDisplay(void)
{
 	LCD8CTL_REG	lcd8ctl_set;
 	LCD8DSP_REG	lcd8dsp_set;

	/* LCD8CTL:LCD8B Control Register */
	{
		lcd8ctl_set.reg = LCD8CTL;
#if defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16) || \
	defined(C17_MCUSEL_W18)
		lcd8ctl_set.bit.LCDDIS = 1;			/// - SEG/COM-pin discharge enable
#endif
		lcd8ctl_set.bit.MODEN = 1;			/// - LCD8B enable
		LCD8CTL = lcd8ctl_set.reg;
	}

	/* LCD8DSP:LCD8B Display Control Register. */
	{
		lcd8dsp_set.reg = LCD8DSP;
		lcd8dsp_set.bit.DSPC = 1;			/// The LCD display state set to "normal display".
		LCD8DSP = lcd8dsp_set.reg;
	}
}


/************************************************************************//**
 * @brief   The display turn off.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17offLcd8bDisplay(void)
{
 	LCD8CTL_REG	lcd8ctl_set;
 	LCD8DSP_REG	lcd8dsp_set;

	/* LCD8DSP:LCD8B Display Control Register. */
	{
		lcd8dsp_set.reg = LCD8DSP;
		lcd8dsp_set.bit.DSPC = 0;			/// The LCD display state set to "display off".
		LCD8DSP = lcd8dsp_set.reg;
	}

	/* LCD8CTL:LCD8B Control Register */
	{
		lcd8ctl_set.reg = LCD8CTL;
		lcd8ctl_set.bit.MODEN = 0;			/// - LCD8B disable
		LCD8CTL = lcd8ctl_set.reg;
	}
}


/************************************************************************//**
 * @brief   This function changes LCD driver's state.
 *
 * @param   state
 *  @li @c  C17_LCD_STATE_ALL_OFF   Mode : All off.
 *  @li @c  C17_LCD_STATE_ALL_ON    Mode : All on.
 *  @li @c  C17_LCD_STATE_NORMAL    Mode : Normal display.
 *  @li @c  C17_LCD_STATE_OFF       Mode : Display off.
 *
 * @retval  none
 ***************************************************************************/
void c17setLcd8bDisplayState(unsigned char state)
{
 	LCD8DSP_REG	lcd8dsp_set;

	/* LCD8DSP:LCD8B Display Control Register. */
	{
		lcd8dsp_set.reg = LCD8DSP;
		lcd8dsp_set.bit.DSPC = state;		/// The LCD display state set.
		LCD8DSP = lcd8dsp_set.reg;
	}
}


/************************************************************************//**
 * @brief   This function gets LCD driver's state.
 *
 * @param   none
 *
 * @retval  C17_LCD_STATE_ALL_OFF   Mode : All off.
 * @retval  C17_LCD_STATE_ALL_ON    Mode : All on.
 * @retval  C17_LCD_STATE_NORMAL    Mode : Normal display.
 * @retval  C17_LCD_STATE_OFF       Mode : Display off.
 ***************************************************************************/
unsigned char c17getLcd8bDisplayState(void)
{
 	LCD8DSP_REG	lcd8dsp_set;

	/// LCD8B Display Control Register
 	lcd8dsp_set.reg = LCD8DSP;

	/// LCD display mode.
	return lcd8dsp_set.bit.DSPC;
}


/************************************************************************//**
 * @brief   This function changes LCD driver's display.
 *
 * @param   display
 *  @li @c  C17_LCD_DISPLAY_INVERTED    Inverted display.
 *  @li @c  C17_LCD_DISPLAY_NORMAL      Normal display.
 *
 * @retval  none
 ****************************************************************************/
void c17setLcd8bDisplayInverted(unsigned char display)
{
 	LCD8DSP_REG	lcd8dsp_set;

	/* LCD8DSP:LCD8B Display Control Register. */
	{
		lcd8dsp_set.reg = LCD8DSP;
		lcd8dsp_set.bit.DSPREV = display;		/// The LCD display black/white inversion set.
		LCD8DSP = lcd8dsp_set.reg;
	}
}


/************************************************************************//**
 * @brief   This function gets LCD driver's display.
 *
 * @param   none
 *
 * @retval  C17_LCD_DISPLAY_INVERTED    Inverted display.
 * @retval  C17_LCD_DISPLAY_NORMAL      Normal display.
 ***************************************************************************/
unsigned char c17getLcd8bDisplayInverted(void)
{
 	LCD8DSP_REG	lcd8dsp_set;

	/// LCD8B Display Control Register
 	lcd8dsp_set.reg = LCD8DSP;

	/// LCD display black/white inversion.
	return lcd8dsp_set.bit.DSPREV;
}


/************************************************************************//**
 * @brief   This function changes LCD driver's display area.
 *
 * @param   area
 *  @li @c  C17_LCD_DISPLAY_AREA0   display area 0.
 *  @li @c  C17_LCD_DISPLAY_AREA1   display area 1.
 *
 * @retval	none
 ***************************************************************************/
void c17setLcd8bDisplayArea(unsigned char area)
{
 	LCD8DSP_REG	lcd8dsp_set;

	/* LCD8DSP:LCD8B Display Control Register. */
	{
		lcd8dsp_set.reg = LCD8DSP;
		lcd8dsp_set.bit.DSPAR = area;		/// The LCD display area set.
		LCD8DSP = lcd8dsp_set.reg;
	}
}


/************************************************************************//**
 * @brief   This function gets LCD driver's display area.
 *
 * @param   none
 *
 * @retval  C17_LCD_DISPLAY_AREA0   display area 0.
 * @retval  C17_LCD_DISPLAY_AREA1   display area 1.
 ***************************************************************************/
unsigned char c17getLcd8bDisplayArea(void)
{
 	LCD8DSP_REG	lcd8dsp_set;

	/// LCD8B Display Control Register
 	lcd8dsp_set.reg = LCD8DSP;

	/// LCD display area.
	return lcd8dsp_set.bit.DSPAR;
}


/************************************************************************//**
 * @brief   This function set checker-board pattern(small) for display.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17setLcd8bCheckerboardPattern(void)
{
	unsigned short i;
	volatile unsigned char *segram = (unsigned char *)LCD8B_SEGRAM_TOP_ADDR;

	for (i = 0; i < LCD8B_SEGRAM_SIZE; i++) {
		if (i % 2 == 0) {
			segram[i] = 0x55;
		} else {
			segram[i] = 0xAA;
		}
	}
}


/************************************************************************//**
 * @brief   This function sets LCD8B.
 *
 * @param   lcdClkSrc      Clock Source.
 *  @li @c  C17_LCD_CLKSRC_IOSC
 *  @li @c  C17_LCD_CLKSRC_OSC1
 *  @li @c  C17_LCD_CLKSRC_OSC3
 *  @li @c  C17_LCD_CLKSRC_EXT
 * @param   lcdClkDiv      Clock Division
 *  @li @c  C17_LCD_CLKDIV_1
 *  @li @c  C17_LCD_CLKDIV_4
 *  @li @c  C17_LCD_CLKDIV_8
 *  @li @c  C17_LCD_CLKDIV_16
 *  @li @c  C17_LCD_CLKDIV_32
 *  @li @c  C17_LCD_CLKDIV_64
 *  @li @c  C17_LCD_CLKDIV_128
 *
 * @retval  none
 ***************************************************************************/
void c17setLcd8b(unsigned short lcdClkSrc, unsigned short lcdClkDiv)
{

#if defined(C17_MCUSEL_W15) || defined(C17_MCUSEL_W18)
	P2FNCSEL_REG	p2fncsel_set;
	P2MODSEL_REG	p2modsel_set;
#endif
#if defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16)
	P3FNCSEL_REG	p3fncsel_set;
	P3MODSEL_REG	p3modsel_set;

	P4FNCSEL_REG	p4fncsel_set;
	P4MODSEL_REG	p4modsel_set;
#endif
#if defined(C17_MCUSEL_W18)
	P6FNCSEL_REG	p6fncsel_set;
	P6MODSEL_REG	p6modsel_set;

	P7FNCSEL_REG	p7fncsel_set;
	P7MODSEL_REG	p7modsel_set;

	P8FNCSEL_REG	p8fncsel_set;
	P8MODSEL_REG	p8modsel_set;
#endif

	LCD8CLK_REG		lcd8clk_set;

 	LCD8TIM1_REG	lcd8tim1_set;
 	LCD8TIM2_REG	lcd8tim2_set;

 	LCD8PWR_REG		lcd8pwr_set;

 	LCD8DSP_REG		lcd8dsp_set;

 	LCD8COMC0_REG	lcd8comc0_set;

 	LCD8INTF_REG	lcd8intf_set;
 	LCD8INTE_REG	lcd8inte_set;

	/// Initialize LEDC ports.

#if defined(C17_MCUSEL_W15) || defined(C17_MCUSEL_W18)
	/// - LCD8B Driver W15 (SEG16 to SEG23)
	/* P2FNCSEL:P2 Port Function Select Register */
	{
		p2fncsel_set.bit.P27MUX = 3;		/// - P27 : UPMUX.
		p2fncsel_set.bit.P26MUX = 3;		/// - P26 : UPMUX.
		p2fncsel_set.bit.P25MUX = 3;		/// - P25 : UPMUX.
		p2fncsel_set.bit.P24MUX = 3;		/// - P24 : UPMUX.
		p2fncsel_set.bit.P23MUX = 3;		/// - P23 : UPMUX.
		p2fncsel_set.bit.P22MUX = 3;		/// - P22 : UPMUX.
		p2fncsel_set.bit.P21MUX = 3;		/// - P21 : UPMUX.
		p2fncsel_set.bit.P20MUX = 3;		/// - P20 : UPMUX.
		P2FNCSEL = p2fncsel_set.reg;
	}

	/* P2MODSEL:P2 Port Mode Select Register */
	{
		p2modsel_set.bit.P27SEL = 1;		/// - P27 : Enable peripheral I/O function.
		p2modsel_set.bit.P26SEL = 1;		/// - P26 : Enable peripheral I/O function.
		p2modsel_set.bit.P25SEL = 1;		/// - P25 : Enable peripheral I/O function.
		p2modsel_set.bit.P24SEL = 1;		/// - P24 : Enable peripheral I/O function.
		p2modsel_set.bit.P23SEL = 1;		/// - P23 : Enable peripheral I/O function.
		p2modsel_set.bit.P22SEL = 1;		/// - P22 : Enable peripheral I/O function.
		p2modsel_set.bit.P21SEL = 1;		/// - P21 : Enable peripheral I/O function.
		p2modsel_set.bit.P20SEL = 1;		/// - P20 : Enable peripheral I/O function.
		P2MODSEL = p2modsel_set.reg;
	}
#endif

#if defined(C17_MCUSEL_W14) || defined(C17_MCUSEL_W16)
	/// - LCD8B Driver W14 (SEG46 to SEG56)
	/// - LCD8B Driver W16 (SEG52 to SEG59)
	/* P3FNCSEL:P3 Port Function Select Register */
	{
		p3fncsel_set.bit.P37MUX = 3;		/// - P37 : UPMUX.
		p3fncsel_set.bit.P36MUX = 3;		/// - P36 : UPMUX.
		p3fncsel_set.bit.P35MUX = 3;		/// - P35 : UPMUX.
		p3fncsel_set.bit.P34MUX = 3;		/// - P34 : UPMUX.
		p3fncsel_set.bit.P33MUX = 3;		/// - P33 : UPMUX.
		p3fncsel_set.bit.P32MUX = 3;		/// - P32 : UPMUX.
		p3fncsel_set.bit.P31MUX = 3;		/// - P31 : UPMUX.
		p3fncsel_set.bit.P30MUX = 3;		/// - P30 : UPMUX.
		P3FNCSEL = p3fncsel_set.reg;
	}

	/* P3MODSEL:P3 Port Mode Select Register */
	{
		p3modsel_set.bit.P37SEL = 1;		/// - P37 : Enable peripheral I/O function.
		p3modsel_set.bit.P36SEL = 1;		/// - P36 : Enable peripheral I/O function.
		p3modsel_set.bit.P35SEL = 1;		/// - P35 : Enable peripheral I/O function.
		p3modsel_set.bit.P34SEL = 1;		/// - P34 : Enable peripheral I/O function.
		p3modsel_set.bit.P33SEL = 1;		/// - P33 : Enable peripheral I/O function.
		p3modsel_set.bit.P32SEL = 1;		/// - P32 : Enable peripheral I/O function.
		p3modsel_set.bit.P31SEL = 1;		/// - P31 : Enable peripheral I/O function.
		p3modsel_set.bit.P30SEL = 1;		/// - P30 : Enable peripheral I/O function.
		P3MODSEL = p3modsel_set.reg;
	}

	/// - LCD8B Driver W14 (SEG42 to SEG45)
	/// - LCD8B Driver W16 (SEG47 to SEG51)
	/* P4FNCSEL:P4 Port Function Select Register */
	{
#if defined(C17_MCUSEL_W16)
		p4fncsel_set.bit.P44MUX = 3;		/// - P44 : UPMUX.
#endif
		p4fncsel_set.bit.P43MUX = 3;		/// - P43 : UPMUX.
		p4fncsel_set.bit.P42MUX = 3;		/// - P42 : UPMUX.
		p4fncsel_set.bit.P41MUX = 3;		/// - P41 : UPMUX.
		p4fncsel_set.bit.P40MUX = 3;		/// - P40 : UPMUX.
		P4FNCSEL = p4fncsel_set.reg;
	}

	/* P4MODSEL:P4 Port Mode Select Register */
	{
#if defined(C17_MCUSEL_W16)
		p4modsel_set.bit.P44SEL = 1;		/// - P44 : Enable peripheral I/O function.
#endif
		p4modsel_set.bit.P43SEL = 1;		/// - P43 : Enable peripheral I/O function.
		p4modsel_set.bit.P42SEL = 1;		/// - P42 : Enable peripheral I/O function.
		p4modsel_set.bit.P41SEL = 1;		/// - P41 : Enable peripheral I/O function.
		p4modsel_set.bit.P40SEL = 1;		/// - P40 : Enable peripheral I/O function.
		P4MODSEL = p4modsel_set.reg;
	}
#endif

#if defined(C17_MCUSEL_W18)
	/// - LCD8B Driver W18 (SEG8 to SEG15)
	/* P6FNCSEL:P6 Port Function Select Register */
	{
		p6fncsel_set.bit.P67MUX = 3;		/// - P67 : UPMUX.
		p6fncsel_set.bit.P66MUX = 3;		/// - P66 : UPMUX.
		p6fncsel_set.bit.P65MUX = 3;		/// - P65 : UPMUX.
		p6fncsel_set.bit.P64MUX = 3;		/// - P64 : UPMUX.
		p6fncsel_set.bit.P63MUX = 3;		/// - P63 : UPMUX.
		p6fncsel_set.bit.P62MUX = 3;		/// - P62 : UPMUX.
		p6fncsel_set.bit.P61MUX = 3;		/// - P61 : UPMUX.
		p6fncsel_set.bit.P60MUX = 3;		/// - P60 : UPMUX.
		P6FNCSEL = p6fncsel_set.reg;
	}

	/* P6MODSEL:P6 Port Mode Select Register */
	{
		p6modsel_set.bit.P67SEL = 1;		/// - P67 : Enable peripheral I/O function.
		p6modsel_set.bit.P66SEL = 1;		/// - P66 : Enable peripheral I/O function.
		p6modsel_set.bit.P65SEL = 1;		/// - P65 : Enable peripheral I/O function.
		p6modsel_set.bit.P64SEL = 1;		/// - P64 : Enable peripheral I/O function.
		p6modsel_set.bit.P63SEL = 1;		/// - P63 : Enable peripheral I/O function.
		p6modsel_set.bit.P62SEL = 1;		/// - P62 : Enable peripheral I/O function.
		p6modsel_set.bit.P61SEL = 1;		/// - P61 : Enable peripheral I/O function.
		p6modsel_set.bit.P60SEL = 1;		/// - P60 : Enable peripheral I/O function.
		P6MODSEL = p6modsel_set.reg;
	}

	/// - LCD8B Driver W18 (SEG4 to SEG7)
	/* P7FNCSEL:P7 Port Function Select Register */
	{
		p7fncsel_set.bit.P73MUX = 3;		/// - P73 : UPMUX.
		p7fncsel_set.bit.P72MUX = 3;		/// - P72 : UPMUX.
		p7fncsel_set.bit.P71MUX = 3;		/// - P71 : UPMUX.
		p7fncsel_set.bit.P70MUX = 3;		/// - P70 : UPMUX.
		P7FNCSEL = p7fncsel_set.reg;
	}

	/* P7MODSEL:P7 Port Mode Select Register */
	{
		p7modsel_set.bit.P73SEL = 1;		/// - P73 : Enable peripheral I/O function.
		p7modsel_set.bit.P72SEL = 1;		/// - P72 : Enable peripheral I/O function.
		p7modsel_set.bit.P71SEL = 1;		/// - P71 : Enable peripheral I/O function.
		p7modsel_set.bit.P70SEL = 1;		/// - P70 : Enable peripheral I/O function.
		P7MODSEL = p7modsel_set.reg;
	}

	/// - LCD8B Driver W18 (COM0 to COM3 COM4/SEG0 to COM7/SEG3)
	/* P8FNCSEL:P8 Port Function Select Register */
	{
		p8fncsel_set.bit.P87MUX = 3;		/// - P87 : UPMUX.
		p8fncsel_set.bit.P86MUX = 3;		/// - P86 : UPMUX.
		p8fncsel_set.bit.P85MUX = 3;		/// - P85 : UPMUX.
		p8fncsel_set.bit.P84MUX = 3;		/// - P84 : UPMUX.
		p8fncsel_set.bit.P83MUX = 3;		/// - P83 : UPMUX.
		p8fncsel_set.bit.P82MUX = 3;		/// - P82 : UPMUX.
		p8fncsel_set.bit.P81MUX = 3;		/// - P81 : UPMUX.
		p8fncsel_set.bit.P80MUX = 3;		/// - P80 : UPMUX.
		P8FNCSEL = p8fncsel_set.reg;
	}

	/* P8MODSEL:P8 Port Mode Select Register */
	{
		p8modsel_set.bit.P87SEL = 1;		/// - P87 : Enable peripheral I/O function.
		p8modsel_set.bit.P86SEL = 1;		/// - P86 : Enable peripheral I/O function.
		p8modsel_set.bit.P85SEL = 1;		/// - P85 : Enable peripheral I/O function.
		p8modsel_set.bit.P84SEL = 1;		/// - P84 : Enable peripheral I/O function.
		p8modsel_set.bit.P83SEL = 1;		/// - P83 : Enable peripheral I/O function.
		p8modsel_set.bit.P82SEL = 1;		/// - P82 : Enable peripheral I/O function.
		p8modsel_set.bit.P81SEL = 1;		/// - P81 : Enable peripheral I/O function.
		p8modsel_set.bit.P80SEL = 1;		/// - P80 : Enable peripheral I/O function.
		P8MODSEL = p8modsel_set.reg;
	}
#endif

	/* LCD8CLK:LCD8B Clock Control Register */
	{
		lcd8clk_set.bit.DBRUN = 1;				/// - Clock supplied in DEBUG mode.
		lcd8clk_set.bit.CLKDIV = lcdClkDiv;		/// - Select the division ratio.
		lcd8clk_set.bit.CLKSRC = lcdClkSrc;		/// - Select the clock source of the LCD8B.
		LCD8CLK = lcd8clk_set.reg;
	}
	/* LCD8TIM1:LCD8B Timing Control Register 1. */
	{
		/**
	     * @todo Change LCD8B Timing Control Register 1
	     */
		lcd8tim1_set.bit.FRMCNT = 0x3;			/// Frame frequency = 64.0 Hz.
		lcd8tim1_set.bit.LDUTY = 0x7;			/// Drive duty = 1/8.
		LCD8TIM1 = lcd8tim1_set.reg;
	}
	/* LCD8TIM2:LCD8B Timing Control Register 2. */
	{
		/**
	     * @todo Change LCD8B Timing Control Register 2
	     */
		lcd8tim2_set.bit.BSTC = 1;				/// Booster clock frequency = fCLK_LCD8B/16 Hz.
		lcd8tim2_set.bit.NLINE = 0x00;			/// N-line inverse AC drive function = Normal drive.
		LCD8TIM2 = lcd8tim2_set.reg;
	}
	/* LCD8PWR:LCD8B Power Control Register. */
	{
		/**
	     * @todo Change LCD8B Power Control Register
	     */
#if defined(C17_MCUSEL_W18)
		lcd8pwr_set.bit.EXVCSEL = 0;			/// LCD drive power supply mode = Internal generation mode.
#endif
		lcd8pwr_set.bit.LC	= 0x0;				/// LCD panel contrast = 0x00:light - 0x1F:dark.
		lcd8pwr_set.bit.BSTEN = 1;				/// LCD voltage booster = off.
#if defined(C17_MCUSEL_W15) || defined(C17_MCUSEL_W18)
		lcd8pwr_set.bit.BISEL = 1;				/// LCD drive bias = 1/4 bias.
#endif
		lcd8pwr_set.bit.HVLD = 0;				/// LCD voltage regulator into heavy load protection mode = Normal mode.
		lcd8pwr_set.bit.VCSEL = 1;				/// LCD voltage regulator output = VC2.
		lcd8pwr_set.bit.VCEN = 1;				/// LCD voltage regulator = on.
		LCD8PWR = lcd8pwr_set.reg;
	}

	/* LCD8DSP:LCD8B Display Control Register. */
	{
		/**
	     * @todo Change LCD8B Display Control Register
	     */
		lcd8dsp_set.bit.SEGREV	= 1;			/// Segment pin assignment direction = Normal assignment.
		lcd8dsp_set.bit.COMREV	= 1;			/// Common pin assignment direction = Normal assignment.
		lcd8dsp_set.bit.DSPREV	= 1;			/// Black/White inversion = Normal display.
		lcd8dsp_set.bit.DSPAR = 0;				/// Display area in the display data RAM = Display area 0.
		lcd8dsp_set.bit.DSPC = 0;				/// LCD display = display off.
		LCD8DSP = lcd8dsp_set.reg;
	}
	/* LCDCOMC0:LCD8B COM Pin Control Register. */
	{
		/**
	     * @todo Change LCD8B COM Pin Control Register
	     */
		lcd8comc0_set.bit.COM7DEN = 1;			/// Partial drive of COM7 = Normal output;
		lcd8comc0_set.bit.COM6DEN = 1;			/// Partial drive of COM6 = Normal output;
		lcd8comc0_set.bit.COM5DEN = 1;			/// Partial drive of COM5 = Normal output;
		lcd8comc0_set.bit.COM4DEN = 1;			/// Partial drive of COM4 = Normal output;
		lcd8comc0_set.bit.COM3DEN = 1;			/// Partial drive of COM3 = Normal output;
		lcd8comc0_set.bit.COM2DEN = 1;			/// Partial drive of COM2 = Normal output;
		lcd8comc0_set.bit.COM1DEN = 1;			/// Partial drive of COM1 = Normal output;
		lcd8comc0_set.bit.COM0DEN = 1;			/// Partial drive of COM0 = Normal output;
		LCD8COMC0 = lcd8comc0_set.reg;
	}
	/// Clear interrupt flags.
	/* LCD8INTF:LCD8B Interrupt Flag Register. */
	{
		lcd8intf_set.bit.FRMIF = 1;
		LCD8INTF = lcd8intf_set.reg;
	}
	/// Disable LCD8B frame interrupts.
	/* LCD8INTE:LCD8B Interrupt Enable Register. */
	{
		lcd8inte_set.bit.FRMIE = 0;
		LCD8INTE = lcd8inte_set.reg;
	}

	/// initializes VRAM.
	initLcd8bSegRam();

}


/************************************************************************//**
 * @brief   LCD8B Interrupt function.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intLcd8b(void)
{
 	LCD8INTF_REG lcd8intf_set;

	/* LCD8INTF LCD8B Interrupt Flag Register read & clear */
	{
		lcd8intf_set.reg = LCD8INTF;
		LCD8INTF = lcd8intf_set.reg;
	}

	/// Check interrupt cause occurrence status.
	if(lcd8intf_set.bit.FRMIF == 1)
	{
	   /**
		* @todo add interrupt function of frame interrupt.
		*/
	}

}


/* ----- static ----- */

/************************************************************************//**
 * @brief   This function initializes RAM of LCD8B Panel(7Segment).
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
static void initLcd8bSegRam(void)
{
	unsigned char	*segram = (unsigned char *)LCD8B_SEGRAM_TOP_ADDR;
	unsigned short	i;

	for(i = 0 ; i < LCD8B_SEGRAM_SIZE ; i++){
		*segram++ = 0x00;
	}
}
#endif

