/************************************************************************//**
 *
 * @file    main.c
 *
 * @brief   This is WDT sample program for S1C17W18 demonstration.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
/************************************************************************//**
 * @main_page   S1C17W18 Watch Dog Timer (WDT)
 *
 * @section	    intro Introduction
 * Sample code for Reset WDT for ten seconds.
 * Afterwards, generate the Reset interrupt.
 *
 * @subsection  step1   Step 1: Initialize T16 Ch.0.
 * @subsection  step2	Step 2: Initialize and start WDT.
 * @subsection  step3   Step 3: Start T16 Ch.0(1-second interrupt).
 * @subsection  step4   Step 4: Reset WDT by T16 Ch.0 1sec Interrupt(10 seconds).
 * @subsection  step5   Step 5: Stop T16 Ch.0
 * @subsection  step6   Step 6: Confirm the Reset interrupt.
 *
 * @section     install Installation
 * Start the IDE and import the "s1c17w18_sample" project.
 *
 ***************************************************************************/
#include <stdlib.h>
#include <stdio.h>
#include "crt0.h"
#include "c17_misc.h"
#include "c17_wdt.h"
#include "c17_clg.h"
#include "c17_t16.h"
#include "c17_init_config.h"

#if defined(C17_PE_WDT)

/* --- global variable --- */
extern volatile unsigned int c17t16Ch0IntCount;

/* --- function declaration --- */
int main_wdt(void);


/************************************************************************//**
 * main function.
 *
 * @brief   1,WDT register is initialized.
 *
 *          2,Reset WDT(10 seconds).
 *
 *          3,Generate the Reset interrupt.
 *
 *
 * @return  EXIT_SUCCESS    Success.
 ***************************************************************************/
int main_wdt(void)
{
	/* <<< Watch dog Timer demonstration start >>> */

	/// Clock = IOSC
	c17startClgIOSC();
	c17switchClgSystemClockIOSC();

	/// Initialize and start OSC1.
	c17startClgOSC1();								// start OSC1.

	/// Clear Interruption counter.
	c17t16Ch0IntCount = 0;

	/**
	 * Clock Source = IOSC(700kHz)
	 * Clock Division = 1/32
	 * Ft = 1sec
	 * TR = 1[sec] * f((700kHz/32) -1 = 21874
	 */
	/// Initialize  T16 CH.0 timer.
	c17setT16(0, C17_T16_CLKSRC_IOSC, C17_T16_CLKDIV_32, C17_T16_MODE_REPEAT);

	/// Set Reload Value T16 CH.0
	c17setCountT16(0, 21874);

	/// Initialize the interrupt.
	ILVT16_0 = INTERRUPT_LEVEL_T16_0;				/// - Set interrupt level.

	/// T16 CH.0 Interrupt Enable
	c17enableIntT16(0);

	/// Initialize WDT.
	c17initWdt();

	/// Start WDT.
	c17startWdt();

	/// Start T16 CH.0 timer.
	c17startT16(0);


	/// Reset WDT(10 seconds).
	while (c17t16Ch0IntCount < 10) {
		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is	released, and it diverges to the server blade.
		asm("halt");
		asm("nop");

		/// - Reset WDT.
		c17resetWdt();

	}

	/// Stop T16 Ch.0
	c17stopT16(0);

	/// Wait interrupt.
	while (1) {
		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is	released, and it diverges to the server blade.
		asm("halt");
		asm("nop");
		// Wait...
	}

	/// Stop WDT.
	c17stopWdt();

	/* <<< Watch dog Timer demonstration finish >>> */

	return EXIT_SUCCESS;
}
#endif

