/************************************************************************//**
 *
 * @file    rtca_reg.h
 *
 * @brief   Definition of the RTCA Register.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Nov. 2018    1.10
 *              - Change source code.
 *
 ******************************************************************************/
#ifndef RTCA_REG_H__
#define RTCA_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// RTCA Control Register
typedef union RTCCTLL_REG_TAG {
    unsigned char   reg;
    struct RTCCTLL_REG_BIT_TAG {
        /**
         * This bit starts/stops the real-time clock counter.
         * .RTCRUN
         * This bit starts/stops the real-time clock counter.
         *    1 (R/W): Running/start control
         *    0 (R/W): Idle/stop control
         */
        unsigned char       RTCRUN      : 1;
        /**
         * This bit resets the 1 Hz counter, the RTCCTL.RTCADJ bit, and the RTCCTL.RTCHLD bit.
         * .RTCRST
         * This bit resets the 1 Hz counter, the RTCCTL.RTCADJ bit, and the RTCCTL.RTCHLD bit.
         *    1 (W): Reset
         *    0 (W): Ineffective
         *    1 (R): Reset is being executed.
         *    0 (R): Reset has finished. (Normal operation)
         */
        unsigned char       RTCRST      : 1;
        /**
         * This bit executes the 30-second correction time adjustment function.
         * .RTCADJ
         *  This bit executes the 30-second correction time adjustment function.
         *    1 (W): Execute 30-second correction
         *    0 (W): Ineffective
         *    1 (R): 30-second correction is executing.
         *    0 (R): 30-second correction has finished. (Normal operation)
         */
        unsigned char       RTCADJ      : 1;
        unsigned char       reserved_1  : 1;    ///< Reserved.
        /**
         * This bit sets the hour counter to 24H mode or 12H mode.
         * .RTC24H
         *  This bit sets the hour counter to 24H mode or 12H mode.
         *    1 (R/W): 24H mode
         *    0 (R/W): 12H mode
         */
        unsigned char       RTC24H      : 1;
        /**
         * This bit halts the count-up operation of the real-time clock counter.
         * .RTCHLD
         *  This bit halts the count-up operation of the real-time clock counter.
         *    1 (R/W): Halt real-time clock counter count-up operation
         *    0 (R/W): Normal operation
         */
        unsigned char       RTCHLD      : 1;
        /**
         * This bit indicates whether the counter is performing count-up operation or not.
         * .RTCBSY
         *  This bit indicates whether the counter is performing count-up operation or not.
         *    1 (R): In count-up operation
         *    0 (R): Idle (ready to rewrite real-time clock counter)
         */
        unsigned char       RTCBSY      : 1;
        unsigned char       reserved_2  : 1;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[1];
} RTCCTLL_REG;

/// RTCA Control Register
typedef union RTCCTLH_REG_TAG {
    unsigned char   reg;
    struct RTCCTLH_REG_BIT_TAG {
        /**
         * Write the correction value for adjusting the 1 Hz frequency to these bits to execute theoretical regulation.
         *  .RTCTRM[6:0]
         *  Write the correction value for adjusting the 1 Hz frequency to these bits to execute theoretical regulation.
         * +--------------------------+----------------+------------+--------------------------+----------------+------------+
         * |       RTCTRM[6:0]        |   Correction   | Correction |       RTCTRM[6:0]        |   Correction   | Correction |
         * | bits (two's-complement)  | value (decimal)| rate [ppm] | bits (two's-complement)  | value (decimal)| rate [ppm] |
         * +--------------------------+----------------+------------+--------------------------+----------------+------------+
         * |          0x00            |       0        |     0.0    |          0x40            |      -64       |   -61.0    |
         * +--------------------------+----------------+------------+--------------------------+----------------+------------+
         * |          0x01            |       1        |     1.0    |          0x41            |      -63       |   -60.1    |
         * +--------------------------+----------------+------------+--------------------------+----------------+------------+
         * |          0x02            |       2        |     1.9    |          0x42            |      -62       |   -59.1    |
         * +--------------------------+----------------+------------+--------------------------+----------------+------------+
         * |          0x03            |       3        |     2.9    |          0x43            |      -61       |   -58.2    |
         * +--------------------------+----------------+------------+--------------------------+----------------+------------+
         * |          ...             |      ...       |     ...    |          ...             |      ...       |    ...     |
         * +--------------------------+----------------+------------+--------------------------+----------------+------------+
         * |          0x3e            |      62        |    59.1    |          0x7e            |       -2       |    -1.9    |
         * +--------------------------+----------------+------------+--------------------------+----------------+------------+
         * |          0x3f            |      63        |    60.1    |          0x7f            |       -1       |    -1.0    |
         * +--------------------------+----------------+------------+--------------------------+----------------+------------+
         */
        unsigned char       RTCTRM      : 7;
        /**
         * This bit indicates whether the theoretical regulation is currently executed or not.
         * .RTCTRMBSY
         *  This bit indicates whether the theoretical regulation is currently executed or not.
         *    1 (R): Theoretical regulation is executing.
         *    0 (R): Theoretical regulation has finished (or not executed).
         */
        unsigned char       RTCTRMBSY   : 1;
    } bit;
    unsigned char   byte_reg[1];
} RTCCTLH_REG;

/// RTCA Second Alarm Register
typedef union RTCALM1_REG_TAG {
    unsigned short  reg;
    struct RTCALM1_REG_BIT_TAG {
        unsigned short      reserved_1  : 8;    ///< Reserved.
        /**
         * There bits set the 1-second digit of the alarm time.
         * .RTCSLA[3:0]
         *  There bits set the 1-second digit of the alarm time.
         * .RTCSHA[2:0]
         *  There bits set the 10-second digit of the alarm time.
         *
         * +----------------------------------------------------+
         * | Setting value in BCD code |                        |
         * +-------------+-------------+                        |
         * | RTCSHA[2:0] | RTCSLA[3:0] | Alarm (second) setting |
         * +-------------+-------------+------------------------+
         * |     0x0     |     0x0     |  00 seconds            |
         * +-------------+-------------+------------------------+
         * |     0x0     |     0x1     |  01 seconds            |
         * +-------------+-------------+------------------------+
         * |     ...     |    ...      |  ...                   |
         * +-------------+-------------+------------------------+
         * |     0x0     |     0x9     |  09 seconds            |
         * +-------------+-------------+------------------------+
         * |     0x1     |     0x0     |  10 seconds            |
         * +-------------+-------------+------------------------+
         * |     ...     |    ...      |  ...                   |
         * +-------------+-------------+------------------------+
         * |     0x5     |     0x9     |  59 seconds            |
         * +-------------+-------------+------------------------+
         */
        unsigned short      RTCSLA      : 4;
        /**
         * There bits set the 10-second digit of the alarm time.
         * .RTCSLA[3:0]
         *  There bits set the 1-second digit of the alarm time.
         * .RTCSHA[2:0]
         *  There bits set the 10-second digit of the alarm time.
         * +----------------------------------------------------+
         * | Setting value in BCD code |                        |
         * +-------------+-------------+                        |
         * | RTCSHA[2:0] | RTCSLA[3:0] | Alarm (second) setting |
         * +-------------+-------------+------------------------+
         * |     0x0     |     0x0     |  00 seconds            |
         * +-------------+-------------+------------------------+
         * |     0x0     |     0x1     |  01 seconds            |
         * +-------------+-------------+------------------------+
         * |     ...     |    ...      |  ...                   |
         * +-------------+-------------+------------------------+
         * |     0x0     |     0x9     |  09 seconds            |
         * +-------------+-------------+------------------------+
         * |     0x1     |     0x0     |  10 seconds            |
         * +-------------+-------------+------------------------+
         * |     ...     |    ...      |  ...                   |
         * +-------------+-------------+------------------------+
         * |     0x5     |     0x9     |  59 seconds            |
         * +-------------+-------------+------------------------+
         */
        unsigned short      RTCSHA      : 3;
        unsigned short      reserved_2  : 1;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} RTCALM1_REG;

/// RTCA Hour/Minute Alarm Register
typedef union RTCALM2_REG_TAG {
    unsigned short  reg;
    struct RTCALM2_REG_BIT_TAG {
        /**
         * There bits set the 1-minute digit of the alarm time.
         * .RTCMILA[3:0]
         *  There bits set the 1-minute digit of the alarm time.
         * The RTCALM2.RTCMIHA[2:0] bits and the RTCALM2.RTCMILA[3:0] bits set the 10-minute digit
         * and 1-minute digit of the alarm time, respectively. A value within 0 to 59 minutes can be set in BCD
         * code.
         */
        unsigned short      RTCMILA     : 4;
        /**
         * There bits set the 10-minute digit of the alarm time.
         * .RTCMIHA[2:0]
         *  There bits set the 10-minute digit of the alarm time.
         * The RTCALM2.RTCMIHA[2:0] bits and the RTCALM2.RTCMILA[3:0] bits set the 10-minute digit
         * and 1-minute digit of the alarm time, respectively. A value within 0 to 59 minutes can be set in BCD
         * code.
         */
        unsigned short      RTCMIHA     : 3;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * There bits set the 1-hour digit of the alarm time.
         * .RTCHLA[3:0]
         *  There bits set the 1-hour digit of the alarm time.
         * The RTCALM2.RTCHHA[1:0] bits and the RTCALM2.RTCHLA[3:0] bits set the 10-hour digit and
         * 1-hour digit of the alarm time, respectively. A value within 1 to 12 o'clock in 12H mode or 0 to 23 in
         * 24H mode can be set in BCD code.
         */
        unsigned short      RTCHLA      : 4;
        /**
         * There bits set the 10-hour digit of the alarm time.
         * .RTCHHA[1:0]
         *  There bits set the 10-hour digit of the alarm time.
         * The RTCALM2.RTCHHA[1:0] bits and the RTCALM2.RTCHLA[3:0] bits set the 10-hour digit and
         * 1-hour digit of the alarm time, respectively. A value within 1 to 12 o'clock in 12H mode or 0 to 23 in
         * 24H mode can be set in BCD code.
         */
        unsigned short      RTCHHA      : 2;
        /**
         * This bit set A.M. or P.M. of the alarm time in 12H mode (RTCCTL.RTC24H bit = 0).
         * .RTCAPA
         *  This bit set A.M. or P.M. of the alarm time in 12H mode (RTCCTL.RTC24H bit = 0).
         *    1 (R/W): P.M.
         *    0 (R/W): A.M.
         */
        unsigned short      RTCAPA      : 1;
        unsigned short      reserved_2  : 1;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} RTCALM2_REG;

/// RTCA Stopwatch Control Register
typedef union RTCSWCTL_REG_TAG {
    unsigned short  reg;
    struct RTCSWCTL_REG_BIT_TAG {
        /**
         * This bit starts/stops the stop watch counter.
         * .SWRUN
         *  This bit starts/stops the stop watch counter.
         *    1 (R/W): Running/start control
         *    0 (R/W): Idle/stop control
         */
        unsigned short      SWRUN       : 1;
        unsigned short      reserved_1  : 3;    ///< Reserved.
        /**
         * This bit resets the stop watch counter to 0x00.
         * .SWRST
         *  This bit resets the stop watch counter to 0x00.
         *    1 (W): Reset
         *    0 (W): Ineffective
         *    0 (R): Always 0 when being read
         */
        unsigned short      SWRST       : 1;
        unsigned short      reserved_2  : 3;    ///< Reserved.
        /**
         * The 1/100-second digits of the stop watch counter can be read as a BCD code.
         * .BCD100[3:0]
         * The 1/100-second digits of the stop watch counter can be read as a BCD code.
         */
        unsigned short      BCD100      : 4;
        /**
         * The 1/10-second digits of the stop watch counter can be read as a BCD code.
         * .BCD10[3:0]
         * The 1/10-second digits of the stop watch counter can be read as a BCD code.
         */
        unsigned short      BCD10       : 4;
    } bit;
    unsigned char   byte_reg[2];
} RTCSWCTL_REG;

/// RTCA Second/1[Hz] Register
typedef union RTCSEC_REG_TAG {
    unsigned short  reg;
    struct RTCSEC_REG_BIT_TAG {
        /**
         * 1 Hz counter data can be read from these bits(128Hz).
         *  .RTC128HZ
         *  1 Hz counter data can be read from these bits(128Hz).
         */
        unsigned short      RTC128HZ    : 1;
        /**
         * 1 Hz counter data can be read from these bits(64Hz).
         *  .RTC64HZ
         *  1 Hz counter data can be read from these bits(64Hz).
         */
        unsigned short      RTC64HZ     : 1;
        /**
         * 1 Hz counter data can be read from these bits(32Hz).
         *  .RTC32HZ
         *  1 Hz counter data can be read from these bits(32Hz).
         */
        unsigned short      RTC32HZ     : 1;
        /**
         * 1 Hz counter data can be read from these bits(16Hz).
         *  .RTC16HZ
         *  1 Hz counter data can be read from these bits(16Hz).
         */
        unsigned short      RTC16HZ     : 1;
        /**
         * 1 Hz counter data can be read from these bits(8Hz).
         *  .RTC8HZ
         *  1 Hz counter data can be read from these bits(8Hz).
         */
        unsigned short      RTC8HZ      : 1;
        /**
         * 1 Hz counter data can be read from these bits(4Hz).
         *  .RTC4HZ
         *  1 Hz counter data can be read from these bits(4Hz).
         */
        unsigned short      RTC4HZ      : 1;
        /**
         * 1 Hz counter data can be read from these bits(2Hz).
         *  .RTC2HZ
         *  1 Hz counter data can be read from these bits(2Hz).
         */
        unsigned short      RTC2HZ      : 1;
        /**
         * 1 Hz counter data can be read from these bits(1Hz).
         *  .RTC1HZ
         *  1 Hz counter data can be read from these bits(1Hz).
         */
        unsigned short      RTC1HZ      : 1;
        /**
         * There bits are used to set and read the 1-second digit of the second counter.
         * .RTCSL[3:0]
         *  There bits are used to set and read the 1-second digit of the second counter.
         * The RTCSEC.RTCSH[2:0] bits and the RTCSEC.RTCSL[3:0] bits are used to set and read the 10-second
         * digit and the 1-second digit of the second counter, respectively. The setting/read values are a BCD
         * code within the range from 0 to 59.
         */
        unsigned short      RTCSL       : 4;
        /**
         * There bits are used to set and read the 10-second digit of the second counter.
         * .RTCSH[2:0]
         *  There bits are used to set and read the 10-second digit of the second counter.
         * The RTCSEC.RTCSH[2:0] bits and the RTCSEC.RTCSL[3:0] bits are used to set and read the 10-second
         * digit and the 1-second digit of the second counter, respectively. The setting/read values are a BCD
         * code within the range from 0 to 59.
         */
        unsigned short      RTCSH       : 3;
        unsigned short      reserved_1  : 1;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} RTCSEC_REG;

/// RTCA Hour/Minute Register
typedef union RTCHUR_REG_TAG {
    unsigned short  reg;
    struct RTCHUR_REG_BIT_TAG {
        /**
         * There bits are used to set and read the 1-minute digit of the minute counter.
         * .RTCMIL[3:0]
         *  There bits are used to set and read the 1-minute digit of the minute counter.
         * The RTCHUR.RTCMIH[2:0] bits and the RTCHUR.RTCMIL[3:0] bits are used to set and read the
         * 10-minute digit and the 1-minute digit of the minute counter, respectively. The setting/read values are
         * a BCD code within the range from 0 to 59.
         */
        unsigned short      RTCMIL      : 4;
        /**
         * There bits are used to set and read the 10-minute digit of the minute counter.
         * .RTCMIH[2:0]
         *  There bits are used to set and read the 10-minute digit of the minute counter.
         * The RTCHUR.RTCMIH[2:0] bits and the RTCHUR.RTCMIL[3:0] bits are used to set and read the
         * 10-minute digit and the 1-minute digit of the minute counter, respectively. The setting/read values are
         * a BCD code within the range from 0 to 59.
         */
        unsigned short      RTCMIH      : 3;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * There bits are used to set and read the 1-hour digit of the hour counter.
         * .RTCHL[3:0]
         *  There bits are used to set and read the 1-hour digit of the hour counter.
         * The RTCHUR.RTCHH[1:0] bits and the RTCHUR.RTCHL[3:0] bits are used to set and read the 10-
         * hour digit and the 1-hour digit of the hour counter, respectively. The setting/read values are a BCD
         * code within the range from 1 to 12 in 12H mode or 0 to 23 in 24H mode.
         */
        unsigned short      RTCHL       : 4;
        /**
         * There bits are used to set and read the 10-hour digit of the hour counter.
         * .RTCHH[1:0]
         *  There bits are used to set and read the 10-hour digit of the hour counter.
         * The RTCHUR.RTCHH[1:0] bits and the RTCHUR.RTCHL[3:0] bits are used to set and read the 10-
         * hour digit and the 1-hour digit of the hour counter, respectively. The setting/read values are a BCD
         * code within the range from 1 to 12 in 12H mode or 0 to 23 in 24H mode.
         */
        unsigned short      RTCHH       : 2;
        /**
         * This bit is used to set and read A.M. or P.M. data in 12H mode (RTCCTL.RTC24H bit = 0).
         * .RTCAP
         *  This bit is used to set and read A.M. or P.M. data in 12H mode (RTCCTL.RTC24H bit = 0).
         *    1 (R/W): P.M.
         *    0 (R/W): A.M.
         */
        unsigned short      RTCAP       : 1;
        unsigned short      reserved_2  : 1;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} RTCHUR_REG;

/// RTCA Month/Day Register
typedef union RTCMON_REG_TAG {
    unsigned short  reg;
    struct RTCMON_REG_BIT_TAG {
        /**
         * There bits are used to set and read the 1-day digit of the day counter.
         * .RTCDL[3:0]
         *  There bits are used to set and read the 1-day digit of the day counter.
         * The RTCMON.RTCDH[1:0] bits and the RTCMON.RTCDL[3:0] bits are used to set and read the 10-
         * day digit and the 1-day digit of the day counter, respectively. The setting/read values are a BCD code
         * within the range from 1 to 31 (to 28 for February in a common year, to 29 for February in a leap year,
         * or to 30 for April/June/September/November).
         */
        unsigned short      RTCDL       : 4;
        /**
         * There bits are used to set and read the 10-day digit of the day counter.
         * .RTCDH[1:0]
         *  There bits are used to set and read the 10-day digit of the day counter.
         * The RTCMON.RTCDH[1:0] bits and the RTCMON.RTCDL[3:0] bits are used to set and read the 10-
         * day digit and the 1-day digit of the day counter, respectively. The setting/read values are a BCD code
         * within the range from 1 to 31 (to 28 for February in a common year, to 29 for February in a leap year,
         * or to 30 for April/June/September/November).
         */
        unsigned short      RTCDH       : 2;
        unsigned short      reserved_1  : 2;    ///< Reserved.
        /**
         * There bits are used to set and read the 1-month digit of the month counter.
         * .RTCMOL[3:0]
         *  There bits are used to set and read the 1-month digit of the month counter.
         * The RTCMON.RTCMOH bit and the RTCMON.RTCMOL[3:0] bits are used to set and read the
         * 10-month digit and the 1-month digit of the month counter, respectively. The setting/read values are a
         * BCD code within the range from 1 to 12.
         */
        unsigned short      RTCMOL      : 4;
        /**
         * There bits are used to set and read the 10-month digit of the month counter.
         * .RTCMOH
         *  There bits are used to set and read the 10-month digit of the month counter.
         * The RTCMON.RTCMOH bit and the RTCMON.RTCMOL[3:0] bits are used to set and read the
         * 10-month digit and the 1-month digit of the month counter, respectively. The setting/read values are a
         * BCD code within the range from 1 to 12.
         */
        unsigned short      RTCMOH      : 1;
        unsigned short      reserved_2  : 3;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} RTCMON_REG;

/// RTCA Year/Week Register
typedef union RTCYAR_REG_TAG {
    unsigned short  reg;
    struct RTCYAR_REG_BIT_TAG {
        /**
         * There bits are used to set and read the 1-year digit of the year counter.
         * .RTCYL[3:0]
         *  There bits are used to set and read the 1-year digit of the year counter.
         * The RTCYAR.RTCYH[3:0] bits and the RTCYAR.RTCYL[3:0] bits are used to set and read the 10-
         * year digit and the 1-year digit of the year counter, respectively. The setting/read values are a BCD
         * code within the range from 0 to 99.
         */
        unsigned short      RTCYL       : 4;
        /**
         * There bits are used to set and read the 10-year digit of the year counter.
         * .RTCYH[3:0]
         *  There bits are used to set and read the 10-year digit of the year counter.
         * The RTCYAR.RTCYH[3:0] bits and the RTCYAR.RTCYL[3:0] bits are used to set and read the 10-
         * year digit and the 1-year digit of the year counter, respectively. The setting/read values are a BCD
         * code within the range from 0 to 99.
         */
        unsigned short      RTCYH       : 4;
        /**
         * These bits are used to set and read day of the week.
         * .RTCWK[2:0]
         *  These bits are used to set and read day of the week.
         * The day of the week counter is a base-7 counter and the setting/read values are 0x0 to 0x6.
         * +------------+-----------------+
         * | RTCWK[2:0] | Day of the week |
         * +------------+-----------------+
         * |    0x6     |    Saturday     |
         * +------------+-----------------+
         * |    0x5     |     Friday      |
         * +------------+-----------------+
         * |    0x4     |    Thursday     |
         * +------------+-----------------+
         * |    0x3     |    Wednesday    |
         * +------------+-----------------+
         * |    0x2     |     Tuesda      |
         * +------------+-----------------+
         * |    0x1     |     Monday      |
         * +------------+-----------------+
         * |    0x0     |     Sunday      |
         * +------------+-----------------+
         */
        unsigned short      RTCWK       : 3;
        unsigned short      reserved_1  : 5;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} RTCYAR_REG;

/// RTCA Interrupt Flag Register
typedef union RTCINTF_REG_TAG {
    unsigned short  reg;
    struct RTCINTF_REG_BIT_TAG {
        /**
         * This bit indicate 1/32-second interrupt cause occurrence status.
         * .1_32SECIF
         *  This bit indicate 1/32-second interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      _1_32SECIF  : 1;
        /**
         * This bit indicate 1/8-second interrupt cause occurrence status.
         * .1_8SECIF
         *  This bit indicate 1/8-second interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      _1_8SECIF   : 1;
        /**
         * This bit indicate 1/4-second interrupt cause occurrence status.
         * .1_4SECIF
         *  This bit indicate 1/4-second interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      _1_4SECIF   : 1;
        /**
         * This bit indicate 1/2-second interrupt cause occurrence status.
         * .1_2SECIF
         *  This bit indicate 1/2-second interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      _1_2SECIF   : 1;
        /**
         * This bit indicate 1-second interrupt cause occurrence status.
         * .1SECIF
         *  This bit indicate 1-second interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      _1SECIF     : 1;
        /**
         * This bit indicate 1-minute interrupt cause occurrence status.
         * .1MINIF
         *  This bit indicate 1-minute interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      _1MINIF     : 1;
        /**
         * This bit indicate 1-day interrupt cause occurrence status.
         * .1MINIF
         *  This bit indicate 1-day interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      _1HURIF     : 1;
        /**
         * This bit indicate 1-day interrupt cause occurrence status.
         * .1DAYIF
         *  This bit indicate 1-day interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      _1DAYIF     : 1;
        /**
         * This bit indicate Alarm interrupt cause occurrence status.
         * .ALARMIF
         *  This bit indicate Alarm interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      ALARMIF     : 1;
        unsigned short      reserved_1  : 3;    ///< Reserved.
        /**
         * This bit indicate Stop watch 100 Hz interrupt cause occurrence status.
         * .SW100IF
         *  This bit indicate Stop watch 100 Hz interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      SW100IF     : 1;
        /**
         * This bit indicate Stop watch 10 Hz interrupt cause occurrence status.
         * .SW10IF
         *  This bit indicate Stop watch 10 Hz interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      SW10IF      : 1;
        /**
         * This bit indicate Stop watch 1 Hz interrupt cause occurrence status.
         * .SW1IF
         *  This bit indicate Stop watch 1 Hz interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      SW1IF       : 1;
        /**
         * This bit indicate Theoretical regulation completion interrupt cause occurrence status.
         * .RTCTRMIF
         *  This bit indicate Theoretical regulation completion interrupt cause occurrence status.
         * This bit indicate the real-time clock interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      RTCTRMIF    : 1;
    } bit;
    unsigned char   byte_reg[2];
} RTCINTF_REG;

/// RTCA Interrupt Enable Register
typedef union RTCINTE_REG_TAG {
    unsigned short  reg;
    struct RTCINTE_REG_BIT_TAG {
        /**
         * This bits enable 1/32-second interrupt.
         * .1_32SECIE
         *  This bits enable 1/32-second interrupt.
         * This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      _1_32SECIE  : 1;
        /**
         * This bits enable 1/8-second interrupt.
         * .1_8SECIE
         *  This bits enable 1/8-second interrupt.
         * This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      _1_8SECIE   : 1;
        /**
         * This bits enable 1/4-second interrupt.
         * .1_4SECIE
         *  This bits enable 1/4-second interrupt.
         * This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      _1_4SECIE   : 1;
        /**
         * This bits enable 1/2-second interrupt.
         * .1_2SECIE
         *  This bits enable 1/2-second interrupt.
         * This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      _1_2SECIE   : 1;
        /**
         * This bits enable 1-second interrupt.
         * .1SECIE
         *  This bits enable 1-second interrupt.
         * This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      _1SECIE     : 1;
        /**
         * This bits enable 1-minute interrupt.
         * .1MINIE
         *  This bits enable 1-minute interrupt.
         * This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      _1MINIE     : 1;
        /**
         * This bits enable 1-hour interrupt.
         * .1HURIE
         *  This bits enable 1-hour interrupt.
         * This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      _1HURIE     : 1;
        /**
         * This bits enable 1-day interrupt.
         * .1DAYIE
         *  This bits enable 1-day interrupt.
         * This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      _1DAYIE     : 1;
        /**
         * This bits enable Alarm interrupt.
         * .ALARMIE
         *  This bits enable Alarm interrupt.
         * This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      ALARMIE     : 1;
        unsigned short      reserved_1  : 3;    ///< Reserved.
        /**
         * This bit enable Stop watch 100 Hz interrupt.
         * .SW100IE
         *  This bit enable Stop watch 100 Hz interrupt.
         *  This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      SW100IE     : 1;
        /**
         * This bit enable Stop watch 10 Hz interrupt.
         * .SW10IE
         *  This bit enable Stop watch 10 Hz interrupt.
         *  This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      SW10IE      : 1;
        /**
         * This bit enable Stop watch 1 Hz interrupt.
         * .SW1IE
         *  This bit enable Stop watch 1 Hz interrupt.
         *  This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      SW1IE       : 1;
        /**
         * This bit enable Theoretical regulation completion interrupt.
         * .RTCTRMIE
         *  This bit enable Theoretical regulation completion interrupt.
         *  This bit enable real-time clock interrupts.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      RTCTRMIE    : 1;
    } bit;
    unsigned char   byte_reg[2];
} RTCINTE_REG;

#ifdef __cplusplus
}
#endif

#endif // RTCA_REG_H__
