/************************************************************************//**
 *
 * @file    uart_reg.h
 *
 * @brief   Definition of the UART (UART) Register.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Nov. 2018    1.10
 *              - Change source code.
 *
 ******************************************************************************/
#ifndef UART_REG_H__
#define UART_REG_H__

#ifdef __cplusplus
extern "C" {
#endif

/// UART Ch.N Clock Control Register
typedef union UANCLK_REG_TAG {
    unsigned short  reg;
    struct UANCLK_REG_BIT_TAG {
        /**
         * These bits select the clock source of the UART.
         * .CLKSRC[1:0]
         *  These bits select the clock source of the UART.
         * .CLKDIV[1:0]
         *  These bits select the division ratio of the UART operating clock.
         * +-------------+-----------------------------------+
         * |             |           CLKSRC[1:0]             |
         * |             +--------+--------+--------+--------+
         * |             |  0x0   |   0x1  |  0x2   |  0x3   |
         * | CLKDIV[1:0] +--------+--------+--------+--------+
         * |             |        |        |        |        |
         * |             |  IOSC  |  OSC1  |  OSC3  | EXOSC  |
         * |             |        |        |        |        |
         * +-------------+--------+--------+--------+--------+
         * |     0x3     |  1/8   |  1/1   |  1/8   |  1/1   |
         * +-------------+--------+        +--------+        +
         * |     0x2     |  1/4   |        |  1/4   |        |
         * +-------------+--------+        +--------+        +
         * |     0x1     |  1/2   |        |  1/2   |        |
         * +-------------+--------+        +--------+        +
         * |     0x0     |  1/1   |        |  1/1   |        |
         * +-------------+--------+--------+--------+--------+
         */
        unsigned short      CLKSRC      : 2;
        unsigned short      reserved_1  : 2;    ///< Reserved.
        /**
         * These bits select the division ratio of the UART operating clock.
         * .CLKSRC[1:0]
         *  These bits select the clock source of the UART.
         * .CLKDIV[1:0]
         *  These bits select the division ratio of the UART operating clock.
         * +-------------+-----------------------------------+
         * |             |           CLKSRC[1:0]             |
         * |             +--------+--------+--------+--------+
         * |             |  0x0   |   0x1  |  0x2   |  0x3   |
         * | CLKDIV[1:0] +--------+--------+--------+--------+
         * |             |        |        |        |        |
         * |             |  IOSC  |  OSC1  |  OSC3  | EXOSC  |
         * |             |        |        |        |        |
         * +-------------+--------+--------+--------+--------+
         * |     0x3     |  1/8   |  1/1   |  1/8   |  1/1   |
         * +-------------+--------+        +--------+        +
         * |     0x2     |  1/4   |        |  1/4   |        |
         * +-------------+--------+        +--------+        +
         * |     0x1     |  1/2   |        |  1/2   |        |
         * +-------------+--------+        +--------+        +
         * |     0x0     |  1/1   |        |  1/1   |        |
         * +-------------+--------+--------+--------+--------+
         */
        unsigned short      CLKDIV      : 2;
        unsigned short      reserved_2  : 2;    ///< Reserved.
        /**
         * This bit sets whether the UART operating clock is supplied in DEBUG mode or not.
         * .DBRUN
         *  This bit sets whether the UART operating clock is supplied in DEBUG mode or not.
         *    1 (R/W): Clock supplied in DEBUG mode
         *    0 (R/W): No clock supplied in DEBUG mode
         */
        unsigned short      DBRUN       : 1;
        unsigned short      reserved_3  : 7;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} UANCLK_REG;

/// UART Ch.N Mode Register
typedef union UANMOD_REG_TAG {
    unsigned short  reg;
    struct UANMOD_REG_BIT_TAG {
        /**
         * This bit sets the stop bit length.
         * .STPB
         *  This bit sets the stop bit length.
         *    1 (R/W): 2 bits
         *    0 (R/W): 1 bit
         */
        unsigned short      STPB        : 1;
        /**
         * This bit selects either odd parity or even parity when using the parity function.
         * .PRMD
         *  This bit selects either odd parity or even parity when using the parity function.
         *    1 (R/W): Odd parity
         *    0 (R/W): Even parity
         */
        unsigned short      PRMD        : 1;
        /**
         * This bit sets the data length.
         * .PREN
         *  This bit enables the parity function.
         *    1 (R/W): Enable parity function
         *    0 (R/W): Disable parity function
         */
        unsigned short      PREN        : 1;
        /**
         * This bit sets the data length.
         * .CHLN
         *  This bit sets the data length.
         *    1 (R/W): 8 bits
         *    0 (R/W): 7 bits
         */
        unsigned short      CHLN        : 1;
        /**
         * This bit enables the IrDA interface function.
         * .IRMD
         *  This bit enables the IrDA interface function.
         *    1 (R/W): Enable IrDA interface function
         *    0 (R/W): Disable IrDA interface function
         */
        unsigned short      IRMD        : 1;
        /**
         * This bit sets the USOUT0 pin output mode.
         * .OUTMD
         *  This bit sets the USOUTn pin output mode.
         *    1 (R/W): Open-drain output
         *    0 (R/W): Push-pull output
         */
        unsigned short      OUTMD       : 1;
        /**
         * This bit enables pull-up of the USIN0 pin.
         * .PUEN
         *  This bit enables pull-up of the USINn pin.
         *    1 (R/W): Enable pull-up
         *    0 (R/W): Disable pull-up
         */
        unsigned short      PUEN        : 1;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * This bit enables the USOUTn output inverting function.
         * .INVIRTX
         *  This bit enables the USOUTn output inverting function.
         *    1 (R/W): Enable output inverting function
         *    0 (R/W): Disable output inverting function
         */
        unsigned short      INVIRTX     : 1;
        /**
         * This bit enables the USINn input inverting function.
         * .INVIRRX
         *  This bit enables the USINn input inverting function.
         *    1 (R/W): Enable input inverting function
         *    0 (R/W): Disable input inverting function
         */
        unsigned short      INVIRRX     : 1;
        unsigned short      reserved_2  : 6;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} UANMOD_REG;

/// UART Ch.N Baud-Rate Register
typedef union UANBR_REG_TAG {
    unsigned short  reg;
    struct UANBR_REG_BIT_TAG {
        /**
         * These bits set the UART transfer rate.
         * .BRT[7:0]
         *  These bits set the UART transfer rate.
         */
        unsigned short      BRT         : 8;
        /**
         * These bits set the UART transfer rate.
         * .FMD[3:0]
         *  These bits set the UART transfer rate.
         */
        unsigned short      FMD         : 4;
        unsigned short      reserved_1  : 4;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} UANBR_REG;

/// UART Ch.N Control Register
typedef union UANCTL_REG_TAG {
    unsigned short  reg;
    struct UANCTL_REG_BIT_TAG {
        /**
         * This bit enables the UART operations.
         * .MODEN
         *  This bit enables the UART operations.
         *    1 (R/W): Enable UART operations (The operating clock is supplied.)
         *    0 (R/W): Disable UART operations (The operating clock is stopped.)
         */
        unsigned short      MODEN       : 1;
        /**
         * This bit issues software reset to the UART.
         * .SFTRST
         *  This bit issues software reset to the UART.
         *    1 (W): Issue software reset
         *    0 (W): Ineffective
         *    1 (R): Software reset is executing.
         *    0 (R): Software reset has finished. (During normal operation)
         */
        unsigned short      SFTRST      : 1;
        unsigned short      reserved_1  :14;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} UANCTL_REG;

/// UART Ch.N Transmit Data Register
typedef union UANTXD_REG_TAG {
    unsigned short  reg;
    struct UANTXD_REG_BIT_TAG {
        /**
         * Data can be written to the transmit data buffer through these bits.
         * .TXD[7:0]
         *  Data can be written to the transmit data buffer through these bits. Make sure the UAnINTF.TBEIF bit is set to 1 before writing data.
         */
        unsigned short      TXD         : 8;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} UANTXD_REG;

/// UART Ch.N Receive Data Register
typedef union UANRXD_REG_TAG {
    unsigned short  reg;
    struct UANRXD_REG_BIT_TAG {
        /**
         * The receive data buffer can be read through these bits.
         * .RXD[7:0]
         *  The receive data buffer can be read through these bits. The receive data buffer consists of a 2-byte FIFO, and older received data is read first.
         */
        unsigned short      RXD         : 8;
        unsigned short      reserved_1  : 8;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} UANRXD_REG;

/// UART Ch.N Status and Interrupt Flag Register
typedef union UANINTF_REG_TAG {
    unsigned short  reg;
    struct UANINTF_REG_BIT_TAG {
        /**
         * This bit indicate Transmit buffer empty interrupt cause occurrence status.
         * .TBEIF
         *  This bit indicate Transmit buffer empty interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      TBEIF       : 1;
        /**
         * This bit indicate Receive buffer one byte full interrupt cause occurrence status.
         * .RB1FIF
         *  This bit indicate Receive buffer one byte full interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      RB1FIF      : 1;
        /**
         * This bit indicate Receive buffer two bytes full interrupt cause occurrence status.
         * .RB2FIF
         *  This bit indicate Receive buffer two bytes full interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      RB2FIF      : 1;
        /**
         * This bit indicate Overrun error interrupt cause occurrence status.
         * .OEIF
         *  This bit indicate Overrun error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      OEIF        : 1;
        /**
         * This bit indicate Parity error interrupt cause occurrence status.
         * .PEIF
         *  This bit indicate Parity error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      PEIF        : 1;
        /**
         * This bit indicate Framing error interrupt cause occurrence status.
         * .FEIF
         *  This bit indicate Framing error interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      FEIF        : 1;
        /**
         * This bit indicate End-of-transmission interrupt cause occurrence status.
         * .TENDIF
         *  This bit indicate End-of-transmission interrupt cause occurrence status.
         *    1 (R): Cause of interrupt occurred
         *    0 (R): No cause of interrupt occurred
         *    1 (W): Clear flag
         *    0 (W): Ineffective
         */
        unsigned short      TENDIF      : 1;
        unsigned short      reserved_1  : 1;    ///< Reserved.
        /**
         * This bit indicates the sending status.
         * .TBSY
         *  This bit indicates the sending status.
         *    1 (R): During sending
         *    0 (R): Idle
         */
        unsigned short      TBSY        : 1;
        /**
         * This bit indicates the receiving status.
         * .RBSY
         *  This bit indicates the receiving status.
         *    1 (R): During receiving
         *    0 (R): Idle
         */
        unsigned short      RBSY        : 1;
        unsigned short      reserved_2  : 6;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} UANINTF_REG;

/// UART Ch.N Interrupt Enable Register
typedef union UANINTE_REG_TAG {
    unsigned short  reg;
    struct UANINTE_REG_BIT_TAG {
        /**
         * This bit enable Transmit buffer empty interrupt.
         * .TBEIE
         *  This bit enable Transmit buffer empty interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      TBEIE       : 1;
        /**
         * This bit enable Receive buffer one byte full interrupt.
         * .RB1FIE
         *  This bit enable Receive buffer one byte full interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      RB1FIE      : 1;
        /**
         * This bit enable Receive buffer two bytes full interrupt.
         * .RB2FIE
         *  This bit enable Receive buffer two bytes full interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      RB2FIE      : 1;
        /**
         * This bit enable Overrun error interrupt.
         * .OEIE
         *  This bit enable Overrun error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      OEIE        : 1;
        /**
         * This bit enable Parity error interrupt.
         * .PEIE
         *  This bit enable Parity error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      PEIE        : 1;
        /**
         * This bit enable Framing error interrupt.
         * .FEIE
         *  This bit enable Framing error interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      FEIE        : 1;
        /**
         * This bit enable End-of-transmission interrupt.
         * .TENDIE
         *  This bit enable End-of-transmission interrupt.
         *    1 (R/W): Enable interrupts
         *    0 (R/W): Disable interrupts
         */
        unsigned short      TENDIE      : 1;
        unsigned short      reserved_1  : 9;    ///< Reserved.
    } bit;
    unsigned char   byte_reg[2];
} UANINTE_REG;

#ifdef __cplusplus
}
#endif

#endif // UART_REG_H__
