/************************************************************************//**
 *
 * @file    c17_port.c
 *
 * @brief   This is Port program.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Oct. 2017    1.10
 *              - Change source code.
 *          - 01 Nov. 2018    1.20
 *              - Change source code.
 *
 ***************************************************************************/
#include "crt0.h"
#include "c17_misc.h"
#include "c17_port_w18.h"
#include "c17_init_config.h"

#if defined(C17_PE_PORT)
/* --- interrupt handler (GNU17v3 Only) --- */
#ifdef CRT0_LINKED
C17_INTERRUPT_HANDLER(_vector05_handler, c17intPortInput);		// PPORT interrupt
#endif /* CRT0_LINKED */


/* --- static const variable --- */
static const unsigned short highByteTable[8] = {0x0100,0x0200,0x0400,0x0800,0x1000,0x2000,0x4000,0x8000};
static const unsigned short lowByteTable[8]  = {0x0001,0x0002,0x0004,0x0008,0x0010,0x0020,0x0040,0x0080};

/* --- macro definition --- */
#define HIGHBYTE_BIT_SET(portno)	(highByteTable[portno])		///- portno = 0 to 7
#define LOWBYTE_BIT_SET(portno)		(lowByteTable[portno])		///- portno = 0 to 7


/* --- static  function --- */
static inline void intInputP0x(P0INTF_REG* p0nif_get);
static inline void intInputP1x(P1INTF_REG* p1nif_get);
static inline void intInputP2x(P2INTF_REG* p2nif_get);
static inline void intInputP3x(P3INTF_REG* p3nif_get);
static inline void intInputP4x(P4INTF_REG* p4nif_get);
static inline void intInputP5x(P5INTF_REG* p5nif_get);
static inline void intInputP6x(P6INTF_REG* p6nif_get);
static inline void intInputP7x(P7INTF_REG* p7nif_get);
static inline void intInputP8x(P8INTF_REG* p8nif_get);

static void enableIntPxx(unsigned short portNo, unsigned short portIntEdge, P0INTCTL_REG* portRegister);
static void disableIntPxx(unsigned short portNo, P0INTCTL_REG* portRegister);
static unsigned char getOutputPxx(unsigned short portNo, P0DAT_REG* portRegister);
static void setOutputPxx(unsigned short portNo, unsigned short portData, P0DAT_REG* portRegister);
static void setOutputPxxByte(unsigned char portData, P0DAT_REG* portRegister);
static unsigned char getInputPxx(unsigned short portNo, P0DAT_REG* portRegister);
static void setChattaPxx(unsigned short portNo, unsigned short portChatta, P0CHATEN_REG* portRegister);
static void setPullUpDownPxx(unsigned short portNo, unsigned short portPull, P0RCTL_REG* portRegister);
static void setDirectionPxx(unsigned short portNo, unsigned short portDir, P0IOEN_REG* portRegister);

/* --- global variable --- */
// Interrupt flag.
/**
 * @todo c17portP0xIntInputFlag = Port P0x interrupt flag
 */
volatile unsigned short c17portP0xIntInputFlag = 0;				///< Port P0x interrupt flag.

/************************************************************************//**
 * @brief   Initialization of the PORT Register.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17initPort(void)
{
	PCLK_REG		pclk_set;

	P0INTCTL_REG	p0intctl_set;
	P0CHATEN_REG	p0chaten_set;
	P0IOEN_REG		p0ioen_set;
	P0RCTL_REG		p0rctl_set;
	P0MODSEL_REG	p0modsel_set;

	P1INTCTL_REG	p1intctl_set;
	P1CHATEN_REG	p1chaten_set;
	P1IOEN_REG		p1ioen_set;
	P1RCTL_REG		p1rctl_set;
	P1MODSEL_REG	p1modsel_set;

	P2INTCTL_REG	p2intctl_set;
	P2CHATEN_REG	p2chaten_set;
	P2IOEN_REG		p2ioen_set;
	P2RCTL_REG		p2rctl_set;
	P2MODSEL_REG	p2modsel_set;

	P3INTCTL_REG	p3intctl_set;
	P3CHATEN_REG	p3chaten_set;
	P3IOEN_REG		p3ioen_set;
	P3RCTL_REG		p3rctl_set;
	P3MODSEL_REG	p3modsel_set;

	P4INTCTL_REG	p4intctl_set;
	P4CHATEN_REG	p4chaten_set;
	P4IOEN_REG		p4ioen_set;
	P4RCTL_REG		p4rctl_set;

	P5INTCTL_REG	p5intctl_set;
	P5CHATEN_REG	p5chaten_set;
	P5IOEN_REG		p5ioen_set;
	P5RCTL_REG		p5rctl_set;

	P6INTCTL_REG	p6intctl_set;
	P6CHATEN_REG	p6chaten_set;
	P6IOEN_REG		p6ioen_set;
	P6RCTL_REG		p6rctl_set;
	P6MODSEL_REG	p6modsel_set;

	P7INTCTL_REG	p7intctl_set;
	P7CHATEN_REG	p7chaten_set;
	P7IOEN_REG		p7ioen_set;
	P7RCTL_REG		p7rctl_set;
	P7MODSEL_REG	p7modsel_set;

	P8INTCTL_REG	p8intctl_set;
	P8CHATEN_REG	p8chaten_set;
	P8IOEN_REG		p8ioen_set;
	P8RCTL_REG		p8rctl_set;
	P8MODSEL_REG	p8modsel_set;

	PDIOEN_REG		pdioen_set;
	PDRCTL_REG		pdrctl_set;
	PDMODSEL_REG	pdmodsel_set;

	/* P0INTCTL: disable port input interrupt. */
	{
		p0intctl_set.reg = 0;
		p0intctl_set.bit.P07IE = 0;
		p0intctl_set.bit.P06IE = 0;
		p0intctl_set.bit.P05IE = 0;
		p0intctl_set.bit.P04IE = 0;
		p0intctl_set.bit.P03IE = 0;
		p0intctl_set.bit.P02IE = 0;
		p0intctl_set.bit.P01IE = 0;
		p0intctl_set.bit.P00IE = 0;
		P0INTCTL = p0intctl_set.reg;
	}
	/* P1INTCTL: disable port input interrupt. */
	{
		p1intctl_set.reg = 0;
		p1intctl_set.bit.P17IE = 0;
		p1intctl_set.bit.P16IE = 0;
		p1intctl_set.bit.P15IE = 0;
		p1intctl_set.bit.P14IE = 0;
		p1intctl_set.bit.P13IE = 0;
		p1intctl_set.bit.P12IE = 0;
		p1intctl_set.bit.P11IE = 0;
		p1intctl_set.bit.P10IE = 0;
		P1INTCTL = p1intctl_set.reg;
	}
	/* P2INTCTL: disable port input interrupt. */
	{
		p2intctl_set.reg = 0;
		p2intctl_set.bit.P27IE = 0;
		p2intctl_set.bit.P26IE = 0;
		p2intctl_set.bit.P25IE = 0;
		p2intctl_set.bit.P24IE = 0;
		p2intctl_set.bit.P23IE = 0;
		p2intctl_set.bit.P22IE = 0;
		p2intctl_set.bit.P21IE = 0;
		p2intctl_set.bit.P20IE = 0;
		P2INTCTL = p2intctl_set.reg;
	}
	/* P3INTCTL: disable port input interrupt. */
	{
		p3intctl_set.reg = 0;
		p3intctl_set.bit.P37IE = 0;
		p3intctl_set.bit.P36IE = 0;
		p3intctl_set.bit.P35IE = 0;
		p3intctl_set.bit.P34IE = 0;
		p3intctl_set.bit.P33IE = 0;
		p3intctl_set.bit.P32IE = 0;
		p3intctl_set.bit.P31IE = 0;
		p3intctl_set.bit.P30IE = 0;
		P3INTCTL = p3intctl_set.reg;
	}
	/* P4INTCTL: disable port input interrupt. */
	{
		p4intctl_set.reg = 0;
		p4intctl_set.bit.P47IE = 0;
		p4intctl_set.bit.P46IE = 0;
		p4intctl_set.bit.P45IE = 0;
		p4intctl_set.bit.P44IE = 0;
		p4intctl_set.bit.P43IE = 0;
		p4intctl_set.bit.P42IE = 0;
		p4intctl_set.bit.P41IE = 0;
		p4intctl_set.bit.P40IE = 0;
		P4INTCTL = p4intctl_set.reg;
	}
	/* P5INTCTL: disable port input interrupt. */
	{
		p5intctl_set.reg = 0;
		p5intctl_set.bit.P52IE = 0;
		p5intctl_set.bit.P51IE = 0;
		p5intctl_set.bit.P50IE = 0;
		P5INTCTL = p5intctl_set.reg;
	}
	/* P6INTCTL: disable port input interrupt. */
	{
		p6intctl_set.reg = 0;
		p6intctl_set.bit.P67IE = 0;
		p6intctl_set.bit.P66IE = 0;
		p6intctl_set.bit.P65IE = 0;
		p6intctl_set.bit.P64IE = 0;
		p6intctl_set.bit.P63IE = 0;
		p6intctl_set.bit.P62IE = 0;
		p6intctl_set.bit.P61IE = 0;
		p6intctl_set.bit.P60IE = 0;
		P6INTCTL = p6intctl_set.reg;
	}
	/* P7INTCTL: disable port input interrupt. */
	{
		p7intctl_set.reg = 0;
		p7intctl_set.bit.P73IE = 0;
		p7intctl_set.bit.P72IE = 0;
		p7intctl_set.bit.P71IE = 0;
		p7intctl_set.bit.P70IE = 0;
		P7INTCTL = p7intctl_set.reg;
	}
	/* P8INTCTL: disable port input interrupt. */
	{
		p8intctl_set.reg = 0;
		p8intctl_set.bit.P87IE = 0;
		p8intctl_set.bit.P86IE = 0;
		p8intctl_set.bit.P85IE = 0;
		p8intctl_set.bit.P84IE = 0;
		p8intctl_set.bit.P83IE = 0;
		p8intctl_set.bit.P82IE = 0;
		p8intctl_set.bit.P81IE = 0;
		p8intctl_set.bit.P80IE = 0;
		P8INTCTL = p8intctl_set.reg;
	}

	/// Disable write-protect.
	c17protectMiscOff();

	/* PCLK: P Port Clock Control Register */
	{
      /**
       * @todo Change CLKSRC & CLKDIV
       */
		// When using the chattering filter, configure the PPORT operating clock
		{
			pclk_set.bit.DBRUN = 1;			/// - Clock supplied in DEBUG mode.
			pclk_set.bit.CLKDIV = 4;		/// - Set division ratio for clock source(1/16).
			pclk_set.bit.KRSTCFG = 0;		/// - Configure the key-entry reset function.
			pclk_set.bit.CLKSRC = 0;		/// - Set clock source for chattering filter(IOSC).
			PCLK = pclk_set.reg;
		}
	}

	/// Enable write-protect.
	c17protectMiscOn();

	/* P0CHATEN: P0 Port Chattering Filter Enable Register */
	{
		p0chaten_set.reg = 0;
		p0chaten_set.bit.P07CHATEN = (PORT07_INIT & 0x20) ? 1:0;
		p0chaten_set.bit.P06CHATEN = (PORT06_INIT & 0x20) ? 1:0;
		p0chaten_set.bit.P05CHATEN = (PORT05_INIT & 0x20) ? 1:0;
		p0chaten_set.bit.P04CHATEN = (PORT04_INIT & 0x20) ? 1:0;
		p0chaten_set.bit.P03CHATEN = (PORT03_INIT & 0x20) ? 1:0;
		p0chaten_set.bit.P02CHATEN = (PORT02_INIT & 0x20) ? 1:0;
		p0chaten_set.bit.P01CHATEN = (PORT01_INIT & 0x20) ? 1:0;
		p0chaten_set.bit.P00CHATEN = (PORT00_INIT & 0x20) ? 1:0;
		P0CHATEN = p0chaten_set.reg;
	}
	/* P1CHATEN: P1 Port Chattering Filter Enable Register */
	{
		p1chaten_set.reg = 0;
		p1chaten_set.bit.P17CHATEN = (PORT17_INIT & 0x20) ? 1:0;
		p1chaten_set.bit.P16CHATEN = (PORT16_INIT & 0x20) ? 1:0;
		p1chaten_set.bit.P15CHATEN = (PORT15_INIT & 0x20) ? 1:0;
		p1chaten_set.bit.P14CHATEN = (PORT14_INIT & 0x20) ? 1:0;
		p1chaten_set.bit.P13CHATEN = (PORT13_INIT & 0x20) ? 1:0;
		p1chaten_set.bit.P12CHATEN = (PORT12_INIT & 0x20) ? 1:0;
		p1chaten_set.bit.P11CHATEN = (PORT11_INIT & 0x20) ? 1:0;
		p1chaten_set.bit.P10CHATEN = (PORT10_INIT & 0x20) ? 1:0;
		P1CHATEN = p1chaten_set.reg;
	}
	/* P2CHATEN: P2 Port Chattering Filter Enable Register */
	{
		p2chaten_set.reg = 0;
		p2chaten_set.bit.P27CHATEN = (PORT27_INIT & 0x20) ? 1:0;
		p2chaten_set.bit.P26CHATEN = (PORT26_INIT & 0x20) ? 1:0;
		p2chaten_set.bit.P25CHATEN = (PORT25_INIT & 0x20) ? 1:0;
		p2chaten_set.bit.P24CHATEN = (PORT24_INIT & 0x20) ? 1:0;
		p2chaten_set.bit.P23CHATEN = (PORT23_INIT & 0x20) ? 1:0;
		p2chaten_set.bit.P22CHATEN = (PORT22_INIT & 0x20) ? 1:0;
		p2chaten_set.bit.P21CHATEN = (PORT21_INIT & 0x20) ? 1:0;
		p2chaten_set.bit.P20CHATEN = (PORT20_INIT & 0x20) ? 1:0;
		P2CHATEN = p2chaten_set.reg;
	}
	/* P3CHATEN: P3 Port Chattering Filter Enable Register */
	{
		p3chaten_set.reg = 0;
		p3chaten_set.bit.P37CHATEN = (PORT37_INIT & 0x20) ? 1:0;
		p3chaten_set.bit.P36CHATEN = (PORT36_INIT & 0x20) ? 1:0;
		p3chaten_set.bit.P35CHATEN = (PORT35_INIT & 0x20) ? 1:0;
		p3chaten_set.bit.P34CHATEN = (PORT34_INIT & 0x20) ? 1:0;
		p3chaten_set.bit.P33CHATEN = (PORT33_INIT & 0x20) ? 1:0;
		p3chaten_set.bit.P32CHATEN = (PORT32_INIT & 0x20) ? 1:0;
		p3chaten_set.bit.P31CHATEN = (PORT31_INIT & 0x20) ? 1:0;
		p3chaten_set.bit.P30CHATEN = (PORT30_INIT & 0x20) ? 1:0;
		P3CHATEN = p3chaten_set.reg;
	}
	/* P4CHATEN: P4 Port Chattering Filter Enable Register */
	{
		p4chaten_set.reg = 0;
		p4chaten_set.bit.P47CHATEN = (PORT47_INIT & 0x20) ? 1:0;
		p4chaten_set.bit.P46CHATEN = (PORT46_INIT & 0x20) ? 1:0;
		p4chaten_set.bit.P45CHATEN = (PORT45_INIT & 0x20) ? 1:0;
		p4chaten_set.bit.P44CHATEN = (PORT44_INIT & 0x20) ? 1:0;
		p4chaten_set.bit.P43CHATEN = (PORT43_INIT & 0x20) ? 1:0;
		p4chaten_set.bit.P42CHATEN = (PORT42_INIT & 0x20) ? 1:0;
		p4chaten_set.bit.P41CHATEN = (PORT41_INIT & 0x20) ? 1:0;
		p4chaten_set.bit.P40CHATEN = (PORT40_INIT & 0x20) ? 1:0;
		P4CHATEN = p4chaten_set.reg;
	}
	/* P5CHATEN: P5 Port Chattering Filter Enable Register */
	{
		p5chaten_set.reg = 0;
		p5chaten_set.bit.P52CHATEN = (PORT52_INIT & 0x20) ? 1:0;
		p5chaten_set.bit.P51CHATEN = (PORT51_INIT & 0x20) ? 1:0;
		p5chaten_set.bit.P50CHATEN = (PORT50_INIT & 0x20) ? 1:0;
		P5CHATEN = p5chaten_set.reg;
	}
	/* P6CHATEN: P6 Port Chattering Filter Enable Register */
	{
		p6chaten_set.reg = 0;
		p6chaten_set.bit.P67CHATEN = (PORT67_INIT & 0x20) ? 1:0;
		p6chaten_set.bit.P66CHATEN = (PORT66_INIT & 0x20) ? 1:0;
		p6chaten_set.bit.P65CHATEN = (PORT65_INIT & 0x20) ? 1:0;
		p6chaten_set.bit.P64CHATEN = (PORT64_INIT & 0x20) ? 1:0;
		p6chaten_set.bit.P63CHATEN = (PORT63_INIT & 0x20) ? 1:0;
		p6chaten_set.bit.P62CHATEN = (PORT62_INIT & 0x20) ? 1:0;
		p6chaten_set.bit.P61CHATEN = (PORT61_INIT & 0x20) ? 1:0;
		p6chaten_set.bit.P60CHATEN = (PORT60_INIT & 0x20) ? 1:0;
		P6CHATEN = p6chaten_set.reg;
	}
	/* P7CHATEN: P7 Port Chattering Filter Enable Register */
	{
		p7chaten_set.reg = 0;
		p7chaten_set.bit.P73CHATEN = (PORT73_INIT & 0x20) ? 1:0;
		p7chaten_set.bit.P72CHATEN = (PORT72_INIT & 0x20) ? 1:0;
		p7chaten_set.bit.P71CHATEN = (PORT71_INIT & 0x20) ? 1:0;
		p7chaten_set.bit.P70CHATEN = (PORT70_INIT & 0x20) ? 1:0;
		P7CHATEN = p7chaten_set.reg;
	}
	/* P8CHATEN: P8 Port Chattering Filter Enable Register */
	{
		p8chaten_set.reg = 0;
		p8chaten_set.bit.P87CHATEN = (PORT87_INIT & 0x20) ? 1:0;
		p8chaten_set.bit.P86CHATEN = (PORT86_INIT & 0x20) ? 1:0;
		p8chaten_set.bit.P85CHATEN = (PORT85_INIT & 0x20) ? 1:0;
		p8chaten_set.bit.P84CHATEN = (PORT84_INIT & 0x20) ? 1:0;
		p8chaten_set.bit.P83CHATEN = (PORT83_INIT & 0x20) ? 1:0;
		p8chaten_set.bit.P82CHATEN = (PORT82_INIT & 0x20) ? 1:0;
		p8chaten_set.bit.P81CHATEN = (PORT81_INIT & 0x20) ? 1:0;
		p8chaten_set.bit.P80CHATEN = (PORT80_INIT & 0x20) ? 1:0;
		P8CHATEN = p8chaten_set.reg;
	}

	/* P0IOEN:P0 Port Enable Register */
	{
		p0ioen_set.bit.P07IEN = (((PORT07_INIT & 0x80) == 0x80) && ((PORT07_INIT & 0x40)==0x00)) ? 1:0;
		p0ioen_set.bit.P06IEN = (((PORT06_INIT & 0x80) == 0x80) && ((PORT06_INIT & 0x40)==0x00)) ? 1:0;
		p0ioen_set.bit.P05IEN = (((PORT05_INIT & 0x80) == 0x80) && ((PORT05_INIT & 0x40)==0x00)) ? 1:0;
		p0ioen_set.bit.P04IEN = (((PORT04_INIT & 0x80) == 0x80) && ((PORT04_INIT & 0x40)==0x00)) ? 1:0;
		p0ioen_set.bit.P03IEN = (((PORT03_INIT & 0x80) == 0x80) && ((PORT03_INIT & 0x40)==0x00)) ? 1:0;
		p0ioen_set.bit.P02IEN = (((PORT02_INIT & 0x80) == 0x80) && ((PORT02_INIT & 0x40)==0x00)) ? 1:0;
		p0ioen_set.bit.P01IEN = (((PORT01_INIT & 0x80) == 0x80) && ((PORT01_INIT & 0x40)==0x00)) ? 1:0;
		p0ioen_set.bit.P00IEN = (((PORT00_INIT & 0x80) == 0x80) && ((PORT00_INIT & 0x40)==0x00)) ? 1:0;

		p0ioen_set.bit.P07OEN = (((PORT07_INIT & 0x80) == 0x80) && ((PORT07_INIT & 0x40)==0x40)) ? 1:0;
		p0ioen_set.bit.P06OEN = (((PORT06_INIT & 0x80) == 0x80) && ((PORT06_INIT & 0x40)==0x40)) ? 1:0;
		p0ioen_set.bit.P05OEN = (((PORT05_INIT & 0x80) == 0x80) && ((PORT05_INIT & 0x40)==0x40)) ? 1:0;
		p0ioen_set.bit.P04OEN = (((PORT04_INIT & 0x80) == 0x80) && ((PORT04_INIT & 0x40)==0x40)) ? 1:0;
		p0ioen_set.bit.P03OEN = (((PORT03_INIT & 0x80) == 0x80) && ((PORT03_INIT & 0x40)==0x40)) ? 1:0;
		p0ioen_set.bit.P02OEN = (((PORT02_INIT & 0x80) == 0x80) && ((PORT02_INIT & 0x40)==0x40)) ? 1:0;
		p0ioen_set.bit.P01OEN = (((PORT01_INIT & 0x80) == 0x80) && ((PORT01_INIT & 0x40)==0x40)) ? 1:0;
		p0ioen_set.bit.P00OEN = (((PORT00_INIT & 0x80) == 0x80) && ((PORT00_INIT & 0x40)==0x40)) ? 1:0;
		P0IOEN = p0ioen_set.reg;
	}
	/* P1IOEN:P1 Port Enable Register */
	{
		p1ioen_set.bit.P17IEN =  (((PORT17_INIT & 0x80) == 0x80) && ((PORT17_INIT & 0x40)==0x00)) ? 1:0;
		p1ioen_set.bit.P16IEN =  (((PORT16_INIT & 0x80) == 0x80) && ((PORT16_INIT & 0x40)==0x00)) ? 1:0;
		p1ioen_set.bit.P15IEN =  (((PORT15_INIT & 0x80) == 0x80) && ((PORT15_INIT & 0x40)==0x00)) ? 1:0;
		p1ioen_set.bit.P14IEN =  (((PORT14_INIT & 0x80) == 0x80) && ((PORT14_INIT & 0x40)==0x00)) ? 1:0;
		p1ioen_set.bit.P13IEN =  (((PORT13_INIT & 0x80) == 0x80) && ((PORT13_INIT & 0x40)==0x00)) ? 1:0;
		p1ioen_set.bit.P12IEN =  (((PORT12_INIT & 0x80) == 0x80) && ((PORT12_INIT & 0x40)==0x00)) ? 1:0;
		p1ioen_set.bit.P11IEN =  (((PORT11_INIT & 0x80) == 0x80) && ((PORT11_INIT & 0x40)==0x00)) ? 1:0;
		p1ioen_set.bit.P10IEN =  (((PORT10_INIT & 0x80) == 0x80) && ((PORT10_INIT & 0x40)==0x00)) ? 1:0;

		p1ioen_set.bit.P17OEN =  (((PORT17_INIT & 0x80) == 0x80) && ((PORT17_INIT & 0x40)==0x40)) ? 1:0;
		p1ioen_set.bit.P16OEN =  (((PORT16_INIT & 0x80) == 0x80) && ((PORT16_INIT & 0x40)==0x40)) ? 1:0;
		p1ioen_set.bit.P15OEN =  (((PORT15_INIT & 0x80) == 0x80) && ((PORT15_INIT & 0x40)==0x40)) ? 1:0;
		p1ioen_set.bit.P14OEN =  (((PORT14_INIT & 0x80) == 0x80) && ((PORT14_INIT & 0x40)==0x40)) ? 1:0;
		p1ioen_set.bit.P13OEN =  (((PORT13_INIT & 0x80) == 0x80) && ((PORT13_INIT & 0x40)==0x40)) ? 1:0;
		p1ioen_set.bit.P12OEN =  (((PORT12_INIT & 0x80) == 0x80) && ((PORT12_INIT & 0x40)==0x40)) ? 1:0;
		p1ioen_set.bit.P11OEN =  (((PORT11_INIT & 0x80) == 0x80) && ((PORT11_INIT & 0x40)==0x40)) ? 1:0;
		p1ioen_set.bit.P10OEN =  (((PORT10_INIT & 0x80) == 0x80) && ((PORT10_INIT & 0x40)==0x40)) ? 1:0;
		P1IOEN = p1ioen_set.reg;
	}
	/* P2IOEN:P2 Port Enable Register */
	{
		p2ioen_set.bit.P27IEN = (((PORT27_INIT & 0x80) == 0x80) && ((PORT27_INIT & 0x40)==0x00)) ? 1:0;
		p2ioen_set.bit.P26IEN = (((PORT26_INIT & 0x80) == 0x80) && ((PORT26_INIT & 0x40)==0x00)) ? 1:0;
		p2ioen_set.bit.P25IEN = (((PORT25_INIT & 0x80) == 0x80) && ((PORT25_INIT & 0x40)==0x00)) ? 1:0;
		p2ioen_set.bit.P24IEN = (((PORT24_INIT & 0x80) == 0x80) && ((PORT24_INIT & 0x40)==0x00)) ? 1:0;
		p2ioen_set.bit.P23IEN = (((PORT23_INIT & 0x80) == 0x80) && ((PORT23_INIT & 0x40)==0x00)) ? 1:0;
		p2ioen_set.bit.P22IEN = (((PORT22_INIT & 0x80) == 0x80) && ((PORT22_INIT & 0x40)==0x00)) ? 1:0;
		p2ioen_set.bit.P21IEN = (((PORT21_INIT & 0x80) == 0x80) && ((PORT21_INIT & 0x40)==0x00)) ? 1:0;
		p2ioen_set.bit.P20IEN = (((PORT20_INIT & 0x80) == 0x80) && ((PORT20_INIT & 0x40)==0x00)) ? 1:0;

		p2ioen_set.bit.P27OEN = (((PORT27_INIT & 0x80) == 0x80) && ((PORT27_INIT & 0x40)==0x40)) ? 1:0;
		p2ioen_set.bit.P26OEN = (((PORT26_INIT & 0x80) == 0x80) && ((PORT26_INIT & 0x40)==0x40)) ? 1:0;
		p2ioen_set.bit.P25OEN = (((PORT25_INIT & 0x80) == 0x80) && ((PORT25_INIT & 0x40)==0x40)) ? 1:0;
		p2ioen_set.bit.P24OEN = (((PORT24_INIT & 0x80) == 0x80) && ((PORT24_INIT & 0x40)==0x40)) ? 1:0;
		p2ioen_set.bit.P23OEN = (((PORT23_INIT & 0x80) == 0x80) && ((PORT23_INIT & 0x40)==0x40)) ? 1:0;
		p2ioen_set.bit.P22OEN = (((PORT22_INIT & 0x80) == 0x80) && ((PORT22_INIT & 0x40)==0x40)) ? 1:0;
		p2ioen_set.bit.P21OEN = (((PORT21_INIT & 0x80) == 0x80) && ((PORT21_INIT & 0x40)==0x40)) ? 1:0;
		p2ioen_set.bit.P20OEN = (((PORT20_INIT & 0x80) == 0x80) && ((PORT20_INIT & 0x40)==0x40)) ? 1:0;
		P2IOEN = p2ioen_set.reg;
	}
	/* P3IOEN:P3 Port Enable Register */
	{
		p3ioen_set.bit.P37IEN = (((PORT37_INIT & 0x80) == 0x80) && ((PORT37_INIT & 0x40)==0x00)) ? 1:0;
		p3ioen_set.bit.P36IEN = (((PORT36_INIT & 0x80) == 0x80) && ((PORT36_INIT & 0x40)==0x00)) ? 1:0;
		p3ioen_set.bit.P35IEN = (((PORT35_INIT & 0x80) == 0x80) && ((PORT35_INIT & 0x40)==0x00)) ? 1:0;
		p3ioen_set.bit.P34IEN = (((PORT34_INIT & 0x80) == 0x80) && ((PORT34_INIT & 0x40)==0x00)) ? 1:0;
		p3ioen_set.bit.P33IEN = (((PORT33_INIT & 0x80) == 0x80) && ((PORT33_INIT & 0x40)==0x00)) ? 1:0;
		p3ioen_set.bit.P32IEN = (((PORT32_INIT & 0x80) == 0x80) && ((PORT32_INIT & 0x40)==0x00)) ? 1:0;
		p3ioen_set.bit.P31IEN = (((PORT31_INIT & 0x80) == 0x80) && ((PORT31_INIT & 0x40)==0x00)) ? 1:0;
		p3ioen_set.bit.P30IEN = (((PORT30_INIT & 0x80) == 0x80) && ((PORT30_INIT & 0x40)==0x00)) ? 1:0;

		p3ioen_set.bit.P37OEN = (((PORT37_INIT & 0x80) == 0x80) && ((PORT37_INIT & 0x40)==0x40)) ? 1:0;
		p3ioen_set.bit.P36OEN = (((PORT36_INIT & 0x80) == 0x80) && ((PORT36_INIT & 0x40)==0x40)) ? 1:0;
		p3ioen_set.bit.P35OEN = (((PORT35_INIT & 0x80) == 0x80) && ((PORT35_INIT & 0x40)==0x40)) ? 1:0;
		p3ioen_set.bit.P34OEN = (((PORT34_INIT & 0x80) == 0x80) && ((PORT34_INIT & 0x40)==0x40)) ? 1:0;
		p3ioen_set.bit.P33OEN = (((PORT33_INIT & 0x80) == 0x80) && ((PORT33_INIT & 0x40)==0x40)) ? 1:0;
		p3ioen_set.bit.P32OEN = (((PORT32_INIT & 0x80) == 0x80) && ((PORT32_INIT & 0x40)==0x40)) ? 1:0;
		p3ioen_set.bit.P31OEN = (((PORT31_INIT & 0x80) == 0x80) && ((PORT31_INIT & 0x40)==0x40)) ? 1:0;
		p3ioen_set.bit.P30OEN = (((PORT30_INIT & 0x80) == 0x80) && ((PORT30_INIT & 0x40)==0x40)) ? 1:0;
		P3IOEN = p3ioen_set.reg;
	}
	/* P4IOEN:P4 Port Enable Register */
	{
		p4ioen_set.bit.P47IEN = (((PORT47_INIT & 0x80) == 0x80) && ((PORT47_INIT & 0x40)==0x00)) ? 1:0;
		p4ioen_set.bit.P46IEN = (((PORT46_INIT & 0x80) == 0x80) && ((PORT46_INIT & 0x40)==0x00)) ? 1:0;
		p4ioen_set.bit.P45IEN = (((PORT45_INIT & 0x80) == 0x80) && ((PORT45_INIT & 0x40)==0x00)) ? 1:0;
		p4ioen_set.bit.P44IEN = (((PORT44_INIT & 0x80) == 0x80) && ((PORT44_INIT & 0x40)==0x00)) ? 1:0;
		p4ioen_set.bit.P43IEN = (((PORT43_INIT & 0x80) == 0x80) && ((PORT43_INIT & 0x40)==0x00)) ? 1:0;
		p4ioen_set.bit.P42IEN = (((PORT42_INIT & 0x80) == 0x80) && ((PORT42_INIT & 0x40)==0x00)) ? 1:0;
		p4ioen_set.bit.P41IEN = (((PORT41_INIT & 0x80) == 0x80) && ((PORT41_INIT & 0x40)==0x00)) ? 1:0;
		p4ioen_set.bit.P40IEN = (((PORT40_INIT & 0x80) == 0x80) && ((PORT40_INIT & 0x40)==0x00)) ? 1:0;

		p4ioen_set.bit.P47OEN = (((PORT47_INIT & 0x80) == 0x80) && ((PORT47_INIT & 0x40)==0x40)) ? 1:0;
		p4ioen_set.bit.P46OEN = (((PORT46_INIT & 0x80) == 0x80) && ((PORT46_INIT & 0x40)==0x40)) ? 1:0;
		p4ioen_set.bit.P45OEN = (((PORT45_INIT & 0x80) == 0x80) && ((PORT45_INIT & 0x40)==0x40)) ? 1:0;
		p4ioen_set.bit.P44OEN = (((PORT44_INIT & 0x80) == 0x80) && ((PORT44_INIT & 0x40)==0x40)) ? 1:0;
		p4ioen_set.bit.P43OEN = (((PORT43_INIT & 0x80) == 0x80) && ((PORT43_INIT & 0x40)==0x40)) ? 1:0;
		p4ioen_set.bit.P42OEN = (((PORT42_INIT & 0x80) == 0x80) && ((PORT42_INIT & 0x40)==0x40)) ? 1:0;
		p4ioen_set.bit.P41OEN = (((PORT41_INIT & 0x80) == 0x80) && ((PORT41_INIT & 0x40)==0x40)) ? 1:0;
		p4ioen_set.bit.P40OEN = (((PORT40_INIT & 0x80) == 0x80) && ((PORT40_INIT & 0x40)==0x40)) ? 1:0;
		P4IOEN = p4ioen_set.reg;
	}
	/* P5IOEN:P5 Port Enable Register */
	{
		p5ioen_set.bit.P52IEN =  (((PORT52_INIT & 0x80) == 0x80) && ((PORT52_INIT & 0x40)==0x00)) ? 1:0;
		p5ioen_set.bit.P51IEN =  (((PORT51_INIT & 0x80) == 0x80) && ((PORT51_INIT & 0x40)==0x00)) ? 1:0;
		p5ioen_set.bit.P50IEN =  (((PORT50_INIT & 0x80) == 0x80) && ((PORT50_INIT & 0x40)==0x00)) ? 1:0;

		p5ioen_set.bit.P52OEN =  (((PORT52_INIT & 0x80) == 0x80) && ((PORT52_INIT & 0x40)==0x40)) ? 1:0;
		p5ioen_set.bit.P51OEN =  (((PORT51_INIT & 0x80) == 0x80) && ((PORT51_INIT & 0x40)==0x40)) ? 1:0;
		p5ioen_set.bit.P50OEN =  (((PORT50_INIT & 0x80) == 0x80) && ((PORT50_INIT & 0x40)==0x40)) ? 1:0;
		P5IOEN = p5ioen_set.reg;
	}
	/* P6IOEN:P6 Port Enable Register */
	{
		p6ioen_set.bit.P67IEN = (((PORT67_INIT & 0x80) == 0x80) && ((PORT67_INIT & 0x40)==0x00)) ? 1:0;
		p6ioen_set.bit.P66IEN = (((PORT66_INIT & 0x80) == 0x80) && ((PORT66_INIT & 0x40)==0x00)) ? 1:0;
		p6ioen_set.bit.P65IEN = (((PORT65_INIT & 0x80) == 0x80) && ((PORT65_INIT & 0x40)==0x00)) ? 1:0;
		p6ioen_set.bit.P64IEN = (((PORT64_INIT & 0x80) == 0x80) && ((PORT64_INIT & 0x40)==0x00)) ? 1:0;
		p6ioen_set.bit.P63IEN = (((PORT63_INIT & 0x80) == 0x80) && ((PORT63_INIT & 0x40)==0x00)) ? 1:0;
		p6ioen_set.bit.P62IEN = (((PORT62_INIT & 0x80) == 0x80) && ((PORT62_INIT & 0x40)==0x00)) ? 1:0;
		p6ioen_set.bit.P61IEN = (((PORT61_INIT & 0x80) == 0x80) && ((PORT61_INIT & 0x40)==0x00)) ? 1:0;
		p6ioen_set.bit.P60IEN = (((PORT60_INIT & 0x80) == 0x80) && ((PORT60_INIT & 0x40)==0x00)) ? 1:0;

		p6ioen_set.bit.P67OEN = (((PORT67_INIT & 0x80) == 0x80) && ((PORT67_INIT & 0x40)==0x40)) ? 1:0;
		p6ioen_set.bit.P66OEN = (((PORT66_INIT & 0x80) == 0x80) && ((PORT66_INIT & 0x40)==0x40)) ? 1:0;
		p6ioen_set.bit.P65OEN = (((PORT65_INIT & 0x80) == 0x80) && ((PORT65_INIT & 0x40)==0x40)) ? 1:0;
		p6ioen_set.bit.P64OEN = (((PORT64_INIT & 0x80) == 0x80) && ((PORT64_INIT & 0x40)==0x40)) ? 1:0;
		p6ioen_set.bit.P63OEN = (((PORT63_INIT & 0x80) == 0x80) && ((PORT63_INIT & 0x40)==0x40)) ? 1:0;
		p6ioen_set.bit.P62OEN = (((PORT62_INIT & 0x80) == 0x80) && ((PORT62_INIT & 0x40)==0x40)) ? 1:0;
		p6ioen_set.bit.P61OEN = (((PORT61_INIT & 0x80) == 0x80) && ((PORT61_INIT & 0x40)==0x40)) ? 1:0;
		p6ioen_set.bit.P60OEN = (((PORT60_INIT & 0x80) == 0x80) && ((PORT60_INIT & 0x40)==0x40)) ? 1:0;
		P6IOEN = p6ioen_set.reg;
	}
	/* P7IOEN:P7 Port Enable Register */
	{
		p7ioen_set.bit.P73IEN = (((PORT73_INIT & 0x80) == 0x80) && ((PORT73_INIT & 0x40)==0x00)) ? 1:0;
		p7ioen_set.bit.P72IEN = (((PORT72_INIT & 0x80) == 0x80) && ((PORT72_INIT & 0x40)==0x00)) ? 1:0;
		p7ioen_set.bit.P71IEN = (((PORT71_INIT & 0x80) == 0x80) && ((PORT71_INIT & 0x40)==0x00)) ? 1:0;
		p7ioen_set.bit.P70IEN = (((PORT70_INIT & 0x80) == 0x80) && ((PORT70_INIT & 0x40)==0x00)) ? 1:0;

		p7ioen_set.bit.P73OEN = (((PORT73_INIT & 0x80) == 0x80) && ((PORT73_INIT & 0x40)==0x40)) ? 1:0;
		p7ioen_set.bit.P72OEN = (((PORT72_INIT & 0x80) == 0x80) && ((PORT72_INIT & 0x40)==0x40)) ? 1:0;
		p7ioen_set.bit.P71OEN = (((PORT71_INIT & 0x80) == 0x80) && ((PORT71_INIT & 0x40)==0x40)) ? 1:0;
		p7ioen_set.bit.P70OEN = (((PORT70_INIT & 0x80) == 0x80) && ((PORT70_INIT & 0x40)==0x40)) ? 1:0;
		P7IOEN = p7ioen_set.reg;
	}
	/* P8IOEN:P8 Port Enable Register */
	{
		p8ioen_set.bit.P87IEN = (((PORT87_INIT & 0x80) == 0x80) && ((PORT87_INIT & 0x40)==0x00)) ? 1:0;
		p8ioen_set.bit.P86IEN = (((PORT86_INIT & 0x80) == 0x80) && ((PORT86_INIT & 0x40)==0x00)) ? 1:0;
		p8ioen_set.bit.P85IEN = (((PORT85_INIT & 0x80) == 0x80) && ((PORT85_INIT & 0x40)==0x00)) ? 1:0;
		p8ioen_set.bit.P84IEN = (((PORT84_INIT & 0x80) == 0x80) && ((PORT84_INIT & 0x40)==0x00)) ? 1:0;
		p8ioen_set.bit.P83IEN = (((PORT83_INIT & 0x80) == 0x80) && ((PORT83_INIT & 0x40)==0x00)) ? 1:0;
		p8ioen_set.bit.P82IEN = (((PORT82_INIT & 0x80) == 0x80) && ((PORT82_INIT & 0x40)==0x00)) ? 1:0;
		p8ioen_set.bit.P81IEN = (((PORT81_INIT & 0x80) == 0x80) && ((PORT81_INIT & 0x40)==0x00)) ? 1:0;
		p8ioen_set.bit.P80IEN = (((PORT80_INIT & 0x80) == 0x80) && ((PORT80_INIT & 0x40)==0x00)) ? 1:0;

		p8ioen_set.bit.P87OEN = (((PORT87_INIT & 0x80) == 0x80) && ((PORT87_INIT & 0x40)==0x40)) ? 1:0;
		p8ioen_set.bit.P86OEN = (((PORT86_INIT & 0x80) == 0x80) && ((PORT86_INIT & 0x40)==0x40)) ? 1:0;
		p8ioen_set.bit.P85OEN = (((PORT85_INIT & 0x80) == 0x80) && ((PORT85_INIT & 0x40)==0x40)) ? 1:0;
		p8ioen_set.bit.P84OEN = (((PORT84_INIT & 0x80) == 0x80) && ((PORT84_INIT & 0x40)==0x40)) ? 1:0;
		p8ioen_set.bit.P83OEN = (((PORT83_INIT & 0x80) == 0x80) && ((PORT83_INIT & 0x40)==0x40)) ? 1:0;
		p8ioen_set.bit.P82OEN = (((PORT82_INIT & 0x80) == 0x80) && ((PORT82_INIT & 0x40)==0x40)) ? 1:0;
		p8ioen_set.bit.P81OEN = (((PORT81_INIT & 0x80) == 0x80) && ((PORT81_INIT & 0x40)==0x40)) ? 1:0;
		p8ioen_set.bit.P80OEN = (((PORT80_INIT & 0x80) == 0x80) && ((PORT80_INIT & 0x40)==0x40)) ? 1:0;
		P8IOEN = p8ioen_set.reg;
	}
	/* PDIOEN:PD Port Enable Register */
	{
		pdioen_set.bit.PD4IEN = (((PORTD4_INIT & 0x80) == 0x80) && ((PORTD4_INIT & 0x40)==0x00)) ? 1:0;
		pdioen_set.bit.PD3IEN = (((PORTD3_INIT & 0x80) == 0x80) && ((PORTD3_INIT & 0x40)==0x00)) ? 1:0;
		pdioen_set.bit.PD1IEN = (((PORTD1_INIT & 0x80) == 0x80) && ((PORTD1_INIT & 0x40)==0x00)) ? 1:0;
		pdioen_set.bit.PD0IEN = (((PORTD0_INIT & 0x80) == 0x80) && ((PORTD0_INIT & 0x40)==0x00)) ? 1:0;

		pdioen_set.bit.PD4OEN = (((PORTD4_INIT & 0x80) == 0x80) && ((PORTD4_INIT & 0x40)==0x40)) ? 1:0;
		pdioen_set.bit.PD3OEN = (((PORTD3_INIT & 0x80) == 0x80) && ((PORTD3_INIT & 0x40)==0x40)) ? 1:0;
		pdioen_set.bit.PD1OEN = (((PORTD1_INIT & 0x80) == 0x80) && ((PORTD1_INIT & 0x40)==0x40)) ? 1:0;
		pdioen_set.bit.PD0OEN = (((PORTD0_INIT & 0x80) == 0x80) && ((PORTD0_INIT & 0x40)==0x40)) ? 1:0;
		PDIOEN = pdioen_set.reg;
	}

	/* P0RCTL_REG:P0 Port Pull-up/down Control Register */
	{
		p0rctl_set.bit.P07PDPU = ((PORT07_INIT & 0x03)==0x01) ? 1:0;
		p0rctl_set.bit.P06PDPU = ((PORT06_INIT & 0x03)==0x01) ? 1:0;
		p0rctl_set.bit.P05PDPU = ((PORT05_INIT & 0x03)==0x01) ? 1:0;
		p0rctl_set.bit.P04PDPU = ((PORT04_INIT & 0x03)==0x01) ? 1:0;
		p0rctl_set.bit.P03PDPU = ((PORT03_INIT & 0x03)==0x01) ? 1:0;
		p0rctl_set.bit.P02PDPU = ((PORT02_INIT & 0x03)==0x01) ? 1:0;
		p0rctl_set.bit.P01PDPU = ((PORT01_INIT & 0x03)==0x01) ? 1:0;
		p0rctl_set.bit.P00PDPU = ((PORT00_INIT & 0x03)==0x01) ? 1:0;

		p0rctl_set.bit.P07REN = ((PORT07_INIT & 0x03)==0x00) ? 0:1;
		p0rctl_set.bit.P06REN = ((PORT06_INIT & 0x03)==0x00) ? 0:1;
		p0rctl_set.bit.P05REN = ((PORT05_INIT & 0x03)==0x00) ? 0:1;
		p0rctl_set.bit.P04REN = ((PORT04_INIT & 0x03)==0x00) ? 0:1;
		p0rctl_set.bit.P03REN = ((PORT03_INIT & 0x03)==0x00) ? 0:1;
		p0rctl_set.bit.P02REN = ((PORT02_INIT & 0x03)==0x00) ? 0:1;
		p0rctl_set.bit.P01REN = ((PORT01_INIT & 0x03)==0x00) ? 0:1;
		p0rctl_set.bit.P00REN = ((PORT00_INIT & 0x03)==0x00) ? 0:1;
		P0RCTL = p0rctl_set.reg;
	}
	/* P1RCTL_REG:P1 Port Pull-up/down Control Register */
	{
		p1rctl_set.bit.P17PDPU = ((PORT17_INIT & 0x03)==0x01) ? 1:0;
		p1rctl_set.bit.P16PDPU = ((PORT16_INIT & 0x03)==0x01) ? 1:0;
		p1rctl_set.bit.P15PDPU = ((PORT15_INIT & 0x03)==0x01) ? 1:0;
		p1rctl_set.bit.P14PDPU = ((PORT14_INIT & 0x03)==0x01) ? 1:0;
		p1rctl_set.bit.P13PDPU = ((PORT13_INIT & 0x03)==0x01) ? 1:0;
		p1rctl_set.bit.P12PDPU = ((PORT12_INIT & 0x03)==0x01) ? 1:0;
		p1rctl_set.bit.P11PDPU = ((PORT11_INIT & 0x03)==0x01) ? 1:0;
		p1rctl_set.bit.P10PDPU = ((PORT10_INIT & 0x03)==0x01) ? 1:0;

		p1rctl_set.bit.P17REN = ((PORT17_INIT & 0x03)==0x00) ? 0:1;
		p1rctl_set.bit.P16REN = ((PORT16_INIT & 0x03)==0x00) ? 0:1;
		p1rctl_set.bit.P15REN = ((PORT15_INIT & 0x03)==0x00) ? 0:1;
		p1rctl_set.bit.P14REN = ((PORT14_INIT & 0x03)==0x00) ? 0:1;
		p1rctl_set.bit.P13REN = ((PORT13_INIT & 0x03)==0x00) ? 0:1;
		p1rctl_set.bit.P12REN = ((PORT12_INIT & 0x03)==0x00) ? 0:1;
		p1rctl_set.bit.P11REN = ((PORT11_INIT & 0x03)==0x00) ? 0:1;
		p1rctl_set.bit.P10REN = ((PORT10_INIT & 0x03)==0x00) ? 0:1;
		P1RCTL = p1rctl_set.reg;
	}
	/* P2RCTL_REG:P2 Port Pull-up/down Control Register */
	{
		p2rctl_set.bit.P27PDPU = ((PORT27_INIT & 0x03)==0x01) ? 1:0;
		p2rctl_set.bit.P26PDPU = ((PORT26_INIT & 0x03)==0x01) ? 1:0;
		p2rctl_set.bit.P25PDPU = ((PORT25_INIT & 0x03)==0x01) ? 1:0;
		p2rctl_set.bit.P24PDPU = ((PORT24_INIT & 0x03)==0x01) ? 1:0;
		p2rctl_set.bit.P23PDPU = ((PORT23_INIT & 0x03)==0x01) ? 1:0;
		p2rctl_set.bit.P22PDPU = ((PORT22_INIT & 0x03)==0x01) ? 1:0;
		p2rctl_set.bit.P21PDPU = ((PORT21_INIT & 0x03)==0x01) ? 1:0;
		p2rctl_set.bit.P20PDPU = ((PORT20_INIT & 0x03)==0x01) ? 1:0;

		p2rctl_set.bit.P27REN = ((PORT27_INIT & 0x03)==0x00) ? 0:1;
		p2rctl_set.bit.P26REN = ((PORT26_INIT & 0x03)==0x00) ? 0:1;
		p2rctl_set.bit.P25REN = ((PORT25_INIT & 0x03)==0x00) ? 0:1;
		p2rctl_set.bit.P24REN = ((PORT24_INIT & 0x03)==0x00) ? 0:1;
		p2rctl_set.bit.P23REN = ((PORT23_INIT & 0x03)==0x00) ? 0:1;
		p2rctl_set.bit.P22REN = ((PORT22_INIT & 0x03)==0x00) ? 0:1;
		p2rctl_set.bit.P21REN = ((PORT21_INIT & 0x03)==0x00) ? 0:1;
		p2rctl_set.bit.P20REN = ((PORT20_INIT & 0x03)==0x00) ? 0:1;
		P2RCTL = p2rctl_set.reg;
	}
	/* P3RCTL_REG:P3 Port Pull-up/down Control Register */
	{
		p3rctl_set.bit.P37PDPU = ((PORT37_INIT & 0x03)==0x01) ? 1:0;
		p3rctl_set.bit.P36PDPU = ((PORT36_INIT & 0x03)==0x01) ? 1:0;
		p3rctl_set.bit.P35PDPU = ((PORT35_INIT & 0x03)==0x01) ? 1:0;
		p3rctl_set.bit.P34PDPU = ((PORT34_INIT & 0x03)==0x01) ? 1:0;
		p3rctl_set.bit.P33PDPU = ((PORT33_INIT & 0x03)==0x01) ? 1:0;
		p3rctl_set.bit.P32PDPU = ((PORT32_INIT & 0x03)==0x01) ? 1:0;
		p3rctl_set.bit.P31PDPU = ((PORT31_INIT & 0x03)==0x01) ? 1:0;
		p3rctl_set.bit.P30PDPU = ((PORT30_INIT & 0x03)==0x01) ? 1:0;

		p3rctl_set.bit.P37REN = ((PORT37_INIT & 0x03)==0x00) ? 0:1;
		p3rctl_set.bit.P36REN = ((PORT36_INIT & 0x03)==0x00) ? 0:1;
		p3rctl_set.bit.P35REN = ((PORT35_INIT & 0x03)==0x00) ? 0:1;
		p3rctl_set.bit.P34REN = ((PORT34_INIT & 0x03)==0x00) ? 0:1;
		p3rctl_set.bit.P33REN = ((PORT33_INIT & 0x03)==0x00) ? 0:1;
		p3rctl_set.bit.P32REN = ((PORT32_INIT & 0x03)==0x00) ? 0:1;
		p3rctl_set.bit.P31REN = ((PORT31_INIT & 0x03)==0x00) ? 0:1;
		p3rctl_set.bit.P30REN = ((PORT30_INIT & 0x03)==0x00) ? 0:1;
		P3RCTL = p3rctl_set.reg;
	}
	/* P4RCTL_REG:P4 Port Pull-up/down Control Register */
	{
		p4rctl_set.bit.P47PDPU = ((PORT47_INIT & 0x03)==0x01) ? 1:0;
		p4rctl_set.bit.P46PDPU = ((PORT46_INIT & 0x03)==0x01) ? 1:0;
		p4rctl_set.bit.P45PDPU = ((PORT45_INIT & 0x03)==0x01) ? 1:0;
		p4rctl_set.bit.P44PDPU = ((PORT44_INIT & 0x03)==0x01) ? 1:0;
		p4rctl_set.bit.P43PDPU = ((PORT43_INIT & 0x03)==0x01) ? 1:0;
		p4rctl_set.bit.P42PDPU = ((PORT42_INIT & 0x03)==0x01) ? 1:0;
		p4rctl_set.bit.P41PDPU = ((PORT41_INIT & 0x03)==0x01) ? 1:0;
		p4rctl_set.bit.P40PDPU = ((PORT40_INIT & 0x03)==0x01) ? 1:0;

		p4rctl_set.bit.P47REN = ((PORT47_INIT & 0x03)==0x00) ? 0:1;
		p4rctl_set.bit.P46REN = ((PORT46_INIT & 0x03)==0x00) ? 0:1;
		p4rctl_set.bit.P45REN = ((PORT45_INIT & 0x03)==0x00) ? 0:1;
		p4rctl_set.bit.P44REN = ((PORT44_INIT & 0x03)==0x00) ? 0:1;
		p4rctl_set.bit.P43REN = ((PORT43_INIT & 0x03)==0x00) ? 0:1;
		p4rctl_set.bit.P42REN = ((PORT42_INIT & 0x03)==0x00) ? 0:1;
		p4rctl_set.bit.P41REN = ((PORT41_INIT & 0x03)==0x00) ? 0:1;
		p4rctl_set.bit.P40REN = ((PORT40_INIT & 0x03)==0x00) ? 0:1;
		P4RCTL = p4rctl_set.reg;
	}
	/* P5RCTL_REG:P5 Port Pull-up/down Control Register */
	{
		p5rctl_set.bit.P52PDPU = ((PORT52_INIT & 0x03)==0x01) ? 1:0;
		p5rctl_set.bit.P51PDPU = ((PORT51_INIT & 0x03)==0x01) ? 1:0;
		p5rctl_set.bit.P50PDPU = ((PORT50_INIT & 0x03)==0x01) ? 1:0;

		p5rctl_set.bit.P52REN = ((PORT52_INIT & 0x03)==0x00) ? 0:1;
		p5rctl_set.bit.P51REN = ((PORT51_INIT & 0x03)==0x00) ? 0:1;
		p5rctl_set.bit.P50REN = ((PORT50_INIT & 0x03)==0x00) ? 0:1;
		P5RCTL = p5rctl_set.reg;
	}
	/* P6RCTL_REG:P6 Port Pull-up/down Control Register */
	{
		p6rctl_set.bit.P67PDPU = ((PORT67_INIT & 0x03)==0x01) ? 1:0;
		p6rctl_set.bit.P66PDPU = ((PORT66_INIT & 0x03)==0x01) ? 1:0;
		p6rctl_set.bit.P65PDPU = ((PORT65_INIT & 0x03)==0x01) ? 1:0;
		p6rctl_set.bit.P64PDPU = ((PORT64_INIT & 0x03)==0x01) ? 1:0;
		p6rctl_set.bit.P63PDPU = ((PORT63_INIT & 0x03)==0x01) ? 1:0;
		p6rctl_set.bit.P62PDPU = ((PORT62_INIT & 0x03)==0x01) ? 1:0;
		p6rctl_set.bit.P61PDPU = ((PORT61_INIT & 0x03)==0x01) ? 1:0;
		p6rctl_set.bit.P60PDPU = ((PORT60_INIT & 0x03)==0x01) ? 1:0;

		p6rctl_set.bit.P67REN = ((PORT67_INIT & 0x03)==0x00) ? 0:1;
		p6rctl_set.bit.P66REN = ((PORT66_INIT & 0x03)==0x00) ? 0:1;
		p6rctl_set.bit.P65REN = ((PORT65_INIT & 0x03)==0x00) ? 0:1;
		p6rctl_set.bit.P64REN = ((PORT64_INIT & 0x03)==0x00) ? 0:1;
		p6rctl_set.bit.P63REN = ((PORT63_INIT & 0x03)==0x00) ? 0:1;
		p6rctl_set.bit.P62REN = ((PORT62_INIT & 0x03)==0x00) ? 0:1;
		p6rctl_set.bit.P61REN = ((PORT61_INIT & 0x03)==0x00) ? 0:1;
		p6rctl_set.bit.P60REN = ((PORT60_INIT & 0x03)==0x00) ? 0:1;
		P6RCTL = p6rctl_set.reg;
	}
	/* P7RCTL_REG:P7 Port Pull-up/down Control Register */
	{
		p7rctl_set.bit.P73PDPU = ((PORT73_INIT & 0x03)==0x01) ? 1:0;
		p7rctl_set.bit.P72PDPU = ((PORT72_INIT & 0x03)==0x01) ? 1:0;
		p7rctl_set.bit.P71PDPU = ((PORT71_INIT & 0x03)==0x01) ? 1:0;
		p7rctl_set.bit.P70PDPU = ((PORT70_INIT & 0x03)==0x01) ? 1:0;

		p7rctl_set.bit.P73REN = ((PORT73_INIT & 0x03)==0x00) ? 0:1;
		p7rctl_set.bit.P72REN = ((PORT72_INIT & 0x03)==0x00) ? 0:1;
		p7rctl_set.bit.P71REN = ((PORT71_INIT & 0x03)==0x00) ? 0:1;
		p7rctl_set.bit.P70REN = ((PORT70_INIT & 0x03)==0x00) ? 0:1;
		P7RCTL = p7rctl_set.reg;
	}
	/* P8RCTL_REG:P8 Port Pull-up/down Control Register */
	{
		p8rctl_set.bit.P87PDPU = ((PORT87_INIT & 0x03)==0x01) ? 1:0;
		p8rctl_set.bit.P86PDPU = ((PORT86_INIT & 0x03)==0x01) ? 1:0;
		p8rctl_set.bit.P85PDPU = ((PORT85_INIT & 0x03)==0x01) ? 1:0;
		p8rctl_set.bit.P84PDPU = ((PORT84_INIT & 0x03)==0x01) ? 1:0;
		p8rctl_set.bit.P83PDPU = ((PORT83_INIT & 0x03)==0x01) ? 1:0;
		p8rctl_set.bit.P82PDPU = ((PORT82_INIT & 0x03)==0x01) ? 1:0;
		p8rctl_set.bit.P81PDPU = ((PORT81_INIT & 0x03)==0x01) ? 1:0;
		p8rctl_set.bit.P80PDPU = ((PORT80_INIT & 0x03)==0x01) ? 1:0;

		p8rctl_set.bit.P87REN = ((PORT87_INIT & 0x03)==0x00) ? 0:1;
		p8rctl_set.bit.P86REN = ((PORT86_INIT & 0x03)==0x00) ? 0:1;
		p8rctl_set.bit.P85REN = ((PORT85_INIT & 0x03)==0x00) ? 0:1;
		p8rctl_set.bit.P84REN = ((PORT84_INIT & 0x03)==0x00) ? 0:1;
		p8rctl_set.bit.P83REN = ((PORT83_INIT & 0x03)==0x00) ? 0:1;
		p8rctl_set.bit.P82REN = ((PORT82_INIT & 0x03)==0x00) ? 0:1;
		p8rctl_set.bit.P81REN = ((PORT81_INIT & 0x03)==0x00) ? 0:1;
		p8rctl_set.bit.P80REN = ((PORT80_INIT & 0x03)==0x00) ? 0:1;
		P8RCTL = p8rctl_set.reg;
	}
	/* PDRCTL_REG:PD Port Pull-up/down Control Register */
	{
		pdrctl_set.bit.PD4PDPU = ((PORTD4_INIT & 0x03)==0x01) ? 1:0;
		pdrctl_set.bit.PD3PDPU = ((PORTD3_INIT & 0x03)==0x01) ? 1:0;
		pdrctl_set.bit.PD1PDPU = ((PORTD1_INIT & 0x03)==0x01) ? 1:0;
		pdrctl_set.bit.PD0PDPU = ((PORTD0_INIT & 0x03)==0x01) ? 1:0;

		pdrctl_set.bit.PD4REN = ((PORTD4_INIT & 0x03)==0x00) ? 0:1;
		pdrctl_set.bit.PD3REN = ((PORTD3_INIT & 0x03)==0x00) ? 0:1;
		pdrctl_set.bit.PD1REN = ((PORTD1_INIT & 0x03)==0x00) ? 0:1;
		pdrctl_set.bit.PD0REN = ((PORTD0_INIT & 0x03)==0x00) ? 0:1;
		PDRCTL = pdrctl_set.reg;
	}

	/* P0MODSEL:P0 Port Mode Select Register */
	{
		p0modsel_set.reg = P0MODSEL;
		if(PORT07_INIT & 0x80) p0modsel_set.bit.P07SEL = 0x00;
		if(PORT06_INIT & 0x80) p0modsel_set.bit.P06SEL = 0x00;
		if(PORT05_INIT & 0x80) p0modsel_set.bit.P05SEL = 0x00;
		if(PORT04_INIT & 0x80) p0modsel_set.bit.P04SEL = 0x00;
		if(PORT03_INIT & 0x80) p0modsel_set.bit.P03SEL = 0x00;
		if(PORT02_INIT & 0x80) p0modsel_set.bit.P02SEL = 0x00;
		if(PORT01_INIT & 0x80) p0modsel_set.bit.P01SEL = 0x00;
		if(PORT00_INIT & 0x80) p0modsel_set.bit.P00SEL = 0x00;
		P0MODSEL = p0modsel_set.reg;
	}
	/* P1MODSEL:P1 Port Mode Select Register */
	{
		p1modsel_set.reg = P1MODSEL;
		if(PORT17_INIT & 0x80) p1modsel_set.bit.P17SEL = 0x00;
		if(PORT16_INIT & 0x80) p1modsel_set.bit.P16SEL = 0x00;
		if(PORT15_INIT & 0x80) p1modsel_set.bit.P15SEL = 0x00;
		if(PORT14_INIT & 0x80) p1modsel_set.bit.P14SEL = 0x00;
		if(PORT13_INIT & 0x80) p1modsel_set.bit.P13SEL = 0x00;
		if(PORT12_INIT & 0x80) p1modsel_set.bit.P12SEL = 0x00;
		if(PORT11_INIT & 0x80) p1modsel_set.bit.P11SEL = 0x00;
		if(PORT10_INIT & 0x80) p1modsel_set.bit.P10SEL = 0x00;
		P1MODSEL = p1modsel_set.reg;
	}
	/* P2MODSEL:P2 Port Mode Select Register */
	{
		p2modsel_set.reg = P2MODSEL;
		if(PORT27_INIT & 0x80) p2modsel_set.bit.P27SEL = 0x00;
		if(PORT26_INIT & 0x80) p2modsel_set.bit.P26SEL = 0x00;
		if(PORT25_INIT & 0x80) p2modsel_set.bit.P25SEL = 0x00;
		if(PORT24_INIT & 0x80) p2modsel_set.bit.P24SEL = 0x00;
		if(PORT23_INIT & 0x80) p2modsel_set.bit.P23SEL = 0x00;
		if(PORT22_INIT & 0x80) p2modsel_set.bit.P22SEL = 0x00;
		if(PORT21_INIT & 0x80) p2modsel_set.bit.P21SEL = 0x00;
		if(PORT20_INIT & 0x80) p2modsel_set.bit.P20SEL = 0x00;
		P2MODSEL = p2modsel_set.reg;
	}
	/* P3MODSEL:P3 Port Mode Select Register */
	{
		p3modsel_set.reg = P3MODSEL;
		if(PORT37_INIT & 0x80) p3modsel_set.bit.P37SEL = 0x00;
		if(PORT36_INIT & 0x80) p3modsel_set.bit.P36SEL = 0x00;
		if(PORT35_INIT & 0x80) p3modsel_set.bit.P35SEL = 0x00;
		if(PORT34_INIT & 0x80) p3modsel_set.bit.P34SEL = 0x00;
		if(PORT33_INIT & 0x80) p3modsel_set.bit.P33SEL = 0x00;
		if(PORT32_INIT & 0x80) p3modsel_set.bit.P32SEL = 0x00;
		if(PORT31_INIT & 0x80) p3modsel_set.bit.P31SEL = 0x00;
		if(PORT30_INIT & 0x80) p3modsel_set.bit.P30SEL = 0x00;
		P3MODSEL = p3modsel_set.reg;
	}
	/* P6MODSEL:P6 Port Mode Select Register */
	{
		p6modsel_set.reg = P6MODSEL;
		if(PORT67_INIT & 0x80) p6modsel_set.bit.P67SEL = 0x00;
		if(PORT66_INIT & 0x80) p6modsel_set.bit.P66SEL = 0x00;
		if(PORT65_INIT & 0x80) p6modsel_set.bit.P65SEL = 0x00;
		if(PORT64_INIT & 0x80) p6modsel_set.bit.P64SEL = 0x00;
		if(PORT63_INIT & 0x80) p6modsel_set.bit.P63SEL = 0x00;
		if(PORT62_INIT & 0x80) p6modsel_set.bit.P62SEL = 0x00;
		if(PORT61_INIT & 0x80) p6modsel_set.bit.P61SEL = 0x00;
		if(PORT60_INIT & 0x80) p6modsel_set.bit.P60SEL = 0x00;
		P6MODSEL = p6modsel_set.reg;
	}
	/* P7MODSEL:P7 Port Mode Select Register */
	{
		p7modsel_set.reg = P7MODSEL;
		if(PORT73_INIT & 0x80) p7modsel_set.bit.P73SEL = 0x00;
		if(PORT72_INIT & 0x80) p7modsel_set.bit.P72SEL = 0x00;
		if(PORT71_INIT & 0x80) p7modsel_set.bit.P71SEL = 0x00;
		if(PORT70_INIT & 0x80) p7modsel_set.bit.P70SEL = 0x00;
		P7MODSEL = p7modsel_set.reg;
	}
	/* P8MODSEL:P8 Port Mode Select Register */
	{
		p8modsel_set.reg = P8MODSEL;
		if(PORT87_INIT & 0x80) p8modsel_set.bit.P87SEL = 0x00;
		if(PORT86_INIT & 0x80) p8modsel_set.bit.P86SEL = 0x00;
		if(PORT85_INIT & 0x80) p8modsel_set.bit.P85SEL = 0x00;
		if(PORT84_INIT & 0x80) p8modsel_set.bit.P84SEL = 0x00;
		if(PORT83_INIT & 0x80) p8modsel_set.bit.P83SEL = 0x00;
		if(PORT82_INIT & 0x80) p8modsel_set.bit.P82SEL = 0x00;
		if(PORT81_INIT & 0x80) p8modsel_set.bit.P81SEL = 0x00;
		if(PORT80_INIT & 0x80) p8modsel_set.bit.P80SEL = 0x00;
		P8MODSEL = p8modsel_set.reg;
	}
	/* PDMODSEL:PD Port Mode Select Register */
	{
		pdmodsel_set.reg = PDMODSEL;
		if(PORTD4_INIT & 0x80) pdmodsel_set.bit.PD4SEL = 0x00;
		if(PORTD3_INIT & 0x80) pdmodsel_set.bit.PD3SEL = 0x00;
		if(PORTD2_INIT & 0x80) pdmodsel_set.bit.PD2SEL = 0x00;
		if(PORTD1_INIT & 0x80) pdmodsel_set.bit.PD1SEL = 0x00;
		if(PORTD0_INIT & 0x80) pdmodsel_set.bit.PD0SEL = 0x00;
		PDMODSEL = pdmodsel_set.reg;
	}

	/// Initialize the interrupt.
	ILVPPORT = INTERRUPT_LEVEL_PORT;

}


/************************************************************************//**
 * @brief   PORT input interrupt function.(Register in the vector table.)
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intPortInput(void)
{
	P0INTF_REG	p0nif_get;
	P1INTF_REG	p1nif_get;
	P2INTF_REG	p2nif_get;
	P3INTF_REG	p3nif_get;
	P4INTF_REG	p4nif_get;
	P5INTF_REG	p5nif_get;
	P6INTF_REG	p6nif_get;
	P7INTF_REG	p7nif_get;
	P8INTF_REG	p8nif_get;

	/* P0INTF:P0 Port Interrupt Flag Register read & clear */
	{
		p0nif_get.reg = P0INTF;
		P0INTF = p0nif_get.reg;
	}
	intInputP0x(&p0nif_get);

	/* P1INTF:P1 Port Interrupt Flag Register read & clear */
	{
		p1nif_get.reg = P1INTF;
		P1INTF = p1nif_get.reg;
	}
	intInputP1x(&p1nif_get);

	/* P2INTF:P2 Port Interrupt Flag Register read & clear */
	{
		p2nif_get.reg = P2INTF;
		P2INTF = p2nif_get.reg;
	}
	intInputP2x(&p2nif_get);

	/* P3INTF:P3 Port Interrupt Flag Register read & clear */
	{
		p3nif_get.reg = P3INTF;
		P3INTF = p3nif_get.reg;
	}
	intInputP3x(&p3nif_get);

	/* P4INTF:P4 Port Interrupt Flag Register read & clear */
	{
		p4nif_get.reg = P4INTF;
		P4INTF = p4nif_get.reg;
	}
	intInputP4x(&p4nif_get);

	/* P5INTF:P5 Port Interrupt Flag Register read & clear */
	{
		p5nif_get.reg = P5INTF;
		P5INTF = p5nif_get.reg;
	}
	intInputP5x(&p5nif_get);

	/* P6INTF:P6 Port Interrupt Flag Register read & clear */
	{
		p6nif_get.reg = P6INTF;
		P6INTF = p6nif_get.reg;
	}
	intInputP6x(&p6nif_get);

	/* P7INTF:P7 Port Interrupt Flag Register read & clear */
	{
		p7nif_get.reg = P7INTF;
		P7INTF = p7nif_get.reg;
	}
	intInputP7x(&p7nif_get);

	/* P8INTF:P8 Port Interrupt Flag Register read & clear */
	{
		p8nif_get.reg = P8INTF;
		P8INTF = p8nif_get.reg;
	}
	intInputP8x(&p8nif_get);
}


static inline void intInputP0x(P0INTF_REG* p0nif_get)
{
	/* P0INTF:P0 Port Interrupt Flag Register */
	{
		if(p0nif_get->bit.P00IF == 1)
		{
		   /**
			* @todo add interrupt function of P00
			*/
			c17portP0xIntInputFlag |= 0x01;
		}
		if(p0nif_get->bit.P01IF == 1)
		{
		   /**
			* @todo add interrupt function of P01
			*/
			c17portP0xIntInputFlag |= 0x02;
		}
		if(p0nif_get->bit.P02IF == 1)
		{
		   /**
			* @todo add interrupt function of P02
			*/
			c17portP0xIntInputFlag |= 0x04;
		}
		if(p0nif_get->bit.P03IF == 1)
		{
		   /**
			* @todo add interrupt function of P03
			*/
			c17portP0xIntInputFlag |= 0x08;
		}
		if(p0nif_get->bit.P04IF == 1)
		{
		   /**
			* @todo add interrupt function of P04
			*/
			c17portP0xIntInputFlag |= 0x10;
		}
		if(p0nif_get->bit.P05IF == 1)
		{
		   /**
			* @todo add interrupt function of P05
			*/
			c17portP0xIntInputFlag |= 0x20;
		}
		if(p0nif_get->bit.P06IF == 1)
		{
		   /**
			* @todo add interrupt function of P06
			*/
			c17portP0xIntInputFlag |= 0x40;
		}
		if(p0nif_get->bit.P07IF == 1)
		{
		   /**
			* @todo add interrupt function of P07
			*/
			c17portP0xIntInputFlag |= 0x80;
		}
	}
}


static inline void intInputP1x(P1INTF_REG* p1nif_get)
{
	/* P1INTF:P1 Port Interrupt Flag Register */
	{
		if(p1nif_get->bit.P10IF == 1)
		{
		   /**
			* @todo add interrupt function of P10
			*/
		}
		if(p1nif_get->bit.P11IF == 1)
		{
		   /**
			* @todo add interrupt function of P11
			*/
		}
		if(p1nif_get->bit.P12IF == 1)
		{
		   /**
			* @todo add interrupt function of P12
			*/
		}
		if(p1nif_get->bit.P13IF == 1)
		{
		   /**
			* @todo add interrupt function of P13
			*/
		}
		if(p1nif_get->bit.P14IF == 1)
		{
		   /**
			* @todo add interrupt function of P14
			*/
		}
		if(p1nif_get->bit.P15IF == 1)
		{
		   /**
			* @todo add interrupt function of P15
			*/
		}
		if(p1nif_get->bit.P16IF == 1)
		{
		   /**
			* @todo add interrupt function of P16
			*/
		}
		if(p1nif_get->bit.P17IF == 1)
		{
		   /**
			* @todo add interrupt function of P17
			*/
		}
	}
}


static inline void intInputP2x(P2INTF_REG* p2nif_get)
{
	/* P2INTF:P2 Port Interrupt Flag Register */
	{
		if(p2nif_get->bit.P20IF == 1)
		{
		   /**
			* @todo add interrupt function of P20
			*/
		}
		if(p2nif_get->bit.P21IF == 1)
		{
		   /**
			* @todo add interrupt function of P21
			*/
		}
		if(p2nif_get->bit.P22IF == 1)
		{
		   /**
			* @todo add interrupt function of P22
			*/
		}
		if(p2nif_get->bit.P23IF == 1)
		{
		   /**
			* @todo add interrupt function of P23
			*/
		}
		if(p2nif_get->bit.P24IF == 1)
		{
		   /**
			* @todo add interrupt function of P24
			*/
		}
		if(p2nif_get->bit.P25IF == 1)
		{
		   /**
			* @todo add interrupt function of P25
			*/
		}
		if(p2nif_get->bit.P26IF == 1)
		{
		   /**
			* @todo add interrupt function of P26
			*/
		}
		if(p2nif_get->bit.P27IF == 1)
		{
		   /**
			* @todo add interrupt function of P27
			*/
		}
	}
}


static inline void intInputP3x(P3INTF_REG* p3nif_get)
{
	/* P3INTF:P3 Port Interrupt Flag Register */
	{
		if(p3nif_get->bit.P30IF == 1)
		{
		   /**
			* @todo add interrupt function of P30
			*/
		}
		if(p3nif_get->bit.P31IF == 1)
		{
		   /**
			* @todo add interrupt function of P31
			*/
		}
		if(p3nif_get->bit.P32IF == 1)
		{
		   /**
			* @todo add interrupt function of P32
			*/
		}
		if(p3nif_get->bit.P33IF == 1)
		{
		   /**
			* @todo add interrupt function of P33
			*/
		}
		if(p3nif_get->bit.P34IF == 1)
		{
		   /**
			* @todo add interrupt function of P34
			*/
		}
		if(p3nif_get->bit.P35IF == 1)
		{
		   /**
			* @todo add interrupt function of P35
			*/
		}
		if(p3nif_get->bit.P36IF == 1)
		{
		   /**
			* @todo add interrupt function of P36
			*/
		}
		if(p3nif_get->bit.P37IF == 1)
		{
		   /**
			* @todo add interrupt function of P37
			*/
		}
	}
}


static inline void intInputP4x(P4INTF_REG* p4nif_get)
{
	/* P4INTF:P4 Port Interrupt Flag Register */
	{
		if(p4nif_get->bit.P40IF == 1)
		{
		   /**
			* @todo add interrupt function of P40
			*/
		}
		if(p4nif_get->bit.P41IF == 1)
		{
		   /**
			* @todo add interrupt function of P41
			*/
		}
		if(p4nif_get->bit.P42IF == 1)
		{
		   /**
			* @todo add interrupt function of P42
			*/
		}
		if(p4nif_get->bit.P43IF == 1)
		{
		   /**
			* @todo add interrupt function of P43
			*/
		}
		if(p4nif_get->bit.P44IF == 1)
		{
		   /**
			* @todo add interrupt function of P44
			*/
		}
		if(p4nif_get->bit.P45IF == 1)
		{
		   /**
			* @todo add interrupt function of P45
			*/
		}
		if(p4nif_get->bit.P46IF == 1)
		{
		   /**
			* @todo add interrupt function of P46
			*/
		}
		if(p4nif_get->bit.P47IF == 1)
		{
		   /**
			* @todo add interrupt function of P47
			*/
		}
	}
}


static inline void intInputP5x(P5INTF_REG* p5nif_get)
{
	/* P5INTF:P5 Port Interrupt Flag Register */
	{
		if(p5nif_get->bit.P50IF == 1)
		{
		   /**
			* @todo add interrupt function of P50
			*/
		}
		if(p5nif_get->bit.P51IF == 1)
		{
		   /**
			* @todo add interrupt function of P11
			*/
		}
		if(p5nif_get->bit.P52IF == 1)
		{
		   /**
			* @todo add interrupt function of P52
			*/
		}
	}
}


static inline void intInputP6x(P6INTF_REG* p6nif_get)
{
	/* P6INTF:P6 Port Interrupt Flag Register */
	{
		if(p6nif_get->bit.P60IF == 1)
		{
		   /**
			* @todo add interrupt function of P60
			*/
		}
		if(p6nif_get->bit.P61IF == 1)
		{
		   /**
			* @todo add interrupt function of P61
			*/
		}
		if(p6nif_get->bit.P62IF == 1)
		{
		   /**
			* @todo add interrupt function of P62
			*/
		}
		if(p6nif_get->bit.P63IF == 1)
		{
		   /**
			* @todo add interrupt function of P63
			*/
		}
		if(p6nif_get->bit.P64IF == 1)
		{
		   /**
			* @todo add interrupt function of P64
			*/
		}
		if(p6nif_get->bit.P65IF == 1)
		{
		   /**
			* @todo add interrupt function of P65
			*/
		}
		if(p6nif_get->bit.P66IF == 1)
		{
		   /**
			* @todo add interrupt function of P66
			*/
		}
		if(p6nif_get->bit.P67IF == 1)
		{
		   /**
			* @todo add interrupt function of P67
			*/
		}
	}
}


static inline void intInputP7x(P7INTF_REG* p7nif_get)
{
	/* P7INTF:P7 Port Interrupt Flag Register */
	{
		if(p7nif_get->bit.P70IF == 1)
		{
		   /**
			* @todo add interrupt function of P70
			*/
		}
		if(p7nif_get->bit.P71IF == 1)
		{
		   /**
			* @todo add interrupt function of P71
			*/
		}
		if(p7nif_get->bit.P72IF == 1)
		{
		   /**
			* @todo add interrupt function of P72
			*/
		}
		if(p7nif_get->bit.P73IF == 1)
		{
		   /**
			* @todo add interrupt function of P73
			*/
		}
	}
}


static inline void intInputP8x(P8INTF_REG* p8nif_get)
{
	/* P8INTF:P8 Port Interrupt Flag Register */
	{
		if(p8nif_get->bit.P80IF == 1)
		{
		   /**
			* @todo add interrupt function of P80
			*/
		}
		if(p8nif_get->bit.P81IF == 1)
		{
		   /**
			* @todo add interrupt function of P81
			*/
		}
		if(p8nif_get->bit.P82IF == 1)
		{
		   /**
			* @todo add interrupt function of P82
			*/
		}
		if(p8nif_get->bit.P83IF == 1)
		{
		   /**
			* @todo add interrupt function of P83
			*/
		}
		if(p8nif_get->bit.P84IF == 1)
		{
		   /**
			* @todo add interrupt function of P84
			*/
		}
		if(p8nif_get->bit.P85IF == 1)
		{
		   /**
			* @todo add interrupt function of P85
			*/
		}
		if(p8nif_get->bit.P86IF == 1)
		{
		   /**
			* @todo add interrupt function of P86
			*/
		}
		if(p8nif_get->bit.P87IF == 1)
		{
		   /**
			* @todo add interrupt function of P87
			*/
		}
	}
}


/************************************************************************//**
 * @brief   Set port interrupt enable.
 *
 * @param   portNo                        Port Number.
 *  @li @c      0 to 7                    Port Number.
 *  @li @c      others                    Nothing is done.
 * @param   portIntEdge                   Interrupt edge.
 *  @li @c      C17_PORT_INT_EDGE_RISING  Rising edge.
 *  @li @c      C17_PORT_INT_EDGE_FALLING Falling edge.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntP0x(unsigned short portNo, unsigned short portIntEdge)
{
	P0INTF_REG      p0intf_set;

	if(portNo > 7) {
		return;
	}

	/* P0INTF: Port Interrupt Flag Register */
	{
		p0intf_set.reg = LOWBYTE_BIT_SET(portNo);
		P0INTF = p0intf_set.reg;
	}

	/* P0INTCTL:P0 Port Interrupt Control Register. */
	{
		enableIntPxx(portNo, portIntEdge, (P0INTCTL_REG*)&P0INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt enable.
 *
 * @param   portNo                        Port Number.
 *  @li @c      0 to 7                    Port Number.
 *  @li @c      others                    Nothing is done.
 * @param   portIntEdge                   Interrupt edge.
 *  @li @c      C17_PORT_INT_EDGE_RISING  Rising edge.
 *  @li @c      C17_PORT_INT_EDGE_FALLING Falling edge.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntP1x(unsigned short portNo, unsigned short portIntEdge)
{
	P1INTF_REG      p1intf_set;

	if(portNo > 7) {
		return;
	}

	/* P1INTF: Port Interrupt Flag Register */
	{
		p1intf_set.reg = LOWBYTE_BIT_SET(portNo);
		P1INTF = p1intf_set.reg;
	}

	/* P1INTCTL:P1 Port Interrupt Control Register. */
	{
		enableIntPxx(portNo, portIntEdge, (P0INTCTL_REG*)&P1INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt enable.
 *
 * @param   portNo                        Port Number.
 *  @li @c      0 to 7                    Port Number.
 *  @li @c      others                    Nothing is done.
 * @param   portIntEdge                   Interrupt edge.
 *  @li @c      C17_PORT_INT_EDGE_RISING  Rising edge.
 *  @li @c      C17_PORT_INT_EDGE_FALLING Falling edge.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntP2x(unsigned short portNo, unsigned short portIntEdge)
{
	P2INTF_REG      p2intf_set;

	if(portNo > 7) {
		return;
	}

	/* P2INTF: Port Interrupt Flag Register */
	{
		p2intf_set.reg = LOWBYTE_BIT_SET(portNo);
		P2INTF = p2intf_set.reg;
	}

	/* P2INTCTL:P2 Port Interrupt Control Register. */
	{
		enableIntPxx(portNo, portIntEdge, (P0INTCTL_REG*)&P2INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt enable.
 *
 * @param   portNo                        Port Number.
 *  @li @c      0 to 7                    Port Number.
 *  @li @c      others                    Nothing is done.
 * @param   portIntEdge                   Interrupt edge.
 *  @li @c      C17_PORT_INT_EDGE_RISING  Rising edge.
 *  @li @c      C17_PORT_INT_EDGE_FALLING Falling edge.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntP3x(unsigned short portNo, unsigned short portIntEdge)
{
	P3INTF_REG      p3intf_set;

	if(portNo > 7) {
		return;
	}

	/* P3INTF: Port Interrupt Flag Register */
	{
		p3intf_set.reg = LOWBYTE_BIT_SET(portNo);
		P3INTF = p3intf_set.reg;
	}

	/* P3INTCTL:P3 Port Interrupt Control Register. */
	{
		enableIntPxx(portNo, portIntEdge, (P0INTCTL_REG*)&P3INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt enable.
 *
 * @param   portNo                        Port Number.
 *  @li @c      0 to 7                    Port Number.
 *  @li @c      others                    Nothing is done.
 * @param   portIntEdge                   Interrupt edge.
 *  @li @c      C17_PORT_INT_EDGE_RISING  Rising edge.
 *  @li @c      C17_PORT_INT_EDGE_FALLING Falling edge.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntP4x(unsigned short portNo, unsigned short portIntEdge)
{
	P4INTF_REG      p4intf_set;

	if(portNo > 7) {
		return;
	}

	/* P4INTF: Port Interrupt Flag Register */
	{
		p4intf_set.reg = LOWBYTE_BIT_SET(portNo);
		P4INTF = p4intf_set.reg;
	}

	/* P4INTCTL:P4 Port Interrupt Control Register. */
	{
		enableIntPxx(portNo, portIntEdge, (P0INTCTL_REG*)&P4INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt enable.
 *
 * @param   portNo                        Port Number.
 *  @li @c      0 to 7                    Port Number.
 *  @li @c      others                    Nothing is done.
 * @param   portIntEdge                   Interrupt edge.
 *  @li @c      C17_PORT_INT_EDGE_RISING  Rising edge.
 *  @li @c      C17_PORT_INT_EDGE_FALLING Falling edge.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntP5x(unsigned short portNo, unsigned short portIntEdge)
{
	P5INTF_REG      p5intf_set;

	if(portNo > 7) {
		return;
	}

	/* P5INTF: Port Interrupt Flag Register */
	{
		p5intf_set.reg = LOWBYTE_BIT_SET(portNo);
		P5INTF = p5intf_set.reg;
	}

	/* P5INTCTL:P5 Port Interrupt Control Register. */
	{
		enableIntPxx(portNo, portIntEdge, (P0INTCTL_REG*)&P5INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt enable.
 *
 * @param   portNo                        Port Number.
 *  @li @c      0 to 7                    Port Number.
 *  @li @c      others                    Nothing is done.
 * @param   portIntEdge                   Interrupt edge.
 *  @li @c      C17_PORT_INT_EDGE_RISING  Rising edge.
 *  @li @c      C17_PORT_INT_EDGE_FALLING Falling edge.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntP6x(unsigned short portNo, unsigned short portIntEdge)
{
	P6INTF_REG      p6intf_set;

	if(portNo > 7) {
		return;
	}

	/* P6INTF: Port Interrupt Flag Register */
	{
		p6intf_set.reg = LOWBYTE_BIT_SET(portNo);
		P6INTF = p6intf_set.reg;
	}

	/* P6INTCTL:P6 Port Interrupt Control Register. */
	{
		enableIntPxx(portNo, portIntEdge, (P0INTCTL_REG*)&P6INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt enable.
 *
 * @param   portNo                        Port Number.
 *  @li @c      0 to 7                    Port Number.
 *  @li @c      others                    Nothing is done.
 * @param   portIntEdge                   Interrupt edge.
 *  @li @c      C17_PORT_INT_EDGE_RISING  Rising edge.
 *  @li @c      C17_PORT_INT_EDGE_FALLING Falling edge.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntP7x(unsigned short portNo, unsigned short portIntEdge)
{
	P7INTF_REG      p7intf_set;

	if(portNo > 7) {
		return;
	}

	/* P7INTF: Port Interrupt Flag Register */
	{
		p7intf_set.reg = LOWBYTE_BIT_SET(portNo);
		P7INTF = p7intf_set.reg;
	}

	/* P7INTCTL:P7 Port Interrupt Control Register. */
	{
		enableIntPxx(portNo, portIntEdge, (P0INTCTL_REG*)&P7INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt enable.
 *
 * @param   portNo                        Port Number.
 *  @li @c      0 to 7                    Port Number.
 *  @li @c      others                    Nothing is done.
 * @param   portIntEdge                   Interrupt edge.
 *  @li @c      C17_PORT_INT_EDGE_RISING  Rising edge.
 *  @li @c      C17_PORT_INT_EDGE_FALLING Falling edge.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntP8x(unsigned short portNo, unsigned short portIntEdge)
{
	P8INTF_REG      p8intf_set;

	if(portNo > 7) {
		return;
	}

	/* P8INTF: Port Interrupt Flag Register */
	{
		p8intf_set.reg = LOWBYTE_BIT_SET(portNo);
		P8INTF = p8intf_set.reg;
	}

	/* P8INTCTL:P8 Port Interrupt Control Register. */
	{
		enableIntPxx(portNo, portIntEdge, (P0INTCTL_REG*)&P8INTCTL);
	}
}


static void enableIntPxx(unsigned short portNo, unsigned short portIntEdge, P0INTCTL_REG* portRegister)
{
	P0INTCTL_REG	pxintctl_set;

	pxintctl_set.reg = portRegister->reg;

	if(portIntEdge == C17_PORT_INT_EDGE_FALLING) {
		/**
		 * Set PxEDGE
		 * Interrupt will occur at a falling edge.
		 */
		pxintctl_set.reg |= HIGHBYTE_BIT_SET(portNo) ;
	} else {
		/**
		 *  Clear PxEDGE
		 * Interrupt will occur at a rising edge.
		 */
		pxintctl_set.reg &= (0xFFFF ^ HIGHBYTE_BIT_SET(portNo));
	}
	/**
	 * Set PxIE
	 * Enable port input interrupts.
	 */
	pxintctl_set.reg |=  LOWBYTE_BIT_SET(portNo) ;

	portRegister->reg = pxintctl_set.reg;
}


/************************************************************************//**
 * @brief   Set port interrupt disable.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntP0x(unsigned short portNo)
{
	if(portNo > 7) {
		return;
	}

	/* P0INTCTL:P0 Port Interrupt Control Register. */
	{
		// Disable interrupt.
		disableIntPxx(portNo, (P0INTCTL_REG*)&P0INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt disable.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntP1x(unsigned short portNo)
{
	if(portNo > 7) {
		return;
	}

	/* P1INTCTL:P1 Port Interrupt Control Register. */
	{
		// Disable interrupt.
		disableIntPxx(portNo, (P0INTCTL_REG*)&P1INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt disable.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntP2x(unsigned short portNo)
{
	if(portNo > 7) {
		return;
	}

	/* P2INTCTL:P2 Port Interrupt Control Register. */
	{
		// Disable interrupt.
		disableIntPxx(portNo, (P0INTCTL_REG*)&P2INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt disable.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntP3x(unsigned short portNo)
{
	if(portNo > 7) {
		return;
	}

	/* P3INTCTL:P3 Port Interrupt Control Register. */
	{
		// Disable interrupt.
		disableIntPxx(portNo, (P0INTCTL_REG*)&P3INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt disable.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntP4x(unsigned short portNo)
{
	if(portNo > 7) {
		return;
	}

	/* P4INTCTL:P4 Port Interrupt Control Register. */
	{
		// Disable interrupt.
		disableIntPxx(portNo, (P0INTCTL_REG*)&P4INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt disable.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntP5x(unsigned short portNo)
{
	if(portNo > 7) {
		return;
	}

	/* P5INTCTL:P5 Port Interrupt Control Register. */
	{
		// Disable interrupt.
		disableIntPxx(portNo, (P0INTCTL_REG*)&P5INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt disable.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntP6x(unsigned short portNo)
{
	if(portNo > 7) {
		return;
	}

	/* P6INTCTL:P6 Port Interrupt Control Register. */
	{
		// Disable interrupt.
		disableIntPxx(portNo, (P0INTCTL_REG*)&P6INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt disable.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntP7x(unsigned short portNo)
{
	if(portNo > 7) {
		return;
	}

	/* P7INTCTL:P7 Port Interrupt Control Register. */
	{
		// Disable interrupt.
		disableIntPxx(portNo, (P0INTCTL_REG*)&P7INTCTL);
	}
}


/************************************************************************//**
 * @brief   Set port interrupt disable.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntP8x(unsigned short portNo)
{
	if(portNo > 7) {
		return;
	}

	/* P8INTCTL:P8 Port Interrupt Control Register. */
	{
		// Disable interrupt.
		disableIntPxx(portNo, (P0INTCTL_REG*)&P8INTCTL);
	}
}


static void disableIntPxx(unsigned short portNo, P0INTCTL_REG* portRegister)
{
	P0INTCTL_REG	pxintctl_set;

	pxintctl_set.reg = portRegister->reg;
	/**
	 * Set PxIE
	 * Disable port input interrupts.
	 */
	pxintctl_set.reg &= (0xFFFF ^ LOWBYTE_BIT_SET(portNo)) ;

	portRegister->reg = pxintctl_set.reg;
}


/************************************************************************//**
 * @brief   Get output port data.(BYTE)
 *
 * @param   none.
 *
 * @retval  0 to 0xFF
 ***************************************************************************/
unsigned char c17getOutputP0xByte(void)
{
	P0DAT_REG	p0data_set;

	p0data_set.reg = P0DAT;

	// Get output data.
	return p0data_set.byte_reg[1];
}


/************************************************************************//**
 * @brief   Get output port data.(BYTE)
 *
 * @param   none.
 *
 * @retval  0 to 0xFF
 ***************************************************************************/
unsigned char c17getOutputP1xByte(void)
{
	P1DAT_REG	p1data_set;

	p1data_set.reg = P1DAT;

	// Get output data.
	return p1data_set.byte_reg[1];
}


/************************************************************************//**
 * @brief   Get output port data.(BYTE)
 *
 * @param   none.
 *
 * @retval  0 to 0xFF
 ***************************************************************************/
unsigned char c17getOutputP2xByte(void)
{
	P2DAT_REG	p2data_set;

	p2data_set.reg = P2DAT;

	// Get output data.
	return p2data_set.byte_reg[1];
}


/************************************************************************//**
 * @brief   Get output port data.(BYTE)
 *
 * @param   none.
 *
 * @retval  0 to 0xFF
 ***************************************************************************/
unsigned char c17getOutputP3xByte(void)
{
	P3DAT_REG	p3data_set;

	p3data_set.reg = P3DAT;

	// Get output data.
	return p3data_set.byte_reg[1];
}


/************************************************************************//**
 * @brief   Get output port data.(BYTE)
 *
 * @param   none.
 *
 * @retval  0 to 0xFF
 ***************************************************************************/
unsigned char c17getOutputP4xByte(void)
{
	P4DAT_REG	p4data_set;

	p4data_set.reg = P4DAT;

	// Get output data.
	return p4data_set.byte_reg[1];
}


/************************************************************************//**
 * @brief   Get output port data.(BYTE)
 *
 * @param   none.
 *
 * @retval  0 to 0xFF
 ***************************************************************************/
unsigned char c17getOutputP5xByte(void)
{
	P5DAT_REG	p5data_set;

	p5data_set.reg = P5DAT;

	// Get output data.
	return p5data_set.byte_reg[1];
}


/************************************************************************//**
 * @brief   Get output port data.(BYTE)
 *
 * @param   none.
 *
 * @retval  0 to 0xFF
 ***************************************************************************/
unsigned char c17getOutputP6xByte(void)
{
	P6DAT_REG	p6data_set;

	p6data_set.reg = P6DAT;

	// Get output data.
	return p6data_set.byte_reg[1];
}


/************************************************************************//**
 * @brief   Get output port data.(BYTE)
 *
 * @param   none.
 *
 * @retval  0 to 0xFF
 ***************************************************************************/
unsigned char c17getOutputP7xByte(void)
{
	P7DAT_REG	p7data_set;

	p7data_set.reg = P7DAT;

	// Get output data.
	return p7data_set.byte_reg[1];
}


/************************************************************************//**
 * @brief   Get output port data.(BYTE)
 *
 * @param   none.
 *
 * @retval  0 to 0xFF
 ***************************************************************************/
unsigned char c17getOutputP8xByte(void)
{
	P8DAT_REG	p8data_set;

	p8data_set.reg = P8DAT;

	// Get output data.
	return p8data_set.byte_reg[1];
}


/************************************************************************//**
 * @brief   Get output port data.(BYTE)
 *
 * @param   none.
 *
 * @retval  0 to 0xFF
 ***************************************************************************/
unsigned char c17getOutputPDxByte(void)
{
	PDDAT_REG	pddata_set;

	pddata_set.reg = PDDAT;

	// Get output data.
	return pddata_set.byte_reg[1];
}


/************************************************************************//**
 * @brief   Get output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getOutputP0x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P0DAT: P0 Port Data Register */
	{
		// Get output data.
		return getOutputPxx(portNo, (P0DAT_REG*)&P0DAT);
	}
}


/************************************************************************//**
 * @brief   Get output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getOutputP1x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P1DAT: P1 Port Data Register */
	{
		// Get output data.
		return getOutputPxx(portNo, (P0DAT_REG*)&P1DAT);
	}
}


/************************************************************************//**
 * @brief   Get output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getOutputP2x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P2DAT: P2 Port Data Register */
	{
		// Get output data.
		return getOutputPxx(portNo, (P0DAT_REG*)&P2DAT);
	}
}


/************************************************************************//**
 * @brief   Get output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getOutputP3x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P3DAT: P3 Port Data Register */
	{
		// Get output data.
		return getOutputPxx(portNo, (P0DAT_REG*)&P3DAT);
	}
}


/************************************************************************//**
 * @brief   Get output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getOutputP4x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P4DAT: P4 Port Data Register */
	{
		// Get output data.
		return getOutputPxx(portNo, (P0DAT_REG*)&P4DAT);
	}
}


/************************************************************************//**
 * @brief   Get output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getOutputP5x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P5DAT: P5 Port Data Register */
	{
		// Get output data.
		return getOutputPxx(portNo, (P0DAT_REG*)&P5DAT);
	}
}


/************************************************************************//**
 * @brief   Get output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getOutputP6x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P6DAT: P6 Port Data Register */
	{
		// Get output data.
		return getOutputPxx(portNo, (P0DAT_REG*)&P6DAT);
	}
}


/************************************************************************//**
 * @brief   Get output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getOutputP7x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P7DAT: P7 Port Data Register */
	{
		// Get output data.
		return getOutputPxx(portNo, (P0DAT_REG*)&P7DAT);
	}
}


/************************************************************************//**
 * @brief   Get output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getOutputP8x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P8DAT: P8 Port Data Register */
	{
		// Get output data.
		return getOutputPxx(portNo, (P0DAT_REG*)&P8DAT);
	}
}


/************************************************************************//**
 * @brief   Get output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getOutputPDx(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*PDDAT: PD Port Data Register */
	{
		// Get output data.
		return getOutputPxx(portNo, (P0DAT_REG*)&PDDAT);
	}
}


static unsigned char getOutputPxx(unsigned short portNo, P0DAT_REG* portRegister)
{
	// Get output data.
	unsigned char result = 0;

	/**
	 * GET PxOUT
     *    1 : Output high level from the port pin
     *    0 : Output low level from the port pin
	 *
	 */
	if((portRegister->reg & HIGHBYTE_BIT_SET(portNo)) != 0)
	{
		result = 1;
	}
	return result;
}


/************************************************************************//**
 * @brief   Set output port data.(BYTE)
 *
 * @param   portData        output data.
 *  @li @c  0 to 0xFF
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP0xByte(unsigned char portData)
{
	/* P0DAT :P0 Port Data Register */
	{
		setOutputPxxByte(portData, (P0DAT_REG*)&P0DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.(BYTE)
 *
 * @param   portData        output data.
 *  @li @c  0 to 0xFF
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP1xByte(unsigned char portData)
{
	/* P1DAT :P1 Port Data Register */
	{
		setOutputPxxByte(portData, (P0DAT_REG*)&P1DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.(BYTE)
 *
 * @param   portData        output data.
 *  @li @c  0 to 0xFF
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP2xByte(unsigned char portData)
{
	/* P2DAT :P2 Port Data Register */
	{
		setOutputPxxByte(portData, (P0DAT_REG*)&P2DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.(BYTE)
 *
 * @param   portData        output data.
 *  @li @c  0 to 0xFF
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP3xByte(unsigned char portData)
{
	/* P3DAT :P3 Port Data Register */
	{
		setOutputPxxByte(portData, (P0DAT_REG*)&P3DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.(BYTE)
 *
 * @param   portData        output data.
 *  @li @c  0 to 0xFF
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP4xByte(unsigned char portData)
{
	/* P4DAT :P4 Port Data Register */
	{
		setOutputPxxByte(portData, (P0DAT_REG*)&P4DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.(BYTE)
 *
 * @param   portData        output data.
 *  @li @c  0 to 0xFF
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP5xByte(unsigned char portData)
{
	/* P5DAT :P5 Port Data Register */
	{
		setOutputPxxByte(portData, (P0DAT_REG*)&P5DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.(BYTE)
 *
 * @param   portData        output data.
 *  @li @c  0 to 0xFF
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP6xByte(unsigned char portData)
{
	/* P6DAT :P6 Port Data Register */
	{
		setOutputPxxByte(portData, (P0DAT_REG*)&P6DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.(BYTE)
 *
 * @param   portData        output data.
 *  @li @c  0 to 0xFF
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP7xByte(unsigned char portData)
{
	/* P7DAT :P7 Port Data Register */
	{
		setOutputPxxByte(portData, (P0DAT_REG*)&P7DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.(BYTE)
 *
 * @param   portData        output data.
 *  @li @c  0 to 0xFF
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP8xByte(unsigned char portData)
{
	/* P8DAT :P8 Port Data Register */
	{
		setOutputPxxByte(portData, (P0DAT_REG*)&P8DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.(BYTE)
 *
 * @param   portData        output data.
 *  @li @c  0 to 0xFF
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputPDxByte(unsigned char portData)
{
	/* PDDAT :PD Port Data Register */
	{
		setOutputPxxByte(portData, (P0DAT_REG*)&PDDAT);
	}

}


static void setOutputPxxByte(unsigned char portData, P0DAT_REG* portRegister)
{
	P0DAT_REG	pxdata_set;

	/* PxDAT :Px Port Data Register */
	{
		pxdata_set.reg = portRegister->reg;
		pxdata_set.byte_reg[1] = portData;
		// Set output data.
		portRegister->reg = pxdata_set.reg;
	}
}


/************************************************************************//**
 * @brief   Set output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 * @param   dportDataata    output data.
 *  @li @c      0 or 1      LOW or HIGH.
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP0x(unsigned short portNo, unsigned short portData)
{
	if(portNo > 7) {
		return ;
	}
	/*P0DAT: P0 Port Data Register.*/
	{
		setOutputPxx(portNo, portData, (P0DAT_REG*)&P0DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 * @param   portData        output data.
 *  @li @c      0 or 1      LOW or HIGH.
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP1x(unsigned short portNo, unsigned short portData)
{
	if(portNo > 7) {
		return ;
	}
	/*P1DAT: P1 Port Data Register.*/
	{
		setOutputPxx(portNo, portData, (P0DAT_REG*)&P1DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 * @param   portData        output data.
 *  @li @c      0 or 1      LOW or HIGH.
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP2x(unsigned short portNo, unsigned short portData)
{
	if(portNo > 7) {
		return ;
	}
	/*P2DAT: P2 Port Data Register.*/
	{
		setOutputPxx(portNo, portData, (P0DAT_REG*)&P2DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 * @param   portData        output data.
 *  @li @c      0 or 1      LOW or HIGH.
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP3x(unsigned short portNo, unsigned short portData)
{
	if(portNo > 7) {
		return ;
	}
	/*P3DAT: P3 Port Data Register.*/
	{
		setOutputPxx(portNo, portData, (P0DAT_REG*)&P3DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 * @param   portData        output data.
 *  @li @c      0 or 1      LOW or HIGH.
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP4x(unsigned short portNo, unsigned short portData)
{
	if(portNo > 7) {
		return ;
	}
	/*P4DAT: P4 Port Data Register.*/
	{
		setOutputPxx(portNo, portData, (P0DAT_REG*)&P4DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 * @param   portData        output data.
 *  @li @c      0 or 1      LOW or HIGH.
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP5x(unsigned short portNo, unsigned short portData)
{
	if(portNo > 7) {
		return ;
	}
	/*P5DAT: P5 Port Data Register.*/
	{
		setOutputPxx(portNo, portData, (P0DAT_REG*)&P5DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 * @param   portData        output data.
 *  @li @c      0 or 1      LOW or HIGH.
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP6x(unsigned short portNo, unsigned short portData)
{
	if(portNo > 7) {
		return ;
	}
	/*P6DAT: P6 Port Data Register.*/
	{
		setOutputPxx(portNo, portData, (P0DAT_REG*)&P6DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 * @param   portData        output data.
 *  @li @c      0 or 1      LOW or HIGH.
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP7x(unsigned short portNo, unsigned short portData)
{
	if(portNo > 7) {
		return ;
	}
	/*P7DAT: P7 Port Data Register.*/
	{
		setOutputPxx(portNo, portData, (P0DAT_REG*)&P7DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 * @param   portData        output data.
 *  @li @c      0 or 1      LOW or HIGH.
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputP8x(unsigned short portNo, unsigned short portData)
{
	if(portNo > 7) {
		return ;
	}
	/*P8DAT: P8 Port Data Register.*/
	{
		setOutputPxx(portNo, portData, (P0DAT_REG*)&P8DAT);
	}
}


/************************************************************************//**
 * @brief   Set output port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 * @param   portData        output data.
 *  @li @c      0 or 1      LOW or HIGH.
 *
 * @retval  none
 ***************************************************************************/
void c17setOutputPDx(unsigned short portNo, unsigned short portData)
{
	if(portNo > 7) {
		return ;
	}
	/*PDDAT: PD Port Data Register.*/
	{
		setOutputPxx(portNo, portData, (P0DAT_REG*)&PDDAT);
	}
}


static void setOutputPxx(unsigned short portNo, unsigned short portData, P0DAT_REG* portRegister)
{
	P0DAT_REG	pxdat_set;

	pxdat_set.reg =  portRegister->reg;

	if(portData == 1) {
		/**
		 * Set PxOUT
		 * Output high level from the port pin.
		 */
		pxdat_set.reg |= HIGHBYTE_BIT_SET(portNo) ;
	} else {
		/**
		 *  Clear PxOUT
		 * Output low level from the port pin.
		 */
		pxdat_set.reg &= (0xFFFF ^ HIGHBYTE_BIT_SET(portNo));
	}

	portRegister->reg = pxdat_set.reg;
}


/************************************************************************//**
 * @brief   Get input port data.(BYTE)
 *
 * @param   none
 *
 * @retval  0 to 0xFF       input data.
 ***************************************************************************/
unsigned char c17getInputP0xByte(void)
{
	P0DAT_REG	p0data_set;

	p0data_set.reg = P0DAT;

	// Get input data.
	return p0data_set.byte_reg[0];
}


/************************************************************************//**
 * @brief   Get input port data.(BYTE)
 *
 * @param   none
 *
 * @retval  0 to 0xFF       input data.
 ***************************************************************************/
unsigned char c17getInputP1xByte(void)
{
	P1DAT_REG	p1data_set;

	p1data_set.reg = P1DAT;

	// Get input data.
	return p1data_set.byte_reg[0];
}


/************************************************************************//**
 * @brief   Get input port data.(BYTE)
 *
 * @param   none
 *
 * @retval  0 to 0xFF       input data.
 ***************************************************************************/
unsigned char c17getInputP2xByte(void)
{
	P2DAT_REG	p2data_set;

	p2data_set.reg = P2DAT;

	// Get input data.
	return p2data_set.byte_reg[0];
}


/************************************************************************//**
 * @brief   Get input port data.(BYTE)
 *
 * @param   none
 *
 * @retval  0 to 0xFF       input data.
 ***************************************************************************/
unsigned char c17getInputP3xByte(void)
{
	P3DAT_REG	p3data_set;

	p3data_set.reg = P3DAT;

	// Get input data.
	return p3data_set.byte_reg[0];
}


/************************************************************************//**
 * @brief   Get input port data.(BYTE)
 *
 * @param   none
 *
 * @retval  0 to 0xFF       input data.
 ***************************************************************************/
unsigned char c17getInputP4xByte(void)
{
	P4DAT_REG	p4data_set;

	p4data_set.reg = P4DAT;

	// Get input data.
	return p4data_set.byte_reg[0];
}


/************************************************************************//**
 * @brief   Get input port data.(BYTE)
 *
 * @param   none
 *
 * @retval  0 to 0xFF       input data.
 ***************************************************************************/
unsigned char c17getInputP5xByte(void)
{
	P5DAT_REG	p5data_set;

	p5data_set.reg = P5DAT;

	// Get input data.
	return p5data_set.byte_reg[0];
}


/************************************************************************//**
 * @brief   Get input port data.(BYTE)
 *
 * @param   none
 *
 * @retval  0 to 0xFF       input data.
 ***************************************************************************/
unsigned char c17getInputP6xByte(void)
{
	P6DAT_REG	p6data_set;

	p6data_set.reg = P6DAT;

	// Get input data.
	return p6data_set.byte_reg[0];
}


/************************************************************************//**
 * @brief   Get input port data.(BYTE)
 *
 * @param   none
 *
 * @retval  0 to 0xFF       input data.
 ***************************************************************************/
unsigned char c17getInputP7xByte(void)
{
	P7DAT_REG	p7data_set;

	p7data_set.reg = P7DAT;

	// Get input data.
	return p7data_set.byte_reg[0];
}


/************************************************************************//**
 * @brief   Get input port data.(BYTE)
 *
 * @param   none
 *
 * @retval  0 to 0xFF       input data.
 ***************************************************************************/
unsigned char c17getInputP8xByte(void)
{
	P8DAT_REG	p8data_set;

	p8data_set.reg = P8DAT;

	// Get input data.
	return p8data_set.byte_reg[0];
}


/************************************************************************//**
 * @brief   Get input port data.(BYTE)
 *
 * @param   none
 *
 * @retval  0 to 0xFF       input data.
 ***************************************************************************/
unsigned char c17getInputPDxByte(void)
{
	PDDAT_REG	pddata_set;

	pddata_set.reg = PDDAT;

	// Get input data.
	return pddata_set.byte_reg[0];
}


/************************************************************************//**
 * @brief   Get input port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getInputP0x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P0DAT: P0 Port Data Register */
	{
		// Get output data.
		return getInputPxx(portNo, (P0DAT_REG*)&P0DAT);
	}
}


/************************************************************************//**
 * @brief   Get input port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getInputP1x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P1DAT: P1 Port Data Register */
	{
		// Get output data.
		return getInputPxx(portNo, (P0DAT_REG*)&P1DAT);
	}
}


/************************************************************************//**
 * @brief   Get input port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getInputP2x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P2DAT: P2 Port Data Register */
	{
		// Get output data.
		return getInputPxx(portNo, (P0DAT_REG*)&P2DAT);
	}
}


/************************************************************************//**
 * @brief   Get input port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getInputP3x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P3DAT: P3 Port Data Register */
	{
		// Get output data.
		return getInputPxx(portNo, (P0DAT_REG*)&P3DAT);
	}
}


/************************************************************************//**
 * @brief   Get input port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getInputP4x(unsigned short portNo)
{
	if (portNo > 7) {
		return 0;
	}

	/*P4DAT: P4 Port Data Register */
	{
		// Get output data.
		return getInputPxx(portNo, (P0DAT_REG*)&P4DAT);
	}
}


/************************************************************************//**
 * @brief   Get input port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getInputP5x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P5DAT: P5 Port Data Register */
	{
		// Get output data.
		return getInputPxx(portNo, (P0DAT_REG*)&P5DAT);
	}
}


/************************************************************************//**
 * @brief   Get input port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getInputP6x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P6DAT: P6 Port Data Register */
	{
		// Get output data.
		return getInputPxx(portNo, (P0DAT_REG*)&P6DAT);
	}
}


/************************************************************************//**
 * @brief   Get input port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getInputP7x(unsigned short portNo)
{
	if(portNo > 7) {
		return 0;
	}

	/*P7DAT: P7 Port Data Register */
	{
		// Get output data.
		return getInputPxx(portNo, (P0DAT_REG*)&P7DAT);
	}
}


/************************************************************************//**
 * @brief   Get input port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getInputP8x(unsigned short portNo)
{
	if (portNo > 7) {
		return 0;
	}

	/*P8DAT: P8 Port Data Register */
	{
		// Get output data.
		return getInputPxx(portNo, (P0DAT_REG*)&P8DAT);
	}
}


/************************************************************************//**
 * @brief   Get input port data.
 *
 * @param   portNo          Port Number.
 *  @li @c      0 to 7      Port Number.
 *  @li @c      others      Nothing is done.
 *
 * @retval      0           Low.
 * @retval      1           High.
 ***************************************************************************/
unsigned char c17getInputPDx(unsigned short portNo)
{
	if (portNo > 7) {
		return 0;
	}

	/*PDDAT: PD Port Data Register */
	{
		// Get output data.
		return getInputPxx(portNo, (P0DAT_REG*)&PDDAT);
	}
}


unsigned char getInputPxx(unsigned short portNo, P0DAT_REG* portRegister)
{
	// Get intput data.
	unsigned char result = 0;

	/**
	 * GET PxIN
     *    1 : Output high level from the port pin
     *    0 : Output low level from the port pin
	 *
	 */
	if((portRegister->reg & LOWBYTE_BIT_SET(portNo)) != 0)
	{
		result = 1;
	}

	return result;
}


/************************************************************************//**
 * @brief   Set port direction and Chattering Filter and PULL UP/PULL DOWN Control
 *
 * @param   portNo                      Port Number.
 *  @li @c      0 to 7                  Port Number.
 *  @li @c      others                  Nothing is done.
 * @param   portDir                     GPIO port input / output
 *  @li @c      C17_PORT_DIR_INPUT      Input.
 *  @li @c      C17_PORT_DIR_OUTPUT     Output.
 * @param   portChatta                  GPIO  Chattering Filter Enable/Disable
 *  @li @c      0                       Disable.
 *  @li @c      1                       Enable.
 * @param   portPull                    GPIO  PULL UP/PULL DOWN Control
 *  @li @c      C17_PORT_PULL_DISABLE   Disable.
 *  @li @c      C17_PORT_PULL_UP        PULL UP.
 *  @li @c      C17_PORT_PULL_DOWN      PULL DOWN.
 *
 * @retval  none
 ***************************************************************************/
void c17setDirectionP0x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull)
{
	// Set Port Direction
	if (portNo > 7) {
		return ;
	}

	/* P0IOEN:P0 Port Enable Register */
	{
		setDirectionPxx(portNo, portDir, (P0IOEN_REG*)&P0IOEN);
	}
	/* P0CHATEN: P0 Port Chattering Filter Enable Register */
	{
		setChattaPxx(portNo, portChatta, (P0CHATEN_REG*)&P0CHATEN);
	}
	/* P0RCTL_REG:P0 Port Pull-up/down Control Register */
	{
		setPullUpDownPxx(portNo, portPull, (P0RCTL_REG*)&P0RCTL);
	}
}


/************************************************************************//**
 * @brief   Set port direction and Chattering Filter and PULL UP/PULL DOWN Control
 *
 * @param   portNo                      Port Number.
 *  @li @c      0 to 7                  Port Number.
 *  @li @c      others                  Nothing is done.
 * @param   portDir                     GPIO port input / output
 *  @li @c      C17_PORT_DIR_INPUT      Input.
 *  @li @c      C17_PORT_DIR_OUTPUT     Output.
 * @param   portChatta                  GPIO  Chattering Filter Enable/Disable
 *  @li @c      0                       Disable.
 *  @li @c      1                       Enable.
 * @param   portPull                    GPIO  PULL UP/PULL DOWN Control
 *  @li @c      C17_PORT_PULL_DISABLE   Disable.
 *  @li @c      C17_PORT_PULL_UP        PULL UP.
 *  @li @c      C17_PORT_PULL_DOWN      PULL DOWN.
 *
 * @retval  none
 ***************************************************************************/
void c17setDirectionP1x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull)
{
	// Set Port Direction
	if (portNo > 7) {
		return ;
	}

	/* P1IOEN:P1 Port Enable Register */
	{
		setDirectionPxx(portNo, portDir, (P0IOEN_REG*)&P1IOEN);
	}
	/* P1CHATEN: P1 Port Chattering Filter Enable Register */
	{
		setChattaPxx(portNo, portChatta, (P0CHATEN_REG*)&P1CHATEN);
	}
	/* P1RCTL_REG:P1 Port Pull-up/down Control Register */
	{
		setPullUpDownPxx(portNo, portPull, (P0RCTL_REG*)&P1RCTL);
	}
}


/************************************************************************//**
 * @brief   Set port direction and Chattering Filter and PULL UP/PULL DOWN Control
 *
 * @param   portNo                      Port Number.
 *  @li @c      0 to 7                  Port Number.
 *  @li @c      others                  Nothing is done.
 * @param   portDir                     GPIO port input / output
 *  @li @c      C17_PORT_DIR_INPUT      Input.
 *  @li @c      C17_PORT_DIR_OUTPUT     Output.
 * @param   portChatta                  GPIO  Chattering Filter Enable/Disable
 *  @li @c      0                       Disable.
 *  @li @c      1                       Enable.
 * @param   portPull                    GPIO  PULL UP/PULL DOWN Control
 *  @li @c      C17_PORT_PULL_DISABLE   Disable.
 *  @li @c      C17_PORT_PULL_UP        PULL UP.
 *  @li @c      C17_PORT_PULL_DOWN      PULL DOWN.
 *
 * @retval  none
 ***************************************************************************/
void c17setDirectionP2x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull)
{
	// Set Port Direction
	if (portNo > 7) {
		return ;
	}
	/* P2IOEN:P2 Port Enable Register */
	{
		setDirectionPxx(portNo, portDir, (P0IOEN_REG*)&P2IOEN);
	}
	/* P2CHATEN: P2 Port Chattering Filter Enable Register */
	{
		setChattaPxx(portNo, portChatta, (P0CHATEN_REG*)&P2CHATEN);
	}
	/* P2RCTL_REG:P2 Port Pull-up/down Control Register */
	{
		setPullUpDownPxx(portNo, portPull, (P0RCTL_REG*)&P2RCTL);
	}
}


/************************************************************************//**
 * @brief   Set port direction and Chattering Filter and PULL UP/PULL DOWN Control
 *
 * @param   portNo                      Port Number.
 *  @li @c      0 to 7                  Port Number.
 *  @li @c      others                  Nothing is done.
 * @param   portDir                     GPIO port input / output
 *  @li @c      C17_PORT_DIR_INPUT      Input.
 *  @li @c      C17_PORT_DIR_OUTPUT     Output.
 * @param   portChatta                  GPIO  Chattering Filter Enable/Disable
 *  @li @c      0                       Disable.
 *  @li @c      1                       Enable.
 * @param   portPull                    GPIO  PULL UP/PULL DOWN Control
 *  @li @c      C17_PORT_PULL_DISABLE   Disable.
 *  @li @c      C17_PORT_PULL_UP        PULL UP.
 *  @li @c      C17_PORT_PULL_DOWN      PULL DOWN.
 *
 * @retval  none
 ***************************************************************************/
void c17setDirectionP3x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull)
{
	// Set Port Direction
	if (portNo > 7) {
		return ;
	}
	/* P3IOEN:P3 Port Enable Register */
	{
		setDirectionPxx(portNo, portDir, (P0IOEN_REG*)&P3IOEN);
	}
	/* P3CHATEN: P3 Port Chattering Filter Enable Register */
	{
		setChattaPxx(portNo, portChatta, (P0CHATEN_REG*)&P3CHATEN);
	}
	/* P3RCTL_REG:P3 Port Pull-up/down Control Register */
	{
		setPullUpDownPxx(portNo, portPull, (P0RCTL_REG*)&P3RCTL);
	}
}


/************************************************************************//**
 * @brief   Set port direction and Chattering Filter and PULL UP/PULL DOWN Control
 *
 * @param   portNo                      Port Number.
 *  @li @c      0 to 7                  Port Number.
 *  @li @c      others                  Nothing is done.
 * @param   portDir                     GPIO port input / output
 *  @li @c      C17_PORT_DIR_INPUT      Input.
 *  @li @c      C17_PORT_DIR_OUTPUT     Output.
 * @param   portChatta                  GPIO  Chattering Filter Enable/Disable
 *  @li @c      0                       Disable.
 *  @li @c      1                       Enable.
 * @param   portPull                    GPIO  PULL UP/PULL DOWN Control
 *  @li @c      C17_PORT_PULL_DISABLE   Disable.
 *  @li @c      C17_PORT_PULL_UP        PULL UP.
 *  @li @c      C17_PORT_PULL_DOWN      PULL DOWN.
 *
 * @retval  none
 ***************************************************************************/
void c17setDirectionP4x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull)
{
	// Set Port Direction
	if (portNo > 7) {
		return ;
	}
	/* P4IOEN:P4 Port Enable Register */
	{
		setDirectionPxx(portNo, portDir, (P0IOEN_REG*)&P4IOEN);
	}
	/* P4CHATEN: P4 Port Chattering Filter Enable Register */
	{
		setChattaPxx(portNo, portChatta, (P0CHATEN_REG*)&P4CHATEN);
	}
	/* P4RCTL_REG:P4 Port Pull-up/down Control Register */
	{
		setPullUpDownPxx(portNo, portPull, (P0RCTL_REG*)&P4RCTL);
	}
}


/************************************************************************//**
 * @brief   Set port direction and Chattering Filter and PULL UP/PULL DOWN Control
 *
 * @param   portNo                      Port Number.
 *  @li @c      0 to 7                  Port Number.
 *  @li @c      others                  Nothing is done.
 * @param   portDir                     GPIO port input / output
 *  @li @c      C17_PORT_DIR_INPUT      Input.
 *  @li @c      C17_PORT_DIR_OUTPUT     Output.
 * @param   portChatta                  GPIO  Chattering Filter Enable/Disable
 *  @li @c      0                       Disable.
 *  @li @c      1                       Enable.
 * @param   portPull                    GPIO  PULL UP/PULL DOWN Control
 *  @li @c      C17_PORT_PULL_DISABLE   Disable.
 *  @li @c      C17_PORT_PULL_UP        PULL UP.
 *  @li @c      C17_PORT_PULL_DOWN      PULL DOWN.
 *
 * @retval  none
 ***************************************************************************/
void c17setDirectionP5x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull)
{
	// Set Port Direction
	if (portNo > 7) {
		return ;
	}

	/* P5IOEN:P5 Port Enable Register */
	{
		setDirectionPxx(portNo, portDir, (P0IOEN_REG*)&P5IOEN);
	}
	/* P5CHATEN: P5 Port Chattering Filter Enable Register */
	{
		setChattaPxx(portNo, portChatta, (P0CHATEN_REG*)&P5CHATEN);
	}
	/* P5RCTL_REG:P5 Port Pull-up/down Control Register */
	{
		setPullUpDownPxx(portNo, portPull, (P0RCTL_REG*)&P5RCTL);
	}
}


/************************************************************************//**
 * @brief   Set port direction and Chattering Filter and PULL UP/PULL DOWN Control
 *
 * @param   portNo                      Port Number.
 *  @li @c      0 to 7                  Port Number.
 *  @li @c      others                  Nothing is done.
 * @param   portDir                     GPIO port input / output
 *  @li @c      C17_PORT_DIR_INPUT      Input.
 *  @li @c      C17_PORT_DIR_OUTPUT     Output.
 * @param   portChatta                  GPIO  Chattering Filter Enable/Disable
 *  @li @c      0                       Disable.
 *  @li @c      1                       Enable.
 * @param   portPull                    GPIO  PULL UP/PULL DOWN Control
 *  @li @c      C17_PORT_PULL_DISABLE   Disable.
 *  @li @c      C17_PORT_PULL_UP        PULL UP.
 *  @li @c      C17_PORT_PULL_DOWN      PULL DOWN.
 *
 * @retval  none
 ***************************************************************************/
void c17setDirectionP6x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull)
{
	// Set Port Direction
	if (portNo > 7) {
		return ;
	}
	/* P6IOEN:P6 Port Enable Register */
	{
		setDirectionPxx(portNo, portDir, (P0IOEN_REG*)&P6IOEN);
	}
	/* P6CHATEN: P6 Port Chattering Filter Enable Register */
	{
		setChattaPxx(portNo, portChatta, (P0CHATEN_REG*)&P6CHATEN);
	}
	/* P6RCTL_REG:P6 Port Pull-up/down Control Register */
	{
		setPullUpDownPxx(portNo, portPull, (P0RCTL_REG*)&P6RCTL);
	}
}


/************************************************************************//**
 * @brief   Set port direction and Chattering Filter and PULL UP/PULL DOWN Control
 *
 * @param   portNo                      Port Number.
 *  @li @c      0 to 7                  Port Number.
 *  @li @c      others                  Nothing is done.
 * @param   portDir                     GPIO port input / output
 *  @li @c      C17_PORT_DIR_INPUT      Input.
 *  @li @c      C17_PORT_DIR_OUTPUT     Output.
 * @param   portChatta                  GPIO  Chattering Filter Enable/Disable
 *  @li @c      0                       Disable.
 *  @li @c      1                       Enable.
 * @param   portPull                    GPIO  PULL UP/PULL DOWN Control
 *  @li @c      C17_PORT_PULL_DISABLE   Disable.
 *  @li @c      C17_PORT_PULL_UP        PULL UP.
 *  @li @c      C17_PORT_PULL_DOWN      PULL DOWN.
 *
 * @retval  none
 ***************************************************************************/
void c17setDirectionP7x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull)
{
	// Set Port Direction
	if (portNo > 7) {
		return ;
	}
	/* P7IOEN:P7 Port Enable Register */
	{
		setDirectionPxx(portNo, portDir, (P0IOEN_REG*)&P7IOEN);
	}
	/* P7CHATEN: P7 Port Chattering Filter Enable Register */
	{
		setChattaPxx(portNo, portChatta, (P0CHATEN_REG*)&P7CHATEN);
	}
	/* P7RCTL_REG:P7 Port Pull-up/down Control Register */
	{
		setPullUpDownPxx(portNo, portPull, (P0RCTL_REG*)&P7RCTL);
	}
}


/************************************************************************//**
 * @brief   Set port direction and Chattering Filter and PULL UP/PULL DOWN Control
 *
 * @param   portNo                      Port Number.
 *  @li @c      0 to 7                  Port Number.
 *  @li @c      others                  Nothing is done.
 * @param   portDir                     GPIO port input / output
 *  @li @c      C17_PORT_DIR_INPUT      Input.
 *  @li @c      C17_PORT_DIR_OUTPUT     Output.
 * @param   portChatta                  GPIO  Chattering Filter Enable/Disable
 *  @li @c      0                       Disable.
 *  @li @c      1                       Enable.
 * @param   portPull                    GPIO  PULL UP/PULL DOWN Control
 *  @li @c      C17_PORT_PULL_DISABLE   Disable.
 *  @li @c      C17_PORT_PULL_UP        PULL UP.
 *  @li @c      C17_PORT_PULL_DOWN      PULL DOWN.
 *
 * @retval  none
 ***************************************************************************/
void c17setDirectionP8x(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull)
{
	// Set Port Direction
	if (portNo > 7) {
		return ;
	}
	/* P8IOEN:P8 Port Enable Register */
	{
		setDirectionPxx(portNo, portDir, (P0IOEN_REG*)&P8IOEN);
	}
	/* P8CHATEN: P8 Port Chattering Filter Enable Register */
	{
		setChattaPxx(portNo, portChatta, (P0CHATEN_REG*)&P8CHATEN);
	}
	/* P8RCTL_REG:P8 Port Pull-up/down Control Register */
	{
		setPullUpDownPxx(portNo, portPull, (P0RCTL_REG*)&P8RCTL);
	}
}


/************************************************************************//**
 * @brief   Set port direction and Chattering Filter and PULL UP/PULL DOWN Control
 *
 * @param   portNo                      Port Number.
 *  @li @c      0 to 7                  Port Number.
 *  @li @c      others                  Nothing is done.
 * @param   portDir                     GPIO port input / output
 *  @li @c      C17_PORT_DIR_INPUT      Input.
 *  @li @c      C17_PORT_DIR_OUTPUT     Output.
 * @param   portChatta                  GPIO  Chattering Filter Enable/Disable
 *  @li @c      0                       Disable.
 *  @li @c      1                       Enable.
 * @param   portPull                    GPIO  PULL UP/PULL DOWN Control
 *  @li @c      C17_PORT_PULL_DISABLE   Disable.
 *  @li @c      C17_PORT_PULL_UP        PULL UP.
 *  @li @c      C17_PORT_PULL_DOWN      PULL DOWN.
 *
 * @retval  none
 ***************************************************************************/
void c17setDirectionPDx(unsigned short portNo, unsigned short portDir, unsigned short portChatta, unsigned short portPull)
{
	// Set Port Direction
	if (portNo > 7) {
		return ;
	}

	/* PDIOEN:PD Port Enable Register */
	{
		setDirectionPxx(portNo, portDir, (P0IOEN_REG*)&PDIOEN);
	}

	/* PDRCTL_REG:PD Port Pull-up/down Control Register */
	{
		setPullUpDownPxx(portNo, portPull, (P0RCTL_REG*)&PDRCTL);
	}
}


static void setDirectionPxx(unsigned short portNo, unsigned short portDir, P0IOEN_REG* portRegister)
{
	P0IOEN_REG	pxioen_set;

	pxioen_set.reg =  portRegister->reg;

	if(portDir == C17_PORT_DIR_OUTPUT){
		/**
		 * Set PxOEN
         *    Enable (Data is output from the port pin.)
    	 */
		pxioen_set.reg |= LOWBYTE_BIT_SET(portNo) ;

		/**
		 * Clear PxIEN
         *    0 (R/W): Disable (Input data is fixed at 0.)
		 *
		 */
		pxioen_set.reg &= (0xFFFF ^ HIGHBYTE_BIT_SET(portNo)) ;
	} else {
		/**
		 * Claer PxOEN
         *     Disable (The port is placed into Hi-Z.)
    	 */
		pxioen_set.reg &= (0xFFFF ^ LOWBYTE_BIT_SET(portNo)) ;

		/**
		 *  Set PxIEN
         *    Enable (The port pin status is input.)
		 *
		 */
		pxioen_set.reg |= HIGHBYTE_BIT_SET(portNo) ;
	}
	portRegister->reg = pxioen_set.reg;

}


static void setChattaPxx(unsigned short portNo, unsigned short portChatta, P0CHATEN_REG* portRegister)
{
	P0CHATEN_REG	pxchaten_set;

	pxchaten_set.reg =  portRegister->reg;

	if (portChatta == 1) {
		/**
		 * Set PxCHATEN
		 * Enable (The chattering filter is used.)
		 */
		pxchaten_set.reg |= LOWBYTE_BIT_SET(portNo) ;
	} else {
		/**
		 * Clear PxCHATEN
		 * Disable (The chattering filter is bypassed.)
		 */
		pxchaten_set.reg &= (0xFFFF ^ LOWBYTE_BIT_SET(portNo));
	}
	portRegister->reg = pxchaten_set.reg;
}


static void setPullUpDownPxx(unsigned short portNo, unsigned short portPull, P0RCTL_REG* portRegister)
{
	P0RCTL_REG	pxrctl_set;

	pxrctl_set.reg =  portRegister->reg;
	switch(portPull)
	{
		case C17_PORT_PULL_DISABLE:
			/**
			 * Clear PxREN
			 * Disable (No pull-up/down control is performed.)
			 *
			 */
			pxrctl_set.reg &=  (0xFFFF ^ LOWBYTE_BIT_SET(portNo));
			break;
		case C17_PORT_PULL_UP:
			/**
			 * Set PxREN
			 * Enable (The built-in pull-up/down resistor is used.)
			 *
			 */
			pxrctl_set.reg |=  LOWBYTE_BIT_SET(portNo);

			/*
			 * Set PxPDPU
			 * Pull-up resistor
			 */
			pxrctl_set.reg |=  HIGHBYTE_BIT_SET(portNo);
			break;
		case C17_PORT_PULL_DOWN:
			/**
			 * Set PxREN
			 * Enable (The built-in pull-up/down resistor is used.)
			 *
			 */
			pxrctl_set.reg |=  LOWBYTE_BIT_SET(portNo);

			/**
			 * Clear PxPDPU
			 * Pull-down resistor
			 */
			pxrctl_set.reg &=  (0xFFFF ^ HIGHBYTE_BIT_SET(portNo));
			break;
	}
	portRegister->reg = pxrctl_set.reg;
}
#endif

