/************************************************************************//**
 *
 * @file    c17_pwg2.c
 *
 * @brief   This is Power Generator driver program file.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Nov. 2018    1.10
 *              - Change source code.
 *
 ***************************************************************************/
#include <stdlib.h>
#include "crt0.h"
#include "c17_misc.h"
#include "c17_pwg2.h"
#include "c17_init_config.h"

#if defined(C17_PE_PWG2)
/* --- interrupt handler (GNU17v3 Only) --- */
#ifdef CRT0_LINKED
C17_INTERRUPT_HANDLER(_vector06_handler, c17intPwg2);	// PWG interrupt
#endif /* CRT0_LINKED */


/************************************************************************//**
 * @brief   This function initializes PWG2 driver.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17initPwg2(void)
{
	PWGCTL_REG	pwgctl_set;
	PWGTIM_REG	pwgtim_set;

	/// disable write-protec.
	c17protectMiscOff();

	/// Set PWG2 operating mode.
	/* PWG2 Control Register. */
	{
		pwgctl_set.reg = C17_PWG2_AUTO;
		PWGCTL = pwgctl_set.reg;
	}

	/// Set OSC1 clock division ratio.
	/* PWG2 Timing Control Register. */
	{
		pwgtim_set.reg = PWG2_SET_INIT;
		PWGTIM = pwgtim_set.reg;
	}

	/// enable write-protect.
	c17protectMiscOn();

	/// Initialize the interrupt.
	ILVPWG2 = INTERRUPT_LEVEL_PWG2;		/// - Set interrupt level.

}


/************************************************************************//**
 * @brief   Set Pwg2 mode.
 *
 * @param   pwgMode
 *  @li @c  C17_PWG2_AUTO           Auto Mode.
 *  @li @c  C17_PWG2_NORMAL         Normal Mode.
 *  @li @c  C17_PWG2_ECONOMY        Economy Mode.
 *  @li @c  C17_PWG2_SUPER_ECONOMY  Super economy Mode.
 *
 * @retval  none
 ***************************************************************************/
void c17setPwg2(unsigned short pwgMode)
{
	PWGCTL_REG	pwgctl_set;

	/// disable write-protec.
	c17protectMiscOff();

	/* PWGCTL:PWG2 Control Register */
	{
		pwgctl_set.bit.PWGMOD = pwgMode;
		PWGCTL = pwgctl_set.reg;
	}

	/// enable write-protect.
	c17protectMiscOn();

}


/************************************************************************//**
 * @brief   Get PWG2 mode.
 *
 * @param   none
 *
 * @retval  C17_PWG2_AUTO           Auto Mode.
 * @retval  C17_PWG2_NORMAL         Normal Mode.
 * @retval  C17_PWG2_ECONOMY        Economy Mode.
 * @retval  C17_PWG2_SUPER_ECONOMY  Super economy Mode.
 ***************************************************************************/
int c17getPwg2Mode(void)
{
	PWGCTL_REG	pwgctl_set;

	unsigned char result = 0;

	/* PWGCTL:PWG2 Control Register */
	{
		pwgctl_set.reg = PWGCTL;
	}

	switch (pwgctl_set.bit.PWGMOD) {
	case 0:		// Auto mode.
		result = C17_PWG2_AUTO;
		break;
	case 2:		// Normal mode.
		result = C17_PWG2_NORMAL;
		break;
	case 3:		// Economy mode.
		result = C17_PWG2_ECONOMY;
		break;
	case 5:		// Super economy  mode.
		result = C17_PWG2_SUPER_ECONOMY;
		break;
	default:
		break;
	}

	return result;
}


/************************************************************************//**
 * @brief   PWG2 Interrupt Enable.
 *
 * @param   none.
 *
 * @retval  none
 ***************************************************************************/
void c17enableIntPwg2(void)
{
	PWGINTF_REG	pwgintf_set;
	PWGINTE_REG	pwginte_set;

	/// Clear interrupt flag.
	/* MODCMPIF:PWG2 Interrupt Flag Register */
	{
		pwgintf_set.reg = 0;
		pwgintf_set.bit.MODCMPIF = 1;
		PWGINTF	= pwgintf_set.reg;			///- Clear interrupt flag.
	}

	/// Disable interrupt.
	/* PWGINTE:PWG2 Interrupt Enable Register */
	{
		pwginte_set.reg = 0;
		pwginte_set.bit.MODCMPIE = 1;
		PWGINTE	= pwginte_set.reg;			///- Enable PWG2 mode transition completion interrupt.
	}
}


/************************************************************************//**
 * @brief   PWG2 Interrupt Disable.
 *
 * @param   none.
 *
 * @retval  none
 ***************************************************************************/
void c17disableIntPwg2(void)
{
	PWGINTF_REG	pwgintf_set;
	PWGINTE_REG	pwginte_set;

	/// Clear interrupt flag.
	/* MODCMPIF:PWG2 Interrupt Flag Register */
	{
		pwgintf_set.reg = 0;
		pwgintf_set.bit.MODCMPIF = 1;
		PWGINTF	= pwgintf_set.reg;			///- Clear interrupt flag.
	}

	/// Disable interrupt.
	/* PWGINTE:PWG2 Interrupt Enable Register */
	{
		pwginte_set.reg = 0;
		pwginte_set.bit.MODCMPIE = 0;
		PWGINTE	= pwginte_set.reg;			///- Enable PWG2 mode transition completion interrupt.
	}
}


/************************************************************************//**
 * @brief   PWG2 interrupt.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void c17intPwg2(void)
{
	PWGINTF_REG	pwgintf_seg;

	/// PWG2 Interrupt Flag Register
	pwgintf_seg.reg = PWGINTF;
	/// Clear interrupt flag.
	PWGINTF = pwgintf_seg.reg;

	/// Check interrupt cause occurrence status.
	if (pwgintf_seg.bit.MODCMPIF == 1) {

	   /**
		* @todo add interrupt function of PWG2 mode transition completion.
		*/
	}

}
#endif

