/************************************************************************//**
 *
 * @file    main.c
 *
 * @brief   This is LCD8B sample program for S1C17W18 demonstration.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
/************************************************************************//**
 * @mainpage    S1C17W18 LCD8B
 *
 * @section     intro Introduction
 * Sample code turns on the LCD display.
 *
 * @subsection  step1   Step  1: Start OSC1.
 * @subsection  step2   Step  2: LCD register initialize and LCD display on.
 * @subsection  step3   Step  3: Start RTCA(1-second interrupt).
 * @subsection  step4   Step  4: Turn on LCD display by all on.
 * @subsection  step5   Step  5: Turn on LCD display by all off.
 * @subsection  step6   Step  6: Turn on LCD display area 0.
 *                               Set display area 0 data by checker-board pattern.
 *                               Turn on LCD display by normal display.
 * @subsection	step7   Step  7: Set LCD driver's inverted display.
 * @subsection	step8   Step  8: Turn off LCD display by display off.
 *                               End sample program.
 *
 * @section     install Installation
 * Start the IDE and import the "s1c17w18_sample" project.
 *
 ************************************************************************* */
#include <stdlib.h>
#include "c17_misc.h"
#include "c17_clg.h"
#include "c17_rtca.h"
#include "c17_lcd8b.h"
#include "c17_init_config.h"

#if defined(C17_PE_LCD8B)

/* --- definition --- */
/**
 * @todo change display switch time[sec].
 */
#define LCD_DISPLAY_SWITCH_TIME	(2)

/* --- global variable --- */
extern volatile unsigned int c17rtcaIntCount;

/* --- function declaration --- */

int main_lcd8b(void);


/************************************************************************//**
 * main function.
 *
 * @brief   1, LCD register initialize.
 *
 *          2, LCD display on.
 *
 *          3, Stop after the display off.
 *
 * @return 	EXIT_SUCCESS    Success.
 ***************************************************************************/
int main_lcd8b(void)
{
	volatile unsigned int secCount = 0;
	volatile unsigned int secOld   = 0;

	/* <<< LCD8B driver demonstration start >>> */

	/// Initialize and start OSC1.
	c17startClgOSC1();

	/// Initialize LCD.
	c17initLcd8b();

	/// Display on.
	c17onLcd8bDisplay();

	/// Initialize and start RTCA.
	c17initRtca();

	/// RTCA Interrupt Enable.
	c17enableIntRtca();

	/// Clear Interruption counter.
	c17rtcaIntCount = 0;

	/// Start RTCA.
	c17startRtca();

	/// Display LCD.
	while(secCount < (6 * LCD_DISPLAY_SWITCH_TIME)){

		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is released, and it diverges to the server blade.
		asm ("halt");
		asm ("nop");

		secOld = secCount;
		secCount = c17rtcaIntCount;

		/// Nothing is done for the same time.
		if (secOld == secCount) {
			continue;
		}

		switch (secCount) {
			case 1 * LCD_DISPLAY_SWITCH_TIME:
				/// The LCD display set the state to "all on".
				c17setLcd8bDisplayState(C17_LCD_STATE_ALL_ON);
				break;

			case 2 * LCD_DISPLAY_SWITCH_TIME:
				/// The LCD display set the state to "all off".
				c17setLcd8bDisplayState(C17_LCD_STATE_ALL_OFF);
				break;

			case 3 * LCD_DISPLAY_SWITCH_TIME:
				/// Set display area 0 data by checker-board pattern.
				c17setLcd8bCheckerboardPattern();
				/// Set LCD driver's display area 0.
				c17setLcd8bDisplayArea(C17_LCD_DISPLAY_AREA0);
				/// The LCD display set the state to "Normal display".
				c17setLcd8bDisplayState(C17_LCD_STATE_NORMAL);
				break;

			case 4 * LCD_DISPLAY_SWITCH_TIME:
				/// Set LCD driver's inverted display.
				c17setLcd8bDisplayInverted(C17_LCD_DISPLAY_INVERTED);
				break;

			case 5 * LCD_DISPLAY_SWITCH_TIME:
				/// The LCD display state set to "Display off".
				c17setLcd8bDisplayState(C17_LCD_STATE_OFF);
				break;

			default:
				/// Non.
				break;
		}
	}

	/// Display off.
	c17offLcd8bDisplay();

	/// Stop RTCA.
	c17stopRtca();

	/* <<< LCD8B driver demonstration finish >>> */

	return EXIT_SUCCESS;
}
#endif

