/************************************************************************//**
 *
 * @file    main.c
 *
 * @brief   This is Sound Generator(SNDA) sample program for S1C17W18 demonstration.
 *
 * @par     Copyright:
 *          Copyright(C) SEIKO EPSON CORPORATION 2016-2016. All rights reserved
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *
 ***************************************************************************/
/************************************************************************//**
 * @mainpage    S1C17W18 Sound Generator(SNDA)
 *
 * @section     intro Introduction
 * Sample code for start Sound Generator(SNDA).
 *
 * @subsection  step1   Step  1: Initialize SNDA.
 * @subsection  step2   Step  2: Start normal mode for SNDA.
 * @subsection  step3   Step  3: Normal mode stop in (SNDA_SWITCH_TIME) seconds.
 * @subsection  step4   Step  4: Start one-shot mode for SNDA.(3 times)
 * @subsection  step5   Step  5: Start melody mode for SNDA.
 * @subsection  step6   Step  6: End processing when the melody ends.
 *
 * @section     install Installation
 * Start the IDE and import the "s1c17w18_sample" project.
 *
 ************************************************************************* */
#include <stdlib.h>
#include "c17_misc.h"
#include "c17_clg.h"
#include "c17_rtca.h"
#include "c17_snda.h"
#include "c17_init_config.h"

#if defined(C17_PE_SNDA)

/* --- definition --- */
/**
 * @todo change switch time[sec].
 */
#define SNDA_SWITCH_TIME	(1)
/**
 * @todo change Melody data MAX number.
 */
#define MELODY_NUM			(20)

/* --- global variable --- */
unsigned short melody_data1[MELODY_NUM][4];		///< Melody data.
unsigned short melody_data2[MELODY_NUM][4];		///< Melody data.
unsigned short melody_data3[MELODY_NUM][4];		///< Melody data.
unsigned short melody_data4[MELODY_NUM][4];		///< Melody data.

extern volatile unsigned int c17rtcaIntCount;

/* --- function declaration --- */
int main_snda(void);

void inputConfirmationSound(void);
void inputDisableSound(void);
void weakAttentionSound(void);
void rtcWait(void);

/************************************************************************//**
 * main function.
 *
 * @brief   1, SNDA register initialize.
 *
 *          2, Start SNDA.
 *
 *          3, Stop SNDA.
 *
 * @return 	EXIT_SUCCESS    Success.
 ***************************************************************************/
int main_snda(void)
{
	volatile unsigned int secCount = 0;
	volatile unsigned int secOld   = 0;

	// <<< Sound Generator demonstration start >>

	/// Initialize and start OSC1.
	c17startClgOSC1();

	/// Initialize SNDA.
	c17initSnda();

	/// Initialize and start RTCA.
	c17initRtca();

	/// RTCA Interrupt Enable.
	c17enableIntRtca();

	/// Clear Interruption counter.
	c17rtcaIntCount = 0;

	/// Start RTCA.
	c17startRtca();

	/// Start SNDA.
	c17startSnda();


	/// Normal mode & One-shot mode Start.

	while(secCount < (6 * SNDA_SWITCH_TIME)){

		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is released, and it diverges to the server blade.
		asm ("halt");
		asm ("nop");

		secOld = secCount;
		secCount = c17rtcaIntCount;

		/// Nothing is done for the same time.
		if (secOld == secCount) {
			continue;
		}

		switch (secCount) {
		case 1 * SNDA_SWITCH_TIME:
			/**
			 * @todo change buzzer signal duty ratio. buzzer signal frequency.
			 */
			/// Start normal mode.
			c17runSndaNormal(2048, 50);
			break;

		case 2 * SNDA_SWITCH_TIME:
			/// Stop normal mode.
			c17stopSndaSound();
			break;

		case 3 * SNDA_SWITCH_TIME:
			/**
			 * @todo change buzzer signal duty ratio. buzzer signal frequency. output duration.
			 */
			/// Run one-shot mode(1).
			c17runSndaOneShot(2048, 87.5, C17_SND_DURATION_15);
			break;

		case 4 * SNDA_SWITCH_TIME:
			/**
			 * @todo change buzzer signal duty ratio. buzzer signal frequency. output duration.
			 */
			/// Run one-shot mode(2).
			c17runSndaOneShot(2048, 87.5, C17_SND_DURATION_10);
			break;

		case 5 * SNDA_SWITCH_TIME:
			/**
			 * @todo change buzzer signal duty ratio. buzzer signal frequency. output duration.
			 */
			/// Run one-shot mode(3).
			c17runSndaOneShot(2048, 87.5, C17_SND_DURATION_5);
			break;

		default:
			/// Non.
			break;
		}
	}


	/// Melody mode Start.

	/// Stop SNDA.
	c17stopSndaSound();
	/// Clear melody data.
	c17clearSndaMelodyData(MELODY_NUM, melody_data1);
	/**
	 * @todo change Melody data.
	 *              Please set to Last data is "C17_SND_LAST_DATA".
	 */
	/// Set melody data.
	c17setMelodyNote(C17_SND_LEN_8, C17_SND_SCALE_B5,  C17_SND_TIE_DISABLE, melody_data1);
	c17setMelodyNote(C17_SND_LEN_8, C17_SND_SCALE_AS5, C17_SND_TIE_DISABLE, melody_data1);
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_A5,  C17_SND_TIE_DISABLE, melody_data1);
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_F5,  C17_SND_TIE_DISABLE, melody_data1);
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_B5,  C17_SND_TIE_DISABLE, melody_data1);
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_G5,  C17_SND_TIE_DISABLE, melody_data1);
	c17setMelodyNote(C17_SND_LEN_2, C17_SND_SCALE_C6,  C17_SND_TIE_DISABLE, melody_data1);
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_C6,  C17_SND_TIE_DISABLE, melody_data1);
	c17setMelodyRest(C17_SND_LEN_32, melody_data1);
	c17setMelodyNote(C17_SND_LEN_16, C17_SND_SCALE_G5, C17_SND_TIE_DISABLE, melody_data1);
	c17setMelodyNote(C17_SND_LEN_8, C17_SND_SCALE_C6,  C17_SND_TIE_DISABLE, melody_data1);

	/// Set melody last data.
	c17setMelodyNote(C17_SND_LAST_DATA, C17_SND_LAST_DATA, C17_SND_LAST_DATA, melody_data1);
	/// Run melody mode.
	c17runSndaMelody(melody_data1, C17_SND_DURATION_6);

	while(c17getSndaMelodyState() == SNDA_MELODY_RUN){
		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is released, and it diverges to the server blade.
		asm ("halt");
		asm ("nop");
	}

	/// Stop SNDA.
	c17stopSndaSound();

	/// Wait between melody.
	rtcWait();


	/// Start Melody.
	inputConfirmationSound();

	while(c17getSndaMelodyState() == SNDA_MELODY_RUN){

		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is released, and it diverges to the server blade.
		asm ("halt");
		asm ("nop");
	}

	/// Stop SNDA.
	c17stopSndaSound();

	/// Wait between melody.
	rtcWait();


	/// Start Melody.
	inputDisableSound();

	while(c17getSndaMelodyState() == SNDA_MELODY_RUN){

		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is released, and it diverges to the server blade.
		asm ("halt");
		asm ("nop");
	}

	/// Stop SNDA.
	c17stopSndaSound();

	/// Wait between melody.
	rtcWait();


	/// Start Melody.
	weakAttentionSound();

	while(c17getSndaMelodyState() == SNDA_MELODY_RUN){

		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is released, and it diverges to the server blade.
		asm ("halt");
		asm ("nop");
	}

	/// Stop RTCA.
	c17stopRtca();

	/// Stop SNDA.
	c17stopSnda();

	/// <<< Sound Generator demonstration finish >>>

	return EXIT_SUCCESS;
}


/************************************************************************//**
 * @brief   This function Audio Confirmation Melody.
 *          Melody: C17_SND_SCALE_C6(0.1[msec])
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void inputConfirmationSound(void)
{
	/// Clear melody data.
	c17clearSndaMelodyData(MELODY_NUM, melody_data2);

	/// Set melody data.
	c17setMelodyNote(C17_SND_LEN_16, C17_SND_SCALE_C6, C17_SND_TIE_DISABLE, melody_data2);

	/// Set melody last data.
	c17setMelodyNote(C17_SND_LAST_DATA, C17_SND_LAST_DATA, C17_SND_LAST_DATA, melody_data2);

	/// Run melody mode.
	c17runSndaMelody(melody_data2, C17_SND_TEMPO_3);
}


/************************************************************************//**
 * @brief   This function Input Disable sound Melody.
 *          Melody: C17_SND_SCALE_C6(0.1[msec]) + interval(0.1[msec] + C17_SND_SCALE_C6(0.5[msec])
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void inputDisableSound(void)
{
	/// Clear melody data.
	c17clearSndaMelodyData(MELODY_NUM, melody_data3);

	/// Set melody data.
	c17setMelodyNote(C17_SND_LEN_16, C17_SND_SCALE_C6, C17_SND_TIE_DISABLE, melody_data3);
	c17setMelodyRest(C17_SND_LEN_16, melody_data3);
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_C6, C17_SND_TIE_DISABLE, melody_data3);

	/// Set melody last data.
	c17setMelodyNote(C17_SND_LAST_DATA, C17_SND_LAST_DATA, C17_SND_LAST_DATA, melody_data3);

	/// Run melody mode.
	c17runSndaMelody(melody_data3, C17_SND_TEMPO_3);
}


/************************************************************************//**
 * @brief   This function Weak note sound Melody.
 *          Melody: {C17_SND_SCALE_C6(0.5[msec]) + interval(0.2[msec]} * 5set
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void weakAttentionSound(void)
{
	/// Clear melody data.
	c17clearSndaMelodyData(MELODY_NUM, melody_data4);

	/// Set melody data.
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_C6, C17_SND_TIE_DISABLE, melody_data4);
	c17setMelodyRest(C17_SND_LEN_8, melody_data4);
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_C6, C17_SND_TIE_DISABLE, melody_data4);
	c17setMelodyRest(C17_SND_LEN_8, melody_data4);
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_C6, C17_SND_TIE_DISABLE, melody_data4);
	c17setMelodyRest(C17_SND_LEN_8, melody_data4);
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_C6, C17_SND_TIE_DISABLE, melody_data4);
	c17setMelodyRest(C17_SND_LEN_8, melody_data4);
	c17setMelodyNote(C17_SND_LEN_4, C17_SND_SCALE_C6, C17_SND_TIE_DISABLE, melody_data4);
	c17setMelodyRest(C17_SND_LEN_8, melody_data4);

	/// Set melody last data.
	c17setMelodyNote(C17_SND_LAST_DATA, C17_SND_LAST_DATA, C17_SND_LAST_DATA, melody_data4);

	/// Run melody mode.
	c17runSndaMelody(melody_data4, C17_SND_TEMPO_3);
}


/************************************************************************//**
 * @brief   This function RTC WAIT.
 *
 * @param   none
 *
 * @retval  none
 ***************************************************************************/
void rtcWait(void)
{

	volatile unsigned int secCount = 0;
	volatile unsigned int secOld   = 0;

	secCount = c17rtcaIntCount;
	secOld = secCount;

	while(secOld == secCount){

		// Set halt mode.
		// Nop is necessary when the main program is not executed after
		// halt is released, and it diverges to the server blade.
		asm ("halt");
		asm ("nop");

		secCount = c17rtcaIntCount;
	}
}
#endif

