/************************************************************************//**
 *
 * @file    main.c
 *
 * @brief   This is SPIA sample program for S1C17W18 demonstration.
 *
 * @par     Copyright:
 *          Copyright (C) SEIKO EPSON CORPORATION 2016-2018. All rights reserved.
 *
 * @warning -
 *
 * @par     History:
 *          - 01 Sep. 2016    1.00
 *              - First revision.
 *          - 01 Nov. 2018    1.10
 *              - Change source code.
 *
 ***************************************************************************/
/************************************************************************//**
 * @main page   S1C17W18 SPIA
 *
 * @section     intro Introduction
 * Sample code transmit data using SPIA.
 * The code receive data using SPIA.
 *
 * @subsection  --- MASTER ---
 * @subsection  step1   Step 1: Start SPIA.
 *                      Initialize and Start SPIA.
 *                      Initialize 16-bit timer for SPIA clock.
 *                      Start SPIA.
 * @subsection  step2   Step 2: Transmit "A" to "Z".
 * @subsection  step3   Step 3: Receive data.
 * @subsection  step4   Step 4: Compare receive data and the transmission data.
 *                      If it is the same data, OK is returned.
 *
 * @subsection  --- SLAVE ---
 * @subsection  step1   Step 1: Start SPIA.
 *                      Initialize and Start SPIA.
 * @subsection  step2   Step 2: Receive data.
 * @subsection  step3   Step 3: Transmit "A" to "Z".
 * @subsection  step4   Step 4: Compare receive data and the transmission data.
 *                      If it is the same data, OK is returned.
 *
 * @section     install Installation
 * Start the IDE and import the "s1c17w18_sample" project.
 *
 *******************************************************************************/
#include <string.h>
#include <stdlib.h>
#include <c17_mcu_select.h>
#include "c17_misc.h"
#include "c17_clg.h"
#include "c17_spia.h"
#include "c17_t16.h"
#include "c17_init_config.h"

#if defined(C17_PE_SPIA_MASTER) || defined(C17_PE_SPIA_SLAVE)

/* --- definition --- */


/* --- global variable --- */

/// Transmit data buffer.
static char sndData[27] =
{
	'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
	'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
	'\0'
};
/// Receive data buffer.
static char rcvData[27];

/* --- function declaration --- */

int main_spia(void);

#ifdef C17_PE_SPIA_MASTER
static int runMaster(void);
#else
static int runSlave(void);
#endif


extern unsigned short c17sendSPIDataAsm(unsigned short spiChannel, char *spiData, unsigned short spiSize);
extern unsigned short c17rcvSpiaDataAsm(unsigned short spiChannel, char *spiData, unsigned short spiSize);

/************************************************************************//**
 * Main function.
 *
 * @brief   1, Initialize and start SPIA.
 *          2, The processing of master or slave begins.
 *          3, stop SPIA
 *
 * @return  EXIT_SUCCESS    Success.
 * @return  EXIT_FAILURE    Failed.
 ***************************************************************************/
int main_spia(void)
{
	int i;
	int result = 0;

	/// Clock = IOSC
	c17startClgIOSC();
	c17switchClgSystemClockIOSC();
	c17stopClgOSC3();

	/// start OSC3(internal oscillator)
	c17startClgIntOSC3(C17_CLG_OSC3_4MHZ);

	/// the system clock set in OSC3.
	c17switchClgSystemClockOSC3();


	// Clear receive data buffer.
	for (i = 0; i < sizeof(rcvData); i++) {
		rcvData[i] = 0;
	}

	/* <<< SPIA demonstration start >>> */

	/// Initialize SPIA.
	c17initSpia();


	/// SPIA CH.0 Start.
	c17startSpia(0);

#ifdef C17_PE_SPIA_MASTER
	// SPIA Master.
	/// Initialize T16 CH.1 timer.
	/// Use for the clock generation of SPI CH.0.
	c17setT16(1, C17_T16_CLKSRC_OSC3, C17_T16_CLKDIV_32, C17_T16_MODE_REPEAT);
	result = runMaster();
#else
	// SPIA Slave.
	result = runSlave();
#endif

	/// Stop SPIA CH.0.
	c17stopSpia(0);

	/* <<< SPIA demonstration finish >>> */



	return result;
}


#ifdef C17_PE_SPIA_MASTER
/************************************************************************//**
 *
 * @brief   runMaster function.
 *
 * @return  EXIT_SUCCESS    Success.
 * @return  EXIT_FAILURE    Failed.
 ***************************************************************************/
int runMaster(void)
{
	/* Transmit */
	{
		/// Assert SPIA CH.0.
		c17assertSpiaSs(0);

		/// Transmit data.
		//c17sendSPIDataAsm(0, sndData, sizeof(sndData));
		c17sendSpiaData(0, sndData, sizeof(sndData));

		/// Negate SPIA CH.0.
		c17negateSpiaSs(0);
	}
	/* Receive */
	{
		/// Assert SPIA CH.0.
		c17assertSpiaSs(0);

		/// Receive data.
		//c17rcvSpiaDataAsm(0,rcvData, sizeof(rcvData));
		c17rcvSpiaData(0, rcvData, sizeof(rcvData));

		/// Negate SPIA CH.0.
		c17negateSpiaSs(0);
	}

	/* Check data */
	/// Check receive data.
	if (strcmp(sndData, rcvData) != 0) {
		return EXIT_FAILURE;
	}

	return EXIT_SUCCESS;
}


#else
/************************************************************************//**
 *
 * @brief   runSlave function.
 *
 * @return  EXIT_SUCCESS    Success.
 * @return  EXIT_FAILURE    Failed.
 ***************************************************************************/
int runSlave(void)
{
	/* Receive */
	{
		/// Receive data.
		c17rcvSpiaData(0, rcvData, sizeof(rcvData));
		//c17rcvSpiaDataAsm(0,rcvData, sizeof(rcvData));
	}

	/* Transmit */
	{
		/// Transmit data.
		c17sendSpiaData(0, sndData, sizeof(sndData));
	}

	/* Check data */
	/// Check receive data.
	if (strcmp(sndData, rcvData) != 0) {
		return EXIT_FAILURE;
	}

	return EXIT_SUCCESS;
}
#endif

#endif

